# -*- coding: mbcs -*-
# Created by makepy.py version 0.5.01
# By python version 3.8.2 (tags/v3.8.2:7b3ab59, Feb 25 2020, 23:03:10) [MSC v.1916 64 bit (AMD64)]
# From type library 'ksConstants.tlb'
# On Fri Nov  5 08:14:55 2021
''
makepy_version = '0.5.01'
python_version = 0x30802f0

import win32com.client.CLSIDToClass, pythoncom, pywintypes
import win32com.client.util
from pywintypes import IID
from win32com.client import Dispatch

# The following 3 lines may need tweaking for the particular server
# Candidates are pythoncom.Missing, .Empty and .ArgNotFound
defaultNamedOptArg=pythoncom.Empty
defaultNamedNotOptArg=pythoncom.Empty
defaultUnnamedArg=pythoncom.Empty

CLSID = IID('{75C9F5D0-B5B8-4526-8681-9903C567D2ED}')
MajorVersion = 1
MinorVersion = 0
LibraryFlags = 8
LCID = 0x0

class constants:
	ksCheckButton                 =1          # from enum ButtonTypeEnum
	ksPushButton                  =0          # from enum ButtonTypeEnum
	ksRadioButton                 =2          # from enum ButtonTypeEnum
	ksCheckCurrent                =1          # from enum CheckStateEnum
	ksCheckFixed                  =2          # from enum CheckStateEnum
	ksCheckUndefined              =0          # from enum CheckStateEnum
	ksCheckVariable               =3          # from enum CheckStateEnum
	ksControlAggregateTriple      =40         # from enum ControlTypeEnum
	ksControlBasePoint            =41         # from enum ControlTypeEnum
	ksControlBmpList              =24         # from enum ControlTypeEnum
	ksControlCheckBox             =8          # from enum ControlTypeEnum
	ksControlColor                =17         # from enum ControlTypeEnum
	ksControlEditAngle            =20         # from enum ControlTypeEnum
	ksControlEditCheckBox         =29         # from enum ControlTypeEnum
	ksControlEditInt              =2          # from enum ControlTypeEnum
	ksControlEditLength           =19         # from enum ControlTypeEnum
	ksControlEditList             =18         # from enum ControlTypeEnum
	ksControlEditPoint            =21         # from enum ControlTypeEnum
	ksControlEditReal             =3          # from enum ControlTypeEnum
	ksControlEditStr              =4          # from enum ControlTypeEnum
	ksControlFileName             =16         # from enum ControlTypeEnum
	ksControlGrid                 =10         # from enum ControlTypeEnum
	ksControlGroupBegin           =34         # from enum ControlTypeEnum
	ksControlGroupEnd             =35         # from enum ControlTypeEnum
	ksControlHatchStyle           =33         # from enum ControlTypeEnum
	ksControlLibExplorer          =25         # from enum ControlTypeEnum
	ksControlLineStyle            =27         # from enum ControlTypeEnum
	ksControlLineStyle3D          =32         # from enum ControlTypeEnum
	ksControlLinkButton           =42         # from enum ControlTypeEnum
	ksControlListAngle            =23         # from enum ControlTypeEnum
	ksControlListInt              =5          # from enum ControlTypeEnum
	ksControlListLength           =22         # from enum ControlTypeEnum
	ksControlListReal             =6          # from enum ControlTypeEnum
	ksControlListScale            =26         # from enum ControlTypeEnum
	ksControlListStr              =7          # from enum ControlTypeEnum
	ksControlMarking              =43         # from enum ControlTypeEnum
	ksControlMultiButton          =9          # from enum ControlTypeEnum
	ksControlOpticalProps         =28         # from enum ControlTypeEnum
	ksControlPoint3D              =37         # from enum ControlTypeEnum
	ksControlPointStyle           =30         # from enum ControlTypeEnum
	ksControlPointStyle3D         =31         # from enum ControlTypeEnum
	ksControlPreviewText          =38         # from enum ControlTypeEnum
	ksControlReplaceList          =44         # from enum ControlTypeEnum
	ksControlSeparator            =1          # from enum ControlTypeEnum
	ksControlSlideBox             =11         # from enum ControlTypeEnum
	ksControlSpinInt              =14         # from enum ControlTypeEnum
	ksControlSpinReal             =15         # from enum ControlTypeEnum
	ksControlTextButton           =13         # from enum ControlTypeEnum
	ksControlTwinSwitcher         =36         # from enum ControlTypeEnum
	ksControlUnknown              =0          # from enum ControlTypeEnum
	ksControlUser                 =12         # from enum ControlTypeEnum
	kcCurrentPlane                =3          # from enum ConvertCoordTypeEnum
	kcDocument                    =1          # from enum ConvertCoordTypeEnum
	kcGeoView                     =2          # from enum ConvertCoordTypeEnum
	ksAllFix                      =0          # from enum DefaultFixTypeEnum
	ksAllFixOff                   =-1         # from enum DefaultFixTypeEnum
	ksAngleFix                    =2          # from enum DefaultFixTypeEnum
	ksPointFix                    =1          # from enum DefaultFixTypeEnum
	kdDoNotSaveChanges            =0          # from enum DocumentCloseOptions
	kdPromptToSaveChanges         =2          # from enum DocumentCloseOptions
	kdSaveChanges                 =1          # from enum DocumentCloseOptions
	ksDocumentAssembly            =5          # from enum DocumentTypeEnum
	ksDocumentDrawing             =1          # from enum DocumentTypeEnum
	ksDocumentFragment            =2          # from enum DocumentTypeEnum
	ksDocumentPart                =4          # from enum DocumentTypeEnum
	ksDocumentSpecification       =3          # from enum DocumentTypeEnum
	ksDocumentTechnologyAssembly  =7          # from enum DocumentTypeEnum
	ksDocumentTextual             =6          # from enum DocumentTypeEnum
	ksDocumentUnknown             =0          # from enum DocumentTypeEnum
	ksAllObj                      =0          # from enum DrawingObjectTypeEnum
	ksArrayParamTable             =79         # from enum DrawingObjectTypeEnum
	ksDrABreakDimension           =39         # from enum DrawingObjectTypeEnum
	ksDrADimension                =10         # from enum DrawingObjectTypeEnum
	ksDrAnnArc                    =67         # from enum DrawingObjectTypeEnum
	ksDrAnnCircle                 =65         # from enum DrawingObjectTypeEnum
	ksDrAnnEllipse                =66         # from enum DrawingObjectTypeEnum
	ksDrAnnEllipseArc             =68         # from enum DrawingObjectTypeEnum
	ksDrAnnLineSeg                =64         # from enum DrawingObjectTypeEnum
	ksDrAnnPoint                  =70         # from enum DrawingObjectTypeEnum
	ksDrAnnPolyline               =69         # from enum DrawingObjectTypeEnum
	ksDrAnnText                   =71         # from enum DrawingObjectTypeEnum
	ksDrArc                       =3          # from enum DrawingObjectTypeEnum
	ksDrArcAxis                   =59         # from enum DrawingObjectTypeEnum
	ksDrArcDimension              =43         # from enum DrawingObjectTypeEnum
	ksDrAttachedLeader            =74         # from enum DrawingObjectTypeEnum
	ksDrAxisLine                  =48         # from enum DrawingObjectTypeEnum
	ksDrBase                      =17         # from enum DrawingObjectTypeEnum
	ksDrBezier                    =8          # from enum DrawingObjectTypeEnum
	ksDrBrace                     =51         # from enum DrawingObjectTypeEnum
	ksDrBrandLeader               =22         # from enum DrawingObjectTypeEnum
	ksDrBrokenLine                =57         # from enum DrawingObjectTypeEnum
	ksDrBuildingCutLine           =73         # from enum DrawingObjectTypeEnum
	ksDrCentreMarker              =42         # from enum DrawingObjectTypeEnum
	ksDrChangeLeader              =46         # from enum DrawingObjectTypeEnum
	ksDrCircle                    =2          # from enum DrawingObjectTypeEnum
	ksDrCircleAxis                =58         # from enum DrawingObjectTypeEnum
	ksDrCircularCentres           =84         # from enum DrawingObjectTypeEnum
	ksDrColorFill                 =41         # from enum DrawingObjectTypeEnum
	ksDrConditionCrossing         =75         # from enum DrawingObjectTypeEnum
	ksDrConicCurve                =81         # from enum DrawingObjectTypeEnum
	ksDrContour                   =26         # from enum DrawingObjectTypeEnum
	ksDrCut                       =19         # from enum DrawingObjectTypeEnum
	ksDrCutUnitMarking            =60         # from enum DrawingObjectTypeEnum
	ksDrDDimension                =13         # from enum DrawingObjectTypeEnum
	ksDrDrawText                  =4          # from enum DrawingObjectTypeEnum
	ksDrEllipse                   =32         # from enum DrawingObjectTypeEnum
	ksDrEllipseArc                =34         # from enum DrawingObjectTypeEnum
	ksDrEllipseArcAxis            =86         # from enum DrawingObjectTypeEnum
	ksDrEquid                     =37         # from enum DrawingObjectTypeEnum
	ksDrExternalView              =63         # from enum DrawingObjectTypeEnum
	ksDrFragment                  =30         # from enum DrawingObjectTypeEnum
	ksDrHatch                     =7          # from enum DrawingObjectTypeEnum
	ksDrLBreakDimension           =38         # from enum DrawingObjectTypeEnum
	ksDrLDimension                =9          # from enum DrawingObjectTypeEnum
	ksDrLeader                    =20         # from enum DrawingObjectTypeEnum
	ksDrLine                      =28         # from enum DrawingObjectTypeEnum
	ksDrLineSeg                   =1          # from enum DrawingObjectTypeEnum
	ksDrLinearCentres             =85         # from enum DrawingObjectTypeEnum
	ksDrMacro                     =27         # from enum DrawingObjectTypeEnum
	ksDrMarkInsideForm            =54         # from enum DrawingObjectTypeEnum
	ksDrMarkOnLeader              =52         # from enum DrawingObjectTypeEnum
	ksDrMarkOnLine                =53         # from enum DrawingObjectTypeEnum
	ksDrMarkerLeader              =23         # from enum DrawingObjectTypeEnum
	ksDrMultiLine                 =72         # from enum DrawingObjectTypeEnum
	ksDrMultiTextLeader           =62         # from enum DrawingObjectTypeEnum
	ksDrNurbs                     =33         # from enum DrawingObjectTypeEnum
	ksDrNurbsByPoints             =80         # from enum DrawingObjectTypeEnum
	ksDrOLEObject                 =49         # from enum DrawingObjectTypeEnum
	ksDrOrdinateDimension         =40         # from enum DrawingObjectTypeEnum
	ksDrPoint                     =5          # from enum DrawingObjectTypeEnum
	ksDrPolyline                  =31         # from enum DrawingObjectTypeEnum
	ksDrPosLeader                 =21         # from enum DrawingObjectTypeEnum
	ksDrRBreakDimension           =15         # from enum DrawingObjectTypeEnum
	ksDrRDimension                =14         # from enum DrawingObjectTypeEnum
	ksDrRaster                    =45         # from enum DrawingObjectTypeEnum
	ksDrRectangle                 =35         # from enum DrawingObjectTypeEnum
	ksDrRegularPolygon            =36         # from enum DrawingObjectTypeEnum
	ksDrRemoteElement             =47         # from enum DrawingObjectTypeEnum
	ksDrRough                     =16         # from enum DrawingObjectTypeEnum
	ksDrStraightAxis              =56         # from enum DrawingObjectTypeEnum
	ksDrTable                     =25         # from enum DrawingObjectTypeEnum
	ksDrTolerance                 =24         # from enum DrawingObjectTypeEnum
	ksDrUnitMarking               =61         # from enum DrawingObjectTypeEnum
	ksDrUnitNumber                =50         # from enum DrawingObjectTypeEnum
	ksDrWPointer                  =18         # from enum DrawingObjectTypeEnum
	ksDrWaveLine                  =55         # from enum DrawingObjectTypeEnum
	ksEmbodimentsTable            =77         # from enum DrawingObjectTypeEnum
	ksLayer                       =29         # from enum DrawingObjectTypeEnum
	ksReportTable                 =76         # from enum DrawingObjectTypeEnum
	ksUnknown                     =-1         # from enum DrawingObjectTypeEnum
	ksView                        =123        # from enum DrawingObjectTypeEnum
	etAbort                       =-1         # from enum ErrorType
	etError1                      =1          # from enum ErrorType
	etError10                     =10         # from enum ErrorType
	etError100                    =100        # from enum ErrorType
	etError101                    =101        # from enum ErrorType
	etError102                    =102        # from enum ErrorType
	etError103                    =103        # from enum ErrorType
	etError104                    =104        # from enum ErrorType
	etError105                    =105        # from enum ErrorType
	etError106                    =106        # from enum ErrorType
	etError107                    =107        # from enum ErrorType
	etError108                    =108        # from enum ErrorType
	etError109                    =109        # from enum ErrorType
	etError11                     =11         # from enum ErrorType
	etError110                    =110        # from enum ErrorType
	etError111                    =111        # from enum ErrorType
	etError112                    =112        # from enum ErrorType
	etError113                    =113        # from enum ErrorType
	etError114                    =114        # from enum ErrorType
	etError115                    =115        # from enum ErrorType
	etError116                    =116        # from enum ErrorType
	etError117                    =117        # from enum ErrorType
	etError118                    =118        # from enum ErrorType
	etError119                    =119        # from enum ErrorType
	etError12                     =12         # from enum ErrorType
	etError120                    =120        # from enum ErrorType
	etError121                    =121        # from enum ErrorType
	etError122                    =122        # from enum ErrorType
	etError123                    =123        # from enum ErrorType
	etError124                    =124        # from enum ErrorType
	etError125                    =125        # from enum ErrorType
	etError126                    =126        # from enum ErrorType
	etError127                    =127        # from enum ErrorType
	etError128                    =128        # from enum ErrorType
	etError129                    =129        # from enum ErrorType
	etError13                     =13         # from enum ErrorType
	etError130                    =130        # from enum ErrorType
	etError131                    =131        # from enum ErrorType
	etError132                    =132        # from enum ErrorType
	etError133                    =133        # from enum ErrorType
	etError134                    =134        # from enum ErrorType
	etError135                    =135        # from enum ErrorType
	etError136                    =136        # from enum ErrorType
	etError137                    =137        # from enum ErrorType
	etError138                    =138        # from enum ErrorType
	etError139                    =139        # from enum ErrorType
	etError14                     =14         # from enum ErrorType
	etError140                    =140        # from enum ErrorType
	etError141                    =141        # from enum ErrorType
	etError142                    =142        # from enum ErrorType
	etError143                    =143        # from enum ErrorType
	etError144                    =144        # from enum ErrorType
	etError145                    =145        # from enum ErrorType
	etError146                    =146        # from enum ErrorType
	etError147                    =147        # from enum ErrorType
	etError148                    =148        # from enum ErrorType
	etError149                    =149        # from enum ErrorType
	etError15                     =15         # from enum ErrorType
	etError150                    =150        # from enum ErrorType
	etError151                    =151        # from enum ErrorType
	etError152                    =152        # from enum ErrorType
	etError153                    =153        # from enum ErrorType
	etError154                    =154        # from enum ErrorType
	etError155                    =155        # from enum ErrorType
	etError156                    =156        # from enum ErrorType
	etError157                    =157        # from enum ErrorType
	etError158                    =158        # from enum ErrorType
	etError159                    =159        # from enum ErrorType
	etError16                     =16         # from enum ErrorType
	etError160                    =160        # from enum ErrorType
	etError161                    =161        # from enum ErrorType
	etError162                    =162        # from enum ErrorType
	etError163                    =163        # from enum ErrorType
	etError164                    =164        # from enum ErrorType
	etError165                    =165        # from enum ErrorType
	etError166                    =166        # from enum ErrorType
	etError167                    =167        # from enum ErrorType
	etError168                    =168        # from enum ErrorType
	etError169                    =169        # from enum ErrorType
	etError17                     =17         # from enum ErrorType
	etError170                    =170        # from enum ErrorType
	etError171                    =171        # from enum ErrorType
	etError172                    =172        # from enum ErrorType
	etError173                    =173        # from enum ErrorType
	etError174                    =174        # from enum ErrorType
	etError175                    =175        # from enum ErrorType
	etError176                    =176        # from enum ErrorType
	etError177                    =177        # from enum ErrorType
	etError178                    =178        # from enum ErrorType
	etError179                    =179        # from enum ErrorType
	etError18                     =18         # from enum ErrorType
	etError180                    =180        # from enum ErrorType
	etError181                    =181        # from enum ErrorType
	etError182                    =182        # from enum ErrorType
	etError183                    =183        # from enum ErrorType
	etError184                    =184        # from enum ErrorType
	etError185                    =185        # from enum ErrorType
	etError186                    =186        # from enum ErrorType
	etError187                    =187        # from enum ErrorType
	etError188                    =188        # from enum ErrorType
	etError189                    =189        # from enum ErrorType
	etError19                     =19         # from enum ErrorType
	etError190                    =190        # from enum ErrorType
	etError191                    =191        # from enum ErrorType
	etError192                    =192        # from enum ErrorType
	etError193                    =193        # from enum ErrorType
	etError194                    =194        # from enum ErrorType
	etError195                    =195        # from enum ErrorType
	etError196                    =196        # from enum ErrorType
	etError197                    =197        # from enum ErrorType
	etError198                    =198        # from enum ErrorType
	etError199                    =199        # from enum ErrorType
	etError2                      =2          # from enum ErrorType
	etError20                     =20         # from enum ErrorType
	etError200                    =200        # from enum ErrorType
	etError201                    =201        # from enum ErrorType
	etError202                    =202        # from enum ErrorType
	etError203                    =203        # from enum ErrorType
	etError204                    =204        # from enum ErrorType
	etError205                    =205        # from enum ErrorType
	etError206                    =206        # from enum ErrorType
	etError207                    =207        # from enum ErrorType
	etError208                    =208        # from enum ErrorType
	etError209                    =209        # from enum ErrorType
	etError21                     =21         # from enum ErrorType
	etError210                    =210        # from enum ErrorType
	etError211                    =211        # from enum ErrorType
	etError212                    =212        # from enum ErrorType
	etError213                    =213        # from enum ErrorType
	etError214                    =214        # from enum ErrorType
	etError215                    =215        # from enum ErrorType
	etError216                    =216        # from enum ErrorType
	etError217                    =217        # from enum ErrorType
	etError218                    =218        # from enum ErrorType
	etError22                     =22         # from enum ErrorType
	etError23                     =23         # from enum ErrorType
	etError24                     =24         # from enum ErrorType
	etError25                     =25         # from enum ErrorType
	etError26                     =26         # from enum ErrorType
	etError27                     =27         # from enum ErrorType
	etError28                     =28         # from enum ErrorType
	etError29                     =29         # from enum ErrorType
	etError3                      =3          # from enum ErrorType
	etError30                     =30         # from enum ErrorType
	etError31                     =31         # from enum ErrorType
	etError32                     =32         # from enum ErrorType
	etError33                     =33         # from enum ErrorType
	etError34                     =34         # from enum ErrorType
	etError35                     =35         # from enum ErrorType
	etError36                     =36         # from enum ErrorType
	etError37                     =37         # from enum ErrorType
	etError38                     =38         # from enum ErrorType
	etError39                     =39         # from enum ErrorType
	etError4                      =4          # from enum ErrorType
	etError40                     =40         # from enum ErrorType
	etError41                     =41         # from enum ErrorType
	etError42                     =42         # from enum ErrorType
	etError43                     =43         # from enum ErrorType
	etError44                     =44         # from enum ErrorType
	etError45                     =45         # from enum ErrorType
	etError46                     =46         # from enum ErrorType
	etError47                     =47         # from enum ErrorType
	etError48                     =48         # from enum ErrorType
	etError49                     =49         # from enum ErrorType
	etError5                      =5          # from enum ErrorType
	etError50                     =50         # from enum ErrorType
	etError51                     =51         # from enum ErrorType
	etError52                     =52         # from enum ErrorType
	etError53                     =53         # from enum ErrorType
	etError54                     =54         # from enum ErrorType
	etError55                     =55         # from enum ErrorType
	etError56                     =56         # from enum ErrorType
	etError57                     =57         # from enum ErrorType
	etError58                     =58         # from enum ErrorType
	etError59                     =59         # from enum ErrorType
	etError6                      =6          # from enum ErrorType
	etError60                     =60         # from enum ErrorType
	etError61                     =61         # from enum ErrorType
	etError62                     =62         # from enum ErrorType
	etError63                     =63         # from enum ErrorType
	etError64                     =64         # from enum ErrorType
	etError65                     =65         # from enum ErrorType
	etError66                     =66         # from enum ErrorType
	etError67                     =67         # from enum ErrorType
	etError68                     =68         # from enum ErrorType
	etError69                     =69         # from enum ErrorType
	etError7                      =7          # from enum ErrorType
	etError70                     =70         # from enum ErrorType
	etError71                     =71         # from enum ErrorType
	etError72                     =72         # from enum ErrorType
	etError73                     =73         # from enum ErrorType
	etError74                     =74         # from enum ErrorType
	etError75                     =75         # from enum ErrorType
	etError76                     =76         # from enum ErrorType
	etError77                     =77         # from enum ErrorType
	etError78                     =78         # from enum ErrorType
	etError79                     =79         # from enum ErrorType
	etError8                      =8          # from enum ErrorType
	etError80                     =80         # from enum ErrorType
	etError81                     =81         # from enum ErrorType
	etError82                     =82         # from enum ErrorType
	etError83                     =83         # from enum ErrorType
	etError84                     =84         # from enum ErrorType
	etError85                     =85         # from enum ErrorType
	etError86                     =86         # from enum ErrorType
	etError87                     =87         # from enum ErrorType
	etError88                     =88         # from enum ErrorType
	etError89                     =89         # from enum ErrorType
	etError9                      =9          # from enum ErrorType
	etError90                     =90         # from enum ErrorType
	etError91                     =91         # from enum ErrorType
	etError92                     =92         # from enum ErrorType
	etError93                     =93         # from enum ErrorType
	etError94                     =94         # from enum ErrorType
	etError95                     =95         # from enum ErrorType
	etError96                     =96         # from enum ErrorType
	etError97                     =97         # from enum ErrorType
	etError98                     =98         # from enum ErrorType
	etError99                     =99         # from enum ErrorType
	etLibraryClose                =-4         # from enum ErrorType
	etNo3dDocument                =-7         # from enum ErrorType
	etNoAllDocument               =-6         # from enum ErrorType
	etNoDocument                  =-2         # from enum ErrorType
	etNoPreView                   =-3         # from enum ErrorType
	etNoSPCDocument               =-5         # from enum ErrorType
	etNoTXTDocument               =-8         # from enum ErrorType
	etSuccess                     =0          # from enum ErrorType
	ksStateFALSE                  =0          # from enum FilterConditionStateEnum
	ksStateTRUE                   =1          # from enum FilterConditionStateEnum
	ksStateUndefined              =-1         # from enum FilterConditionStateEnum
	ksFrameMaximize               =1          # from enum FrameRegimeEnum
	ksFrameMinimize               =0          # from enum FrameRegimeEnum
	ksFrameRestore                =2          # from enum FrameRegimeEnum
	ks3dMateConstraint            =11002      # from enum KompasAPIObjectTypeEnum
	ks3dMateConstraints           =11243      # from enum KompasAPIObjectTypeEnum
	ksIntervalVariable            =10127      # from enum KompasAPIObjectTypeEnum
	ksMate3DByAngle               =11244      # from enum KompasAPIObjectTypeEnum
	ksMate3DByTangent             =11245      # from enum KompasAPIObjectTypeEnum
	ksMate3DCamGear               =11248      # from enum KompasAPIObjectTypeEnum
	ksMate3DDependentPosition     =11249      # from enum KompasAPIObjectTypeEnum
	ksMate3DSymmetry              =11246      # from enum KompasAPIObjectTypeEnum
	ksMate3DTransmission          =11247      # from enum KompasAPIObjectTypeEnum
	ksObjectAdditionalBlockSectionTuning=10076      # from enum KompasAPIObjectTypeEnum
	ksObjectAdditionalBlockSectionTunings=10075      # from enum KompasAPIObjectTypeEnum
	ksObjectAdditionalBlockStyle  =10072      # from enum KompasAPIObjectTypeEnum
	ksObjectAdditionalBlockStyles =10071      # from enum KompasAPIObjectTypeEnum
	ksObjectAdditionalBlockTuning =10074      # from enum KompasAPIObjectTypeEnum
	ksObjectAdditionalBlockTunings=10073      # from enum KompasAPIObjectTypeEnum
	ksObjectAngleDimension        =13047      # from enum KompasAPIObjectTypeEnum
	ksObjectAngleDimension3D      =11037      # from enum KompasAPIObjectTypeEnum
	ksObjectAngleDimensions       =13049      # from enum KompasAPIObjectTypeEnum
	ksObjectAngleDimensions3D     =11038      # from enum KompasAPIObjectTypeEnum
	ksObjectAngularUnhistoriedDimension=11220      # from enum KompasAPIObjectTypeEnum
	ksObjectAnnotativeArc         =13125      # from enum KompasAPIObjectTypeEnum
	ksObjectAnnotativeCircle      =13123      # from enum KompasAPIObjectTypeEnum
	ksObjectAnnotativeEllipse     =13124      # from enum KompasAPIObjectTypeEnum
	ksObjectAnnotativeEllipseArc  =13126      # from enum KompasAPIObjectTypeEnum
	ksObjectAnnotativeLineSegment =13122      # from enum KompasAPIObjectTypeEnum
	ksObjectAnnotativePoint       =13128      # from enum KompasAPIObjectTypeEnum
	ksObjectAnnotativePolyLine    =13127      # from enum KompasAPIObjectTypeEnum
	ksObjectAnnotativeText        =13129      # from enum KompasAPIObjectTypeEnum
	ksObjectApplication           =10001      # from enum KompasAPIObjectTypeEnum
	ksObjectArc                   =13027      # from enum KompasAPIObjectTypeEnum
	ksObjectArc3D                 =11120      # from enum KompasAPIObjectTypeEnum
	ksObjectArcAxis               =13005      # from enum KompasAPIObjectTypeEnum
	ksObjectArcDimension          =13050      # from enum KompasAPIObjectTypeEnum
	ksObjectArcDimension3D        =11347      # from enum KompasAPIObjectTypeEnum
	ksObjectArcDimensions         =13051      # from enum KompasAPIObjectTypeEnum
	ksObjectArcDimensions3D       =11348      # from enum KompasAPIObjectTypeEnum
	ksObjectArcs                  =13026      # from enum KompasAPIObjectTypeEnum
	ksObjectArcs3D                =11119      # from enum KompasAPIObjectTypeEnum
	ksObjectAreaMeasurement3D     =11301      # from enum KompasAPIObjectTypeEnum
	ksObjectAreaMeasurements3D    =11300      # from enum KompasAPIObjectTypeEnum
	ksObjectAssemblyDocument      =10025      # from enum KompasAPIObjectTypeEnum
	ksObjectAssociationTable      =13149      # from enum KompasAPIObjectTypeEnum
	ksObjectAssociationTables     =13148      # from enum KompasAPIObjectTypeEnum
	ksObjectAssociationView       =10032      # from enum KompasAPIObjectTypeEnum
	ksObjectAttachedDocument      =10093      # from enum KompasAPIObjectTypeEnum
	ksObjectAttachedDocuments     =10092      # from enum KompasAPIObjectTypeEnum
	ksObjectAttachedLeader        =13144      # from enum KompasAPIObjectTypeEnum
	ksObjectAttachedLeaders       =13145      # from enum KompasAPIObjectTypeEnum
	ksObjectAttrTypeMng           =10507      # from enum KompasAPIObjectTypeEnum
	ksObjectAttribute             =10504      # from enum KompasAPIObjectTypeEnum
	ksObjectAttributeType         =10506      # from enum KompasAPIObjectTypeEnum
	ksObjectAuxCircularPattern    =11088      # from enum KompasAPIObjectTypeEnum
	ksObjectAuxLinearPattern      =11087      # from enum KompasAPIObjectTypeEnum
	ksObjectAuxMirrorPattern      =11095      # from enum KompasAPIObjectTypeEnum
	ksObjectAuxPathPattern        =11089      # from enum KompasAPIObjectTypeEnum
	ksObjectAuxPointDrivenPattern =11121      # from enum KompasAPIObjectTypeEnum
	ksObjectAuxTablePattern       =11125      # from enum KompasAPIObjectTypeEnum
	ksObjectAxes3D                =11189      # from enum KompasAPIObjectTypeEnum
	ksObjectAxis3D                =11188      # from enum KompasAPIObjectTypeEnum
	ksObjectAxis3DBy2Planes       =11191      # from enum KompasAPIObjectTypeEnum
	ksObjectAxis3DBy2Points       =11190      # from enum KompasAPIObjectTypeEnum
	ksObjectAxis3DByConeface      =11192      # from enum KompasAPIObjectTypeEnum
	ksObjectAxis3DByEdge          =11193      # from enum KompasAPIObjectTypeEnum
	ksObjectAxis3DByOperation     =11195      # from enum KompasAPIObjectTypeEnum
	ksObjectAxis3DByPointAndObject=11194      # from enum KompasAPIObjectTypeEnum
	ksObjectAxisJut               =13007      # from enum KompasAPIObjectTypeEnum
	ksObjectAxisLine              =13111      # from enum KompasAPIObjectTypeEnum
	ksObjectAxisLine3D            =11341      # from enum KompasAPIObjectTypeEnum
	ksObjectAxisLines             =13110      # from enum KompasAPIObjectTypeEnum
	ksObjectBase                  =13060      # from enum KompasAPIObjectTypeEnum
	ksObjectBase3D                =11056      # from enum KompasAPIObjectTypeEnum
	ksObjectBaseLineDimension3D   =11031      # from enum KompasAPIObjectTypeEnum
	ksObjectBases                 =13061      # from enum KompasAPIObjectTypeEnum
	ksObjectBases3D               =11057      # from enum KompasAPIObjectTypeEnum
	ksObjectBezier                =13079      # from enum KompasAPIObjectTypeEnum
	ksObjectBeziers               =13078      # from enum KompasAPIObjectTypeEnum
	ksObjectBilletObsolete        =11234      # from enum KompasAPIObjectTypeEnum
	ksObjectBilletsObsoletes      =11235      # from enum KompasAPIObjectTypeEnum
	ksObjectBodiesCircularPattern =11143      # from enum KompasAPIObjectTypeEnum
	ksObjectBodiesLinearPattern   =11142      # from enum KompasAPIObjectTypeEnum
	ksObjectBodiesPathPattern     =11144      # from enum KompasAPIObjectTypeEnum
	ksObjectBodiesPointDrivenPattern=11122      # from enum KompasAPIObjectTypeEnum
	ksObjectBodiesTablePattern    =11126      # from enum KompasAPIObjectTypeEnum
	ksObjectBody7                 =11009      # from enum KompasAPIObjectTypeEnum
	ksObjectBodyReposition        =11295      # from enum KompasAPIObjectTypeEnum
	ksObjectBodyRepositions       =11294      # from enum KompasAPIObjectTypeEnum
	ksObjectBoolean               =11267      # from enum KompasAPIObjectTypeEnum
	ksObjectBooleans              =11266      # from enum KompasAPIObjectTypeEnum
	ksObjectBrace                 =13022      # from enum KompasAPIObjectTypeEnum
	ksObjectBraces                =13023      # from enum KompasAPIObjectTypeEnum
	ksObjectBrandLeader           =13057      # from enum KompasAPIObjectTypeEnum
	ksObjectBrandLeader3D         =11055      # from enum KompasAPIObjectTypeEnum
	ksObjectBreakAngleDimension   =13048      # from enum KompasAPIObjectTypeEnum
	ksObjectBreakLineDimension    =13043      # from enum KompasAPIObjectTypeEnum
	ksObjectBreakLineDimensions   =13044      # from enum KompasAPIObjectTypeEnum
	ksObjectBreakRadialDimension  =13030      # from enum KompasAPIObjectTypeEnum
	ksObjectBreakRadialDimensions =13032      # from enum KompasAPIObjectTypeEnum
	ksObjectBrokenLine            =13136      # from enum KompasAPIObjectTypeEnum
	ksObjectBrokenLines           =13135      # from enum KompasAPIObjectTypeEnum
	ksObjectBuildingAxes          =13006      # from enum KompasAPIObjectTypeEnum
	ksObjectBuildingCutLine       =13132      # from enum KompasAPIObjectTypeEnum
	ksObjectBuildingCutLines      =13131      # from enum KompasAPIObjectTypeEnum
	ksObjectCentreMarker          =13107      # from enum KompasAPIObjectTypeEnum
	ksObjectCentreMarkers         =13106      # from enum KompasAPIObjectTypeEnum
	ksObjectChamfer               =11257      # from enum KompasAPIObjectTypeEnum
	ksObjectChamfers              =11256      # from enum KompasAPIObjectTypeEnum
	ksObjectChangeLeader          =13059      # from enum KompasAPIObjectTypeEnum
	ksObjectCheckSum              =10099      # from enum KompasAPIObjectTypeEnum
	ksObjectChooseManager         =10107      # from enum KompasAPIObjectTypeEnum
	ksObjectCircle                =13075      # from enum KompasAPIObjectTypeEnum
	ksObjectCircleAxis            =13004      # from enum KompasAPIObjectTypeEnum
	ksObjectCircleCopyObjectParam =13139      # from enum KompasAPIObjectTypeEnum
	ksObjectCircles               =13074      # from enum KompasAPIObjectTypeEnum
	ksObjectCircularCentres       =13162      # from enum KompasAPIObjectTypeEnum
	ksObjectCircularCopyObjectParam=13140      # from enum KompasAPIObjectTypeEnum
	ksObjectCircularPattern       =11082      # from enum KompasAPIObjectTypeEnum
	ksObjectCircularPatternAnyCopy=11214      # from enum KompasAPIObjectTypeEnum
	ksObjectCircularsCentries     =13161      # from enum KompasAPIObjectTypeEnum
	ksObjectCloudPointsSurface    =11139      # from enum KompasAPIObjectTypeEnum
	ksObjectCloudPointsSurfaces   =11138      # from enum KompasAPIObjectTypeEnum
	ksObjectCollectionGeometry    =11238      # from enum KompasAPIObjectTypeEnum
	ksObjectCollectionsGeometry   =11239      # from enum KompasAPIObjectTypeEnum
	ksObjectColouring             =13119      # from enum KompasAPIObjectTypeEnum
	ksObjectColourings            =13118      # from enum KompasAPIObjectTypeEnum
	ksObjectColumnInfo            =10505      # from enum KompasAPIObjectTypeEnum
	ksObjectConditionIntersect    =13170      # from enum KompasAPIObjectTypeEnum
	ksObjectConditionIntersects   =13171      # from enum KompasAPIObjectTypeEnum
	ksObjectConicCurve            =13160      # from enum KompasAPIObjectTypeEnum
	ksObjectConicCurves           =13159      # from enum KompasAPIObjectTypeEnum
	ksObjectConicHoleParameters   =11255      # from enum KompasAPIObjectTypeEnum
	ksObjectConicSpiral3D         =11179      # from enum KompasAPIObjectTypeEnum
	ksObjectConjunctivePoint      =11063      # from enum KompasAPIObjectTypeEnum
	ksObjectConjunctivePoints     =11062      # from enum KompasAPIObjectTypeEnum
	ksObjectConnectCurve          =11114      # from enum KompasAPIObjectTypeEnum
	ksObjectConnectCurves         =11113      # from enum KompasAPIObjectTypeEnum
	ksObjectContentDialogParam    =10124      # from enum KompasAPIObjectTypeEnum
	ksObjectContour               =10705      # from enum KompasAPIObjectTypeEnum
	ksObjectContour3D             =11161      # from enum KompasAPIObjectTypeEnum
	ksObjectContourArc            =10708      # from enum KompasAPIObjectTypeEnum
	ksObjectContourLineSegment    =10707      # from enum KompasAPIObjectTypeEnum
	ksObjectContourSegment        =10706      # from enum KompasAPIObjectTypeEnum
	ksObjectContours3D            =11162      # from enum KompasAPIObjectTypeEnum
	ksObjectControlPoint          =11061      # from enum KompasAPIObjectTypeEnum
	ksObjectControlPoints         =11060      # from enum KompasAPIObjectTypeEnum
	ksObjectConverter             =10098      # from enum KompasAPIObjectTypeEnum
	ksObjectCopiesGeometry        =11237      # from enum KompasAPIObjectTypeEnum
	ksObjectCopyGeometry          =11236      # from enum KompasAPIObjectTypeEnum
	ksObjectCopyObjectParam       =13137      # from enum KompasAPIObjectTypeEnum
	ksObjectCountersinkHoleParameters=11252      # from enum KompasAPIObjectTypeEnum
	ksObjectCountersinkSpotfacingHoleParameters=11254      # from enum KompasAPIObjectTypeEnum
	ksObjectCoupling              =11274      # from enum KompasAPIObjectTypeEnum
	ksObjectCurve2D               =13115      # from enum KompasAPIObjectTypeEnum
	ksObjectCurveBy2Projections   =11159      # from enum KompasAPIObjectTypeEnum
	ksObjectCurveByLaw            =11149      # from enum KompasAPIObjectTypeEnum
	ksObjectCurveByLaws           =11150      # from enum KompasAPIObjectTypeEnum
	ksObjectCurveCopyObjectParam  =13138      # from enum KompasAPIObjectTypeEnum
	ksObjectCurveOutLine          =11147      # from enum KompasAPIObjectTypeEnum
	ksObjectCurveOutLines         =11148      # from enum KompasAPIObjectTypeEnum
	ksObjectCurveStyle            =10520      # from enum KompasAPIObjectTypeEnum
	ksObjectCurveVertexParam      =11046      # from enum KompasAPIObjectTypeEnum
	ksObjectCurvesBy2Projectionses=11160      # from enum KompasAPIObjectTypeEnum
	ksObjectCurvesStyles          =10516      # from enum KompasAPIObjectTypeEnum
	ksObjectCut                   =11269      # from enum KompasAPIObjectTypeEnum
	ksObjectCutExtrusion          =11010      # from enum KompasAPIObjectTypeEnum
	ksObjectCutLine               =13067      # from enum KompasAPIObjectTypeEnum
	ksObjectCutLines              =13066      # from enum KompasAPIObjectTypeEnum
	ksObjectCutRotated            =11129      # from enum KompasAPIObjectTypeEnum
	ksObjectCutUnitMarking        =13014      # from enum KompasAPIObjectTypeEnum
	ksObjectCutUnitMarkings       =13015      # from enum KompasAPIObjectTypeEnum
	ksObjectCuts                  =11268      # from enum KompasAPIObjectTypeEnum
	ksObjectCylindricSpiral3D     =11180      # from enum KompasAPIObjectTypeEnum
	ksObjectDerivedPattern        =11092      # from enum KompasAPIObjectTypeEnum
	ksObjectDiametralDimension    =13029      # from enum KompasAPIObjectTypeEnum
	ksObjectDiametralDimension3D  =11034      # from enum KompasAPIObjectTypeEnum
	ksObjectDiametralDimensions   =13033      # from enum KompasAPIObjectTypeEnum
	ksObjectDiametralDimensions3D =11036      # from enum KompasAPIObjectTypeEnum
	ksObjectDiametralUnhistoriedDimension=11222      # from enum KompasAPIObjectTypeEnum
	ksObjectDismantleStep         =11346      # from enum KompasAPIObjectTypeEnum
	ksObjectDistanceAngleMeasurement3D=11297      # from enum KompasAPIObjectTypeEnum
	ksObjectDistanceAngleMeasurements3D=11296      # from enum KompasAPIObjectTypeEnum
	ksObjectDocument2DSettings    =10041      # from enum KompasAPIObjectTypeEnum
	ksObjectDocument3DManager     =11228      # from enum KompasAPIObjectTypeEnum
	ksObjectDocument3DSettings    =10045      # from enum KompasAPIObjectTypeEnum
	ksObjectDocumentFrame         =10018      # from enum KompasAPIObjectTypeEnum
	ksObjectDocumentFrames        =10019      # from enum KompasAPIObjectTypeEnum
	ksObjectDocumentSettings      =10040      # from enum KompasAPIObjectTypeEnum
	ksObjectDocuments             =10002      # from enum KompasAPIObjectTypeEnum
	ksObjectDrawingContour        =13072      # from enum KompasAPIObjectTypeEnum
	ksObjectDrawingContours       =13073      # from enum KompasAPIObjectTypeEnum
	ksObjectDrawingDocument       =10021      # from enum KompasAPIObjectTypeEnum
	ksObjectDrawingDocumentSettings=10042      # from enum KompasAPIObjectTypeEnum
	ksObjectDrawingGroup          =13113      # from enum KompasAPIObjectTypeEnum
	ksObjectDrawingGroups         =13114      # from enum KompasAPIObjectTypeEnum
	ksObjectDrawingObject         =13000      # from enum KompasAPIObjectTypeEnum
	ksObjectDrawingTable          =13062      # from enum KompasAPIObjectTypeEnum
	ksObjectDrawingTables         =13063      # from enum KompasAPIObjectTypeEnum
	ksObjectDrawingText           =13001      # from enum KompasAPIObjectTypeEnum
	ksObjectDrawingTexts          =13002      # from enum KompasAPIObjectTypeEnum
	ksObjectDynamicCrossSection   =11334      # from enum KompasAPIObjectTypeEnum
	ksObjectDynamicCrossSectionStep=11335      # from enum KompasAPIObjectTypeEnum
	ksObjectDynamicCrossSectionStepParametersByBorderPoints=11340      # from enum KompasAPIObjectTypeEnum
	ksObjectDynamicCrossSectionStepParametersByFreePlane=11336      # from enum KompasAPIObjectTypeEnum
	ksObjectDynamicCrossSectionStepParametersByOffsetPlane=11337      # from enum KompasAPIObjectTypeEnum
	ksObjectDynamicCrossSectionStepParametersByRotatedPlane=11338      # from enum KompasAPIObjectTypeEnum
	ksObjectDynamicCrossSectionStepParametersByZone=11339      # from enum KompasAPIObjectTypeEnum
	ksObjectEdge                  =11280      # from enum KompasAPIObjectTypeEnum
	ksObjectEdgeLengthMeasurement3D=11299      # from enum KompasAPIObjectTypeEnum
	ksObjectEdgeLengthMeasurements3D=11298      # from enum KompasAPIObjectTypeEnum
	ksObjectEditDoubleManipulator =13168      # from enum KompasAPIObjectTypeEnum
	ksObjectEllipse               =13093      # from enum KompasAPIObjectTypeEnum
	ksObjectEllipseArc            =13095      # from enum KompasAPIObjectTypeEnum
	ksObjectEllipseArcs           =13094      # from enum KompasAPIObjectTypeEnum
	ksObjectEllipses              =13092      # from enum KompasAPIObjectTypeEnum
	ksObjectEmbodiment            =11168      # from enum KompasAPIObjectTypeEnum
	ksObjectEquidistant           =13101      # from enum KompasAPIObjectTypeEnum
	ksObjectEquidistant3D         =11077      # from enum KompasAPIObjectTypeEnum
	ksObjectEquidistantSurface    =11101      # from enum KompasAPIObjectTypeEnum
	ksObjectEquidistantSurfaces   =11100      # from enum KompasAPIObjectTypeEnum
	ksObjectEquidistants          =13100      # from enum KompasAPIObjectTypeEnum
	ksObjectEquidistants3D        =11076      # from enum KompasAPIObjectTypeEnum
	ksObjectEvolution             =11276      # from enum KompasAPIObjectTypeEnum
	ksObjectEvolutionSurface      =11278      # from enum KompasAPIObjectTypeEnum
	ksObjectEvolutionSurfaces     =11277      # from enum KompasAPIObjectTypeEnum
	ksObjectEvolutions            =11275      # from enum KompasAPIObjectTypeEnum
	ksObjectExtensionSurface      =11099      # from enum KompasAPIObjectTypeEnum
	ksObjectExtensionSurfaces     =11098      # from enum KompasAPIObjectTypeEnum
	ksObjectExternalGDI           =10709      # from enum KompasAPIObjectTypeEnum
	ksObjectExternalTessellation  =10704      # from enum KompasAPIObjectTypeEnum
	ksObjectExtrusion             =11008      # from enum KompasAPIObjectTypeEnum
	ksObjectExtrusionSurface      =11131      # from enum KompasAPIObjectTypeEnum
	ksObjectExtrusionSurfaces     =11130      # from enum KompasAPIObjectTypeEnum
	ksObjectExtrussions           =11007      # from enum KompasAPIObjectTypeEnum
	ksObjectFace                  =11281      # from enum KompasAPIObjectTypeEnum
	ksObjectFaceMover             =11354      # from enum KompasAPIObjectTypeEnum
	ksObjectFaceMovers            =11353      # from enum KompasAPIObjectTypeEnum
	ksObjectFaceRemover           =11069      # from enum KompasAPIObjectTypeEnum
	ksObjectFaceRemovers          =11068      # from enum KompasAPIObjectTypeEnum
	ksObjectFeaturePatterns       =11080      # from enum KompasAPIObjectTypeEnum
	ksObjectFillet                =11259      # from enum KompasAPIObjectTypeEnum
	ksObjectFilletCurve           =11116      # from enum KompasAPIObjectTypeEnum
	ksObjectFilletCurves          =11115      # from enum KompasAPIObjectTypeEnum
	ksObjectFillets               =11258      # from enum KompasAPIObjectTypeEnum
	ksObjectFindObject3DParameters=13173      # from enum KompasAPIObjectTypeEnum
	ksObjectFindObjectParameters  =13165      # from enum KompasAPIObjectTypeEnum
	ksObjectFont                  =10079      # from enum KompasAPIObjectTypeEnum
	ksObjectFormatLabelRules      =10046      # from enum KompasAPIObjectTypeEnum
	ksObjectFragmentDocument      =10022      # from enum KompasAPIObjectTypeEnum
	ksObjectFragmentDocumentSettings=10043      # from enum KompasAPIObjectTypeEnum
	ksObjectFullFillet            =11326      # from enum KompasAPIObjectTypeEnum
	ksObjectFullFillets           =11325      # from enum KompasAPIObjectTypeEnum
	ksObjectHatch                 =13117      # from enum KompasAPIObjectTypeEnum
	ksObjectHatchParam            =13112      # from enum KompasAPIObjectTypeEnum
	ksObjectHatchStyle            =10521      # from enum KompasAPIObjectTypeEnum
	ksObjectHatches               =13116      # from enum KompasAPIObjectTypeEnum
	ksObjectHatchsStyles          =10517      # from enum KompasAPIObjectTypeEnum
	ksObjectHeightDimension       =13045      # from enum KompasAPIObjectTypeEnum
	ksObjectHeightDimensions      =13046      # from enum KompasAPIObjectTypeEnum
	ksObjectHole3D                =11251      # from enum KompasAPIObjectTypeEnum
	ksObjectHoles3D               =11250      # from enum KompasAPIObjectTypeEnum
	ksObjectImportedSurface       =11141      # from enum KompasAPIObjectTypeEnum
	ksObjectImportedSurfaces      =11140      # from enum KompasAPIObjectTypeEnum
	ksObjectIncline               =11261      # from enum KompasAPIObjectTypeEnum
	ksObjectInclines              =11260      # from enum KompasAPIObjectTypeEnum
	ksObjectInsert                =10058      # from enum KompasAPIObjectTypeEnum
	ksObjectInsertionDefinition   =13105      # from enum KompasAPIObjectTypeEnum
	ksObjectInsertionFragment     =13102      # from enum KompasAPIObjectTypeEnum
	ksObjectInsertionObjects      =13104      # from enum KompasAPIObjectTypeEnum
	ksObjectInsertionParameters   =10104      # from enum KompasAPIObjectTypeEnum
	ksObjectInsertionView         =13103      # from enum KompasAPIObjectTypeEnum
	ksObjectInserts               =10057      # from enum KompasAPIObjectTypeEnum
	ksObjectInsertsLibraries      =10055      # from enum KompasAPIObjectTypeEnum
	ksObjectInsertsLibrary        =10056      # from enum KompasAPIObjectTypeEnum
	ksObjectIsoparametricCurve    =11151      # from enum KompasAPIObjectTypeEnum
	ksObjectIsoparametricCurves   =11152      # from enum KompasAPIObjectTypeEnum
	ksObjectIsoparametricCurvesSet=11153      # from enum KompasAPIObjectTypeEnum
	ksObjectIsoparametricCurvesSets=11154      # from enum KompasAPIObjectTypeEnum
	ksObjectJointSurface          =11293      # from enum KompasAPIObjectTypeEnum
	ksObjectJointSurfaces         =11292      # from enum KompasAPIObjectTypeEnum
	ksObjectKompasError           =10003      # from enum KompasAPIObjectTypeEnum
	ksObjectLayer                 =10037      # from enum KompasAPIObjectTypeEnum
	ksObjectLayer3D               =11225      # from enum KompasAPIObjectTypeEnum
	ksObjectLayerFilterCondition  =10038      # from enum KompasAPIObjectTypeEnum
	ksObjectLayerFilterConditions =10039      # from enum KompasAPIObjectTypeEnum
	ksObjectLayerGroup            =10035      # from enum KompasAPIObjectTypeEnum
	ksObjectLayerGroup3D          =11227      # from enum KompasAPIObjectTypeEnum
	ksObjectLayerGroups           =10033      # from enum KompasAPIObjectTypeEnum
	ksObjectLayerGroups3D         =11226      # from enum KompasAPIObjectTypeEnum
	ksObjectLayers                =10036      # from enum KompasAPIObjectTypeEnum
	ksObjectLayers3D              =11224      # from enum KompasAPIObjectTypeEnum
	ksObjectLayoutSheet           =10097      # from enum KompasAPIObjectTypeEnum
	ksObjectLayoutSheets          =10096      # from enum KompasAPIObjectTypeEnum
	ksObjectLeader                =13052      # from enum KompasAPIObjectTypeEnum
	ksObjectLeader3D              =11050      # from enum KompasAPIObjectTypeEnum
	ksObjectLeaders               =13053      # from enum KompasAPIObjectTypeEnum
	ksObjectLeaders3D             =11049      # from enum KompasAPIObjectTypeEnum
	ksObjectLibArraySettings      =10710      # from enum KompasAPIObjectTypeEnum
	ksObjectLibraryHoleParameters =11324      # from enum KompasAPIObjectTypeEnum
	ksObjectLibraryManager        =10050      # from enum KompasAPIObjectTypeEnum
	ksObjectLine                  =13083      # from enum KompasAPIObjectTypeEnum
	ksObjectLineDimension         =13041      # from enum KompasAPIObjectTypeEnum
	ksObjectLineDimension3D       =11032      # from enum KompasAPIObjectTypeEnum
	ksObjectLineDimensions        =13042      # from enum KompasAPIObjectTypeEnum
	ksObjectLineDimensions3D      =11030      # from enum KompasAPIObjectTypeEnum
	ksObjectLineSegment           =13025      # from enum KompasAPIObjectTypeEnum
	ksObjectLineSegment3D         =11163      # from enum KompasAPIObjectTypeEnum
	ksObjectLineSegments          =13024      # from enum KompasAPIObjectTypeEnum
	ksObjectLineSegments3D        =11164      # from enum KompasAPIObjectTypeEnum
	ksObjectLinearCentres         =13164      # from enum KompasAPIObjectTypeEnum
	ksObjectLinearPattern         =11081      # from enum KompasAPIObjectTypeEnum
	ksObjectLinearPatternAnyCopy  =11213      # from enum KompasAPIObjectTypeEnum
	ksObjectLinearUnhistoriedDimension=11219      # from enum KompasAPIObjectTypeEnum
	ksObjectLinearsCentries       =13163      # from enum KompasAPIObjectTypeEnum
	ksObjectLines                 =13082      # from enum KompasAPIObjectTypeEnum
	ksObjectLoadCombinationsParam =13146      # from enum KompasAPIObjectTypeEnum
	ksObjectLocalCSAxesDirectionParam=11041      # from enum KompasAPIObjectTypeEnum
	ksObjectLocalCSEulerParam     =11043      # from enum KompasAPIObjectTypeEnum
	ksObjectLocalCSOrientByObjectParam=11042      # from enum KompasAPIObjectTypeEnum
	ksObjectLocalCoordinateSystem =11040      # from enum KompasAPIObjectTypeEnum
	ksObjectLocalCoordinateSystem2D=13142      # from enum KompasAPIObjectTypeEnum
	ksObjectLocalCoordinateSystems=11039      # from enum KompasAPIObjectTypeEnum
	ksObjectLocalCoordinateSystems2D=13143      # from enum KompasAPIObjectTypeEnum
	ksObjectLoft                  =11271      # from enum KompasAPIObjectTypeEnum
	ksObjectLoftSurface           =11273      # from enum KompasAPIObjectTypeEnum
	ksObjectLoftSurfaces          =11272      # from enum KompasAPIObjectTypeEnum
	ksObjectLofts                 =11270      # from enum KompasAPIObjectTypeEnum
	ksObjectLoop7                 =11282      # from enum KompasAPIObjectTypeEnum
	ksObjectMacroObject           =13081      # from enum KompasAPIObjectTypeEnum
	ksObjectMacroObject3D         =11289      # from enum KompasAPIObjectTypeEnum
	ksObjectMacroObjects          =13080      # from enum KompasAPIObjectTypeEnum
	ksObjectMacroObjects3D        =11288      # from enum KompasAPIObjectTypeEnum
	ksObjectManipulators          =13166      # from enum KompasAPIObjectTypeEnum
	ksObjectMarkInsideForm        =13012      # from enum KompasAPIObjectTypeEnum
	ksObjectMarkLeader            =13056      # from enum KompasAPIObjectTypeEnum
	ksObjectMarkLeader3D          =11051      # from enum KompasAPIObjectTypeEnum
	ksObjectMarkNode              =13009      # from enum KompasAPIObjectTypeEnum
	ksObjectMarkNodes             =13008      # from enum KompasAPIObjectTypeEnum
	ksObjectMarkOnLeader          =13010      # from enum KompasAPIObjectTypeEnum
	ksObjectMarkOnLine            =13011      # from enum KompasAPIObjectTypeEnum
	ksObjectMarks                 =13013      # from enum KompasAPIObjectTypeEnum
	ksObjectMath2D                =10105      # from enum KompasAPIObjectTypeEnum
	ksObjectMathCurve3D           =11232      # from enum KompasAPIObjectTypeEnum
	ksObjectMathSurface3D         =11233      # from enum KompasAPIObjectTypeEnum
	ksObjectMeshCopyObjectParam   =13141      # from enum KompasAPIObjectTypeEnum
	ksObjectMeshObject3D          =13158      # from enum KompasAPIObjectTypeEnum
	ksObjectMeshPointsSurface     =11137      # from enum KompasAPIObjectTypeEnum
	ksObjectMeshPointsSurfaces    =11136      # from enum KompasAPIObjectTypeEnum
	ksObjectMirrorPattern         =11093      # from enum KompasAPIObjectTypeEnum
	ksObjectModelObject           =11001      # from enum KompasAPIObjectTypeEnum
	ksObjectMoldCavities          =11286      # from enum KompasAPIObjectTypeEnum
	ksObjectMoldCavity            =11287      # from enum KompasAPIObjectTypeEnum
	ksObjectMouseEnterLeaveParameters=13169      # from enum KompasAPIObjectTypeEnum
	ksObjectMultiTextLeader       =13020      # from enum KompasAPIObjectTypeEnum
	ksObjectMultiTextLeaders      =13021      # from enum KompasAPIObjectTypeEnum
	ksObjectMultiline             =13070      # from enum KompasAPIObjectTypeEnum
	ksObjectMultilines            =13071      # from enum KompasAPIObjectTypeEnum
	ksObjectNewAssemblyDocumentSettings=10115      # from enum KompasAPIObjectTypeEnum
	ksObjectNewPartDocumentSettings=10114      # from enum KompasAPIObjectTypeEnum
	ksObjectNumericGroup          =13174      # from enum KompasAPIObjectTypeEnum
	ksObjectNurbs                 =13087      # from enum KompasAPIObjectTypeEnum
	ksObjectNurbsByPoints         =13151      # from enum KompasAPIObjectTypeEnum
	ksObjectNurbsSurface          =11073      # from enum KompasAPIObjectTypeEnum
	ksObjectNurbsSurfaceByCurvesMesh=11291      # from enum KompasAPIObjectTypeEnum
	ksObjectNurbsSurfaces         =11072      # from enum KompasAPIObjectTypeEnum
	ksObjectNurbsSurfacesByCurvesMeshs=11290      # from enum KompasAPIObjectTypeEnum
	ksObjectNurbses               =13086      # from enum KompasAPIObjectTypeEnum
	ksObjectNurbsesByPoints       =13150      # from enum KompasAPIObjectTypeEnum
	ksObjectOleDrawingObject      =13091      # from enum KompasAPIObjectTypeEnum
	ksObjectOleDrawingObjects     =13090      # from enum KompasAPIObjectTypeEnum
	ksObjectOpenDocumentParam     =13147      # from enum KompasAPIObjectTypeEnum
	ksObjectOperationAngularDimension=11170      # from enum KompasAPIObjectTypeEnum
	ksObjectOperationDiametralDimension=11172      # from enum KompasAPIObjectTypeEnum
	ksObjectOperationLinearDimension=11169      # from enum KompasAPIObjectTypeEnum
	ksObjectOperationRadialDimension=11171      # from enum KompasAPIObjectTypeEnum
	ksObjectOrientedEdge7         =11283      # from enum KompasAPIObjectTypeEnum
	ksObjectParametriticConstraint=10503      # from enum KompasAPIObjectTypeEnum
	ksObjectPart7                 =11000      # from enum KompasAPIObjectTypeEnum
	ksObjectPartDocument          =10024      # from enum KompasAPIObjectTypeEnum
	ksObjectParts7                =11003      # from enum KompasAPIObjectTypeEnum
	ksObjectPartsCircularPattern  =11085      # from enum KompasAPIObjectTypeEnum
	ksObjectPartsLinearPattern    =11084      # from enum KompasAPIObjectTypeEnum
	ksObjectPartsPathPattern      =11086      # from enum KompasAPIObjectTypeEnum
	ksObjectPartsPointDrivenPattern=11091      # from enum KompasAPIObjectTypeEnum
	ksObjectPartsTablePattern     =11124      # from enum KompasAPIObjectTypeEnum
	ksObjectPathPattern           =11083      # from enum KompasAPIObjectTypeEnum
	ksObjectPathPatternAnyCopy    =11215      # from enum KompasAPIObjectTypeEnum
	ksObjectPhantom2D             =13153      # from enum KompasAPIObjectTypeEnum
	ksObjectPlacement3D           =11223      # from enum KompasAPIObjectTypeEnum
	ksObjectPlacement3DManipulator=13167      # from enum KompasAPIObjectTypeEnum
	ksObjectPlane3D               =11197      # from enum KompasAPIObjectTypeEnum
	ksObjectPlane3DBy2Edge        =11209      # from enum KompasAPIObjectTypeEnum
	ksObjectPlane3DBy3Points      =11201      # from enum KompasAPIObjectTypeEnum
	ksObjectPlane3DByAngle        =11202      # from enum KompasAPIObjectTypeEnum
	ksObjectPlane3DByEdgeAndPlane =11208      # from enum KompasAPIObjectTypeEnum
	ksObjectPlane3DByEdgeAndPoint =11203      # from enum KompasAPIObjectTypeEnum
	ksObjectPlane3DByOffset       =11200      # from enum KompasAPIObjectTypeEnum
	ksObjectPlane3DByPlaneCurve   =11198      # from enum KompasAPIObjectTypeEnum
	ksObjectPlane3DMiddle         =11207      # from enum KompasAPIObjectTypeEnum
	ksObjectPlane3DNormalToSurface=11206      # from enum KompasAPIObjectTypeEnum
	ksObjectPlane3DParallelByPoint=11204      # from enum KompasAPIObjectTypeEnum
	ksObjectPlane3DPerpendicularByEdge=11205      # from enum KompasAPIObjectTypeEnum
	ksObjectPlane3DTangentToFace  =11210      # from enum KompasAPIObjectTypeEnum
	ksObjectPlane3DTangentToFaceInPoint=11199      # from enum KompasAPIObjectTypeEnum
	ksObjectPlanes3D              =11196      # from enum KompasAPIObjectTypeEnum
	ksObjectPoint                 =13077      # from enum KompasAPIObjectTypeEnum
	ksObjectPoint3D               =11014      # from enum KompasAPIObjectTypeEnum
	ksObjectPoint3DParamByCylinder=11135      # from enum KompasAPIObjectTypeEnum
	ksObjectPoint3DParamBySphere  =11134      # from enum KompasAPIObjectTypeEnum
	ksObjectPoint3DParamCenter    =11018      # from enum KompasAPIObjectTypeEnum
	ksObjectPoint3DParamCoord     =11015      # from enum KompasAPIObjectTypeEnum
	ksObjectPoint3DParamCurve     =11019      # from enum KompasAPIObjectTypeEnum
	ksObjectPoint3DParamDisplace  =11016      # from enum KompasAPIObjectTypeEnum
	ksObjectPoint3DParamIntersect =11017      # from enum KompasAPIObjectTypeEnum
	ksObjectPoint3DParamProjection=11021      # from enum KompasAPIObjectTypeEnum
	ksObjectPoint3DParamSurface   =11020      # from enum KompasAPIObjectTypeEnum
	ksObjectPointDrivenPattern    =11090      # from enum KompasAPIObjectTypeEnum
	ksObjectPointDrivenPatternAnyCopy=11217      # from enum KompasAPIObjectTypeEnum
	ksObjectPoints                =13076      # from enum KompasAPIObjectTypeEnum
	ksObjectPoints3D              =11013      # from enum KompasAPIObjectTypeEnum
	ksObjectPointsArrFromFile     =11186      # from enum KompasAPIObjectTypeEnum
	ksObjectPointsArrOnCurve      =11182      # from enum KompasAPIObjectTypeEnum
	ksObjectPointsArrOnSurface    =11184      # from enum KompasAPIObjectTypeEnum
	ksObjectPointsArrsFromFiles   =11187      # from enum KompasAPIObjectTypeEnum
	ksObjectPointsArrsOnCurves    =11183      # from enum KompasAPIObjectTypeEnum
	ksObjectPointsArrsOnSurfaces  =11185      # from enum KompasAPIObjectTypeEnum
	ksObjectPolyLine              =11048      # from enum KompasAPIObjectTypeEnum
	ksObjectPolyLine2D            =13085      # from enum KompasAPIObjectTypeEnum
	ksObjectPolyLines             =11047      # from enum KompasAPIObjectTypeEnum
	ksObjectPolyLines2D           =13084      # from enum KompasAPIObjectTypeEnum
	ksObjectPositionLeader        =13058      # from enum KompasAPIObjectTypeEnum
	ksObjectPositionLeader3D      =11054      # from enum KompasAPIObjectTypeEnum
	ksObjectPrintJob              =10110      # from enum KompasAPIObjectTypeEnum
	ksObjectPrintJob_Sheet        =10111      # from enum KompasAPIObjectTypeEnum
	ksObjectProcedure             =10051      # from enum KompasAPIObjectTypeEnum
	ksObjectProcedures            =10054      # from enum KompasAPIObjectTypeEnum
	ksObjectProceduresLibraries   =10052      # from enum KompasAPIObjectTypeEnum
	ksObjectProceduresLibrary     =10053      # from enum KompasAPIObjectTypeEnum
	ksObjectProcess2D             =13152      # from enum KompasAPIObjectTypeEnum
	ksObjectProcess3D             =13154      # from enum KompasAPIObjectTypeEnum
	ksObjectProcessParam          =10004      # from enum KompasAPIObjectTypeEnum
	ksObjectProgressBarIndicator  =10100      # from enum KompasAPIObjectTypeEnum
	ksObjectProjectionCurve       =11157      # from enum KompasAPIObjectTypeEnum
	ksObjectProjectionCurves      =11158      # from enum KompasAPIObjectTypeEnum
	ksObjectProperty              =10508      # from enum KompasAPIObjectTypeEnum
	ksObjectPropertyAggregateControl=10121      # from enum KompasAPIObjectTypeEnum
	ksObjectPropertyBasePoint     =10125      # from enum KompasAPIObjectTypeEnum
	ksObjectPropertyBmpList       =10014      # from enum KompasAPIObjectTypeEnum
	ksObjectPropertyCheckBox      =10011      # from enum KompasAPIObjectTypeEnum
	ksObjectPropertyColor         =10095      # from enum KompasAPIObjectTypeEnum
	ksObjectPropertyControls      =10007      # from enum KompasAPIObjectTypeEnum
	ksObjectPropertyEdit          =10009      # from enum KompasAPIObjectTypeEnum
	ksObjectPropertyEditCheckBox  =10113      # from enum KompasAPIObjectTypeEnum
	ksObjectPropertyEditList      =10101      # from enum KompasAPIObjectTypeEnum
	ksObjectPropertyFileName      =10094      # from enum KompasAPIObjectTypeEnum
	ksObjectPropertyGrid          =10017      # from enum KompasAPIObjectTypeEnum
	ksObjectPropertyGroupBegin    =10116      # from enum KompasAPIObjectTypeEnum
	ksObjectPropertyGroupEnd      =10117      # from enum KompasAPIObjectTypeEnum
	ksObjectPropertyKeeper        =10514      # from enum KompasAPIObjectTypeEnum
	ksObjectPropertyLibExplorer   =10102      # from enum KompasAPIObjectTypeEnum
	ksObjectPropertyLinkButton    =10122      # from enum KompasAPIObjectTypeEnum
	ksObjectPropertyList          =10010      # from enum KompasAPIObjectTypeEnum
	ksObjectPropertyManager       =10020      # from enum KompasAPIObjectTypeEnum
	ksObjectPropertyMarking       =10123      # from enum KompasAPIObjectTypeEnum
	ksObjectPropertyMng           =10509      # from enum KompasAPIObjectTypeEnum
	ksObjectPropertyMultiButton   =10012      # from enum KompasAPIObjectTypeEnum
	ksObjectPropertyOpticalProps  =10112      # from enum KompasAPIObjectTypeEnum
	ksObjectPropertyPoint3D       =10714      # from enum KompasAPIObjectTypeEnum
	ksObjectPropertyPreviewText   =10120      # from enum KompasAPIObjectTypeEnum
	ksObjectPropertyReplaceList   =10129      # from enum KompasAPIObjectTypeEnum
	ksObjectPropertySeparator     =10008      # from enum KompasAPIObjectTypeEnum
	ksObjectPropertySlideBox      =10016      # from enum KompasAPIObjectTypeEnum
	ksObjectPropertySpinEdit      =10028      # from enum KompasAPIObjectTypeEnum
	ksObjectPropertyStyleList     =10109      # from enum KompasAPIObjectTypeEnum
	ksObjectPropertyTab           =10006      # from enum KompasAPIObjectTypeEnum
	ksObjectPropertyTabs          =10005      # from enum KompasAPIObjectTypeEnum
	ksObjectPropertyTextButton    =10027      # from enum KompasAPIObjectTypeEnum
	ksObjectPropertyTwinSwitcher  =10713      # from enum KompasAPIObjectTypeEnum
	ksObjectPropertyUserControl   =10013      # from enum KompasAPIObjectTypeEnum
	ksObjectRadialDimension       =13028      # from enum KompasAPIObjectTypeEnum
	ksObjectRadialDimension3D     =11033      # from enum KompasAPIObjectTypeEnum
	ksObjectRadialDimensions      =13031      # from enum KompasAPIObjectTypeEnum
	ksObjectRadialDimensions3D    =11035      # from enum KompasAPIObjectTypeEnum
	ksObjectRadialUnhistoriedDimension=11221      # from enum KompasAPIObjectTypeEnum
	ksObjectRaster                =13089      # from enum KompasAPIObjectTypeEnum
	ksObjectRasters               =13088      # from enum KompasAPIObjectTypeEnum
	ksObjectRectangle             =13097      # from enum KompasAPIObjectTypeEnum
	ksObjectRectangles            =13096      # from enum KompasAPIObjectTypeEnum
	ksObjectRegularPolygon        =13099      # from enum KompasAPIObjectTypeEnum
	ksObjectRegularPolygons       =13098      # from enum KompasAPIObjectTypeEnum
	ksObjectRemoteElement         =13109      # from enum KompasAPIObjectTypeEnum
	ksObjectRemoteElements        =13108      # from enum KompasAPIObjectTypeEnum
	ksObjectReport                =10511      # from enum KompasAPIObjectTypeEnum
	ksObjectReportProcess         =10510      # from enum KompasAPIObjectTypeEnum
	ksObjectReportStyle           =10512      # from enum KompasAPIObjectTypeEnum
	ksObjectReportStyleColumn     =10513      # from enum KompasAPIObjectTypeEnum
	ksObjectRestoredSurface       =11343      # from enum KompasAPIObjectTypeEnum
	ksObjectRestoredSurfaces      =11342      # from enum KompasAPIObjectTypeEnum
	ksObjectRib                   =11263      # from enum KompasAPIObjectTypeEnum
	ksObjectRibs                  =11262      # from enum KompasAPIObjectTypeEnum
	ksObjectRotated               =11128      # from enum KompasAPIObjectTypeEnum
	ksObjectRotatedSurface        =11133      # from enum KompasAPIObjectTypeEnum
	ksObjectRotatedSurfaces       =11132      # from enum KompasAPIObjectTypeEnum
	ksObjectRotateds              =11127      # from enum KompasAPIObjectTypeEnum
	ksObjectRough                 =13054      # from enum KompasAPIObjectTypeEnum
	ksObjectRough3D               =11052      # from enum KompasAPIObjectTypeEnum
	ksObjectRoughs                =13055      # from enum KompasAPIObjectTypeEnum
	ksObjectRoughs3D              =11053      # from enum KompasAPIObjectTypeEnum
	ksObjectRuledSurface          =11097      # from enum KompasAPIObjectTypeEnum
	ksObjectRuledSurfaces         =11096      # from enum KompasAPIObjectTypeEnum
	ksObjectSaveAsDetailParam     =13172      # from enum KompasAPIObjectTypeEnum
	ksObjectScaling3D             =11146      # from enum KompasAPIObjectTypeEnum
	ksObjectScalings3D            =11145      # from enum KompasAPIObjectTypeEnum
	ksObjectSelectionManager      =10106      # from enum KompasAPIObjectTypeEnum
	ksObjectSheetFormat           =10077      # from enum KompasAPIObjectTypeEnum
	ksObjectSheetMetalBend        =11022      # from enum KompasAPIObjectTypeEnum
	ksObjectSheetMetalBendedStraighten=11311      # from enum KompasAPIObjectTypeEnum
	ksObjectSheetMetalBendedStraightens=11310      # from enum KompasAPIObjectTypeEnum
	ksObjectSheetMetalBends       =11023      # from enum KompasAPIObjectTypeEnum
	ksObjectSheetMetalBodies      =11011      # from enum KompasAPIObjectTypeEnum
	ksObjectSheetMetalBody        =11012      # from enum KompasAPIObjectTypeEnum
	ksObjectSheetMetalClosedCorner=11305      # from enum KompasAPIObjectTypeEnum
	ksObjectSheetMetalClosedCorners=11304      # from enum KompasAPIObjectTypeEnum
	ksObjectSheetMetalCut         =11028      # from enum KompasAPIObjectTypeEnum
	ksObjectSheetMetalCuts        =11029      # from enum KompasAPIObjectTypeEnum
	ksObjectSheetMetalFlanging    =11351      # from enum KompasAPIObjectTypeEnum
	ksObjectSheetMetalFlangings   =11352      # from enum KompasAPIObjectTypeEnum
	ksObjectSheetMetalHole        =11026      # from enum KompasAPIObjectTypeEnum
	ksObjectSheetMetalHoles       =11027      # from enum KompasAPIObjectTypeEnum
	ksObjectSheetMetalJalousie    =11317      # from enum KompasAPIObjectTypeEnum
	ksObjectSheetMetalJalousies   =11316      # from enum KompasAPIObjectTypeEnum
	ksObjectSheetMetalLineBend    =11024      # from enum KompasAPIObjectTypeEnum
	ksObjectSheetMetalLineBends   =11025      # from enum KompasAPIObjectTypeEnum
	ksObjectSheetMetalLinearRuledShell=11323      # from enum KompasAPIObjectTypeEnum
	ksObjectSheetMetalLinearRuledShells=11322      # from enum KompasAPIObjectTypeEnum
	ksObjectSheetMetalPlate       =11307      # from enum KompasAPIObjectTypeEnum
	ksObjectSheetMetalPlates      =11306      # from enum KompasAPIObjectTypeEnum
	ksObjectSheetMetalPressForming=11313      # from enum KompasAPIObjectTypeEnum
	ksObjectSheetMetalPressFormings=11312      # from enum KompasAPIObjectTypeEnum
	ksObjectSheetMetalPunch       =11349      # from enum KompasAPIObjectTypeEnum
	ksObjectSheetMetalPunchs      =11350      # from enum KompasAPIObjectTypeEnum
	ksObjectSheetMetalRib         =11319      # from enum KompasAPIObjectTypeEnum
	ksObjectSheetMetalRibs        =11318      # from enum KompasAPIObjectTypeEnum
	ksObjectSheetMetalRuledShell  =11321      # from enum KompasAPIObjectTypeEnum
	ksObjectSheetMetalRuledShells =11320      # from enum KompasAPIObjectTypeEnum
	ksObjectSheetMetalShoulder    =11315      # from enum KompasAPIObjectTypeEnum
	ksObjectSheetMetalShoulders   =11314      # from enum KompasAPIObjectTypeEnum
	ksObjectSheetMetalSketchBend  =11303      # from enum KompasAPIObjectTypeEnum
	ksObjectSheetMetalSketchBends =11302      # from enum KompasAPIObjectTypeEnum
	ksObjectSheetMetalUndercut    =11309      # from enum KompasAPIObjectTypeEnum
	ksObjectSheetMetalUndercuts   =11308      # from enum KompasAPIObjectTypeEnum
	ksObjectShell                 =11265      # from enum KompasAPIObjectTypeEnum
	ksObjectShellMirrorPattern    =11094      # from enum KompasAPIObjectTypeEnum
	ksObjectShells                =11264      # from enum KompasAPIObjectTypeEnum
	ksObjectSketch                =11006      # from enum KompasAPIObjectTypeEnum
	ksObjectSketchAngularDimension=11174      # from enum KompasAPIObjectTypeEnum
	ksObjectSketchBreakAngularDimension=11175      # from enum KompasAPIObjectTypeEnum
	ksObjectSketchBreakLinearDimension=11231      # from enum KompasAPIObjectTypeEnum
	ksObjectSketchBreakRadialDimension=11177      # from enum KompasAPIObjectTypeEnum
	ksObjectSketchDiametralDimension=11178      # from enum KompasAPIObjectTypeEnum
	ksObjectSketchLinearDimension =11173      # from enum KompasAPIObjectTypeEnum
	ksObjectSketchRadialDimension =11176      # from enum KompasAPIObjectTypeEnum
	ksObjectSketchs               =11005      # from enum KompasAPIObjectTypeEnum
	ksObjectSnapInfo              =10712      # from enum KompasAPIObjectTypeEnum
	ksObjectSpecRough             =13120      # from enum KompasAPIObjectTypeEnum
	ksObjectSpecRough3D           =11230      # from enum KompasAPIObjectTypeEnum
	ksObjectSpecificationBaseObject=10086      # from enum KompasAPIObjectTypeEnum
	ksObjectSpecificationBaseObjects=10083      # from enum KompasAPIObjectTypeEnum
	ksObjectSpecificationColumn   =10089      # from enum KompasAPIObjectTypeEnum
	ksObjectSpecificationColumnItem=10091      # from enum KompasAPIObjectTypeEnum
	ksObjectSpecificationColumnItems=10090      # from enum KompasAPIObjectTypeEnum
	ksObjectSpecificationColumnStyle=10063      # from enum KompasAPIObjectTypeEnum
	ksObjectSpecificationColumnStyles=10062      # from enum KompasAPIObjectTypeEnum
	ksObjectSpecificationColumns  =10088      # from enum KompasAPIObjectTypeEnum
	ksObjectSpecificationCommentObject=10087      # from enum KompasAPIObjectTypeEnum
	ksObjectSpecificationCommentObjects=10084      # from enum KompasAPIObjectTypeEnum
	ksObjectSpecificationDescription=10060      # from enum KompasAPIObjectTypeEnum
	ksObjectSpecificationDescriptions=10059      # from enum KompasAPIObjectTypeEnum
	ksObjectSpecificationDocument =10023      # from enum KompasAPIObjectTypeEnum
	ksObjectSpecificationObject   =10085      # from enum KompasAPIObjectTypeEnum
	ksObjectSpecificationSectionStyle=10065      # from enum KompasAPIObjectTypeEnum
	ksObjectSpecificationSectionStyles=10064      # from enum KompasAPIObjectTypeEnum
	ksObjectSpecificationStyle    =10061      # from enum KompasAPIObjectTypeEnum
	ksObjectSpecificationStyles   =10522      # from enum KompasAPIObjectTypeEnum
	ksObjectSpecificationSubsection=10070      # from enum KompasAPIObjectTypeEnum
	ksObjectSpecificationSubsections=10069      # from enum KompasAPIObjectTypeEnum
	ksObjectSpecificationTuning   =10066      # from enum KompasAPIObjectTypeEnum
	ksObjectSpecificationTuningSection=10068      # from enum KompasAPIObjectTypeEnum
	ksObjectSpecificationTuningSections=10067      # from enum KompasAPIObjectTypeEnum
	ksObjectSpirals3D             =11181      # from enum KompasAPIObjectTypeEnum
	ksObjectSpline3D              =11044      # from enum KompasAPIObjectTypeEnum
	ksObjectSplineOnSurface       =11155      # from enum KompasAPIObjectTypeEnum
	ksObjectSplines3D             =11045      # from enum KompasAPIObjectTypeEnum
	ksObjectSplinesOnSurfaces     =11156      # from enum KompasAPIObjectTypeEnum
	ksObjectSplitLine             =11065      # from enum KompasAPIObjectTypeEnum
	ksObjectSplitLines            =11064      # from enum KompasAPIObjectTypeEnum
	ksObjectSplitSolid            =11355      # from enum KompasAPIObjectTypeEnum
	ksObjectSplitSolids           =11356      # from enum KompasAPIObjectTypeEnum
	ksObjectSpotfacingHoleParameters=11253      # from enum KompasAPIObjectTypeEnum
	ksObjectStamp                 =10108      # from enum KompasAPIObjectTypeEnum
	ksObjectStraightAxis          =13003      # from enum KompasAPIObjectTypeEnum
	ksObjectStyle                 =10519      # from enum KompasAPIObjectTypeEnum
	ksObjectStyles                =10515      # from enum KompasAPIObjectTypeEnum
	ksObjectSurfacePatch          =11067      # from enum KompasAPIObjectTypeEnum
	ksObjectSurfacePatches        =11066      # from enum KompasAPIObjectTypeEnum
	ksObjectSurfaceSewer          =11071      # from enum KompasAPIObjectTypeEnum
	ksObjectSurfaceSewers         =11070      # from enum KompasAPIObjectTypeEnum
	ksObjectSurfaceThickening     =11118      # from enum KompasAPIObjectTypeEnum
	ksObjectSurfaceThickenings    =11117      # from enum KompasAPIObjectTypeEnum
	ksObjectSurfacesIntersectionCurve=11075      # from enum KompasAPIObjectTypeEnum
	ksObjectSurfacesIntersectionCurves=11074      # from enum KompasAPIObjectTypeEnum
	ksObjectSystemSettings        =10044      # from enum KompasAPIObjectTypeEnum
	ksObjectTableCell             =10703      # from enum KompasAPIObjectTypeEnum
	ksObjectTablePattern          =11123      # from enum KompasAPIObjectTypeEnum
	ksObjectTablePatternAnyCopy   =11218      # from enum KompasAPIObjectTypeEnum
	ksObjectTabulator             =10081      # from enum KompasAPIObjectTypeEnum
	ksObjectTabulators            =10080      # from enum KompasAPIObjectTypeEnum
	ksObjectTechnicalDemand       =13121      # from enum KompasAPIObjectTypeEnum
	ksObjectTechnicalDemand3D     =11167      # from enum KompasAPIObjectTypeEnum
	ksObjectText                  =10700      # from enum KompasAPIObjectTypeEnum
	ksObjectTextDocument          =10026      # from enum KompasAPIObjectTypeEnum
	ksObjectTextDocumentSection   =10126      # from enum KompasAPIObjectTypeEnum
	ksObjectTextItem              =10702      # from enum KompasAPIObjectTypeEnum
	ksObjectTextLine              =10701      # from enum KompasAPIObjectTypeEnum
	ksObjectTextStyle             =10078      # from enum KompasAPIObjectTypeEnum
	ksObjectTextTable             =10711      # from enum KompasAPIObjectTypeEnum
	ksObjectTextsStyles           =10518      # from enum KompasAPIObjectTypeEnum
	ksObjectThread                =11242      # from enum KompasAPIObjectTypeEnum
	ksObjectThreadDialogParam     =10119      # from enum KompasAPIObjectTypeEnum
	ksObjectThreadPattern         =10118      # from enum KompasAPIObjectTypeEnum
	ksObjectThreads               =11241      # from enum KompasAPIObjectTypeEnum
	ksObjectTolerance             =13064      # from enum KompasAPIObjectTypeEnum
	ksObjectTolerance3D           =11059      # from enum KompasAPIObjectTypeEnum
	ksObjectToleranceRecalc       =11229      # from enum KompasAPIObjectTypeEnum
	ksObjectTolerances            =13065      # from enum KompasAPIObjectTypeEnum
	ksObjectTolerances3D          =11058      # from enum KompasAPIObjectTypeEnum
	ksObjectTrimmedCurve          =11079      # from enum KompasAPIObjectTypeEnum
	ksObjectTrimmedCurves         =11078      # from enum KompasAPIObjectTypeEnum
	ksObjectTrimmedSurface        =11103      # from enum KompasAPIObjectTypeEnum
	ksObjectTrimmedSurfaces       =11102      # from enum KompasAPIObjectTypeEnum
	ksObjectUnhistoredCurve3D     =11165      # from enum KompasAPIObjectTypeEnum
	ksObjectUnhistoredCurves3D    =11166      # from enum KompasAPIObjectTypeEnum
	ksObjectUnionComponents       =11285      # from enum KompasAPIObjectTypeEnum
	ksObjectUnionsComponents      =11284      # from enum KompasAPIObjectTypeEnum
	ksObjectUnitMarking           =13016      # from enum KompasAPIObjectTypeEnum
	ksObjectUnitMarkings          =13017      # from enum KompasAPIObjectTypeEnum
	ksObjectUnitNumber            =13018      # from enum KompasAPIObjectTypeEnum
	ksObjectUnitNumbers           =13019      # from enum KompasAPIObjectTypeEnum
	ksObjectUnknown               =0          # from enum KompasAPIObjectTypeEnum
	ksObjectUserDataStorage       =10502      # from enum KompasAPIObjectTypeEnum
	ksObjectUserDataStorages      =10501      # from enum KompasAPIObjectTypeEnum
	ksObjectUserDataStoragesMng   =10500      # from enum KompasAPIObjectTypeEnum
	ksObjectUserDesignationCompObj=13155      # from enum KompasAPIObjectTypeEnum
	ksObjectUserFolder            =13156      # from enum KompasAPIObjectTypeEnum
	ksObjectUserFolders           =13157      # from enum KompasAPIObjectTypeEnum
	ksObjectUserObject3D          =11211      # from enum KompasAPIObjectTypeEnum
	ksObjectUserObjects3D         =11212      # from enum KompasAPIObjectTypeEnum
	ksObjectUserWireFrame3D       =11240      # from enum KompasAPIObjectTypeEnum
	ksObjectVariable7             =10103      # from enum KompasAPIObjectTypeEnum
	ksObjectVariableTable         =11004      # from enum KompasAPIObjectTypeEnum
	ksObjectVector3D              =11104      # from enum KompasAPIObjectTypeEnum
	ksObjectVector3DAlongSurfaceNormalParameters=11109      # from enum KompasAPIObjectTypeEnum
	ksObjectVector3DBy2AnglesParameters=11107      # from enum KompasAPIObjectTypeEnum
	ksObjectVector3DBy2VertexesParameters=11105      # from enum KompasAPIObjectTypeEnum
	ksObjectVector3DByCoefficientsParameters=11106      # from enum KompasAPIObjectTypeEnum
	ksObjectVector3DByCurveParameters=11110      # from enum KompasAPIObjectTypeEnum
	ksObjectVector3DByLocalCSParameters=11112      # from enum KompasAPIObjectTypeEnum
	ksObjectVector3DByObjectParameters=11108      # from enum KompasAPIObjectTypeEnum
	ksObjectVector3DByScreenNormalParameters=11111      # from enum KompasAPIObjectTypeEnum
	ksObjectVertex                =11279      # from enum KompasAPIObjectTypeEnum
	ksObjectView                  =10031      # from enum KompasAPIObjectTypeEnum
	ksObjectViewPointer           =13068      # from enum KompasAPIObjectTypeEnum
	ksObjectViewPointers          =13069      # from enum KompasAPIObjectTypeEnum
	ksObjectViews                 =10030      # from enum KompasAPIObjectTypeEnum
	ksObjectViewsAndLayersManager =10029      # from enum KompasAPIObjectTypeEnum
	ksObjectWaveLine              =13134      # from enum KompasAPIObjectTypeEnum
	ksObjectWaveLines             =13133      # from enum KompasAPIObjectTypeEnum
	ksObjectWireFrame3D           =11345      # from enum KompasAPIObjectTypeEnum
	ksObjectWireFrames3D          =11344      # from enum KompasAPIObjectTypeEnum
	ksObjectZone                  =11327      # from enum KompasAPIObjectTypeEnum
	ksObjectZoneDivision          =11331      # from enum KompasAPIObjectTypeEnum
	ksObjectZoneDivisionParametersByPlanes=11332      # from enum KompasAPIObjectTypeEnum
	ksObjectZoneDivisionParametersRegular=11333      # from enum KompasAPIObjectTypeEnum
	ksObjectZoneParametersByBorderPoints=11330      # from enum KompasAPIObjectTypeEnum
	ksObjectZoneParametersByObjects=11329      # from enum KompasAPIObjectTypeEnum
	ksObjectZonesManager          =11328      # from enum KompasAPIObjectTypeEnum
	ksSpecificationObjectCreateParam=10128      # from enum KompasAPIObjectTypeEnum
	wgLayers                      =0          # from enum LayersGroupWayEnum
	wgLayersCharacteristics       =1          # from enum LayersGroupWayEnum
	vtUnknown                     =-1         # from enum LtViewType
	vt_Arbitrary                  =2          # from enum LtViewType
	vt_Arrow                      =5          # from enum LtViewType
	vt_Normal                     =1          # from enum LtViewType
	vt_Projected                  =4          # from enum LtViewType
	vt_Remote                     =6          # from enum LtViewType
	vt_Remote2D                   =100        # from enum LtViewType
	vt_Section                    =7          # from enum LtViewType
	vt_Standart                   =3          # from enum LtViewType
	vt_System                     =0          # from enum LtViewType
	pr2ObjectsLineDim             =10059      # from enum ProcessTypeEnum
	prAddAssembly                 =20059      # from enum ProcessTypeEnum
	prAddBilletPartFromFile       =20189      # from enum ProcessTypeEnum
	prAddDetail                   =20058      # from enum ProcessTypeEnum
	prAddLayoutGeometryFromFile   =20188      # from enum ProcessTypeEnum
	prAddLocalPartFromFile        =20187      # from enum ProcessTypeEnum
	prAddPartFromFile             =20071      # from enum ProcessTypeEnum
	prAlignShelfs                 =36075      # from enum ProcessTypeEnum
	prAllIntersectPoint           =10003      # from enum ProcessTypeEnum
	prAngleDimension              =10061      # from enum ProcessTypeEnum
	prAngleDimention3D            =20107      # from enum ProcessTypeEnum
	prArc2Points                  =10034      # from enum ProcessTypeEnum
	prArc2PointsAngle             =10033      # from enum ProcessTypeEnum
	prArc3D                       =20123      # from enum ProcessTypeEnum
	prArc3Points                  =10032      # from enum ProcessTypeEnum
	prArcAxis                     =10187      # from enum ProcessTypeEnum
	prArcDimension                =10069      # from enum ProcessTypeEnum
	prArcDimension3D              =20222      # from enum ProcessTypeEnum
	prArcTangent                  =10035      # from enum ProcessTypeEnum
	prArrayParamReport            =10214      # from enum ProcessTypeEnum
	prArrayPintsOnSyrface         =20150      # from enum ProcessTypeEnum
	prArrayPointsByCloud          =20138      # from enum ProcessTypeEnum
	prArrayPointsFromFile         =20136      # from enum ProcessTypeEnum
	prArrayPointsOnCurve          =20137      # from enum ProcessTypeEnum
	prAssemblyContour             =10086      # from enum ProcessTypeEnum
	prAssemblyEquid               =10054      # from enum ProcessTypeEnum
	prAutoDimA                    =10179      # from enum ProcessTypeEnum
	prAutoDimABreak               =10184      # from enum ProcessTypeEnum
	prAutoDimD                    =10180      # from enum ProcessTypeEnum
	prAutoDimL                    =10178      # from enum ProcessTypeEnum
	prAutoDimLBreak               =10183      # from enum ProcessTypeEnum
	prAutoDimLToPoint             =10182      # from enum ProcessTypeEnum
	prAutoDimR                    =10181      # from enum ProcessTypeEnum
	prAuxObjectMultiplyByCurve    =20142      # from enum ProcessTypeEnum
	prAuxObjectMultiplyByMesh     =20140      # from enum ProcessTypeEnum
	prAuxObjectMultiplyByRing     =20141      # from enum ProcessTypeEnum
	prAuxObjectMultiplyMirror     =20151      # from enum ProcessTypeEnum
	prAuxPointDrivenPattern       =20164      # from enum ProcessTypeEnum
	prAuxTablePattern             =20162      # from enum ProcessTypeEnum
	prAxedLineSegment             =10084      # from enum ProcessTypeEnum
	prAxis3D                      =20216      # from enum ProcessTypeEnum
	prAxisByDirection             =20145      # from enum ProcessTypeEnum
	prBase                        =10080      # from enum ProcessTypeEnum
	prBase3D                      =20113      # from enum ProcessTypeEnum
	prBaseEvolution               =20008      # from enum ProcessTypeEnum
	prBaseExtrusion               =20000      # from enum ProcessTypeEnum
	prBaseLoft                    =20012      # from enum ProcessTypeEnum
	prBaseRotated                 =20004      # from enum ProcessTypeEnum
	prBaseShMtPlate               =20089      # from enum ProcessTypeEnum
	prBaseShMtSolid               =20082      # from enum ProcessTypeEnum
	prBezier                      =10045      # from enum ProcessTypeEnum
	prBindingMesh                 =20176      # from enum ProcessTypeEnum
	prBisectorLine                =10023      # from enum ProcessTypeEnum
	prBlackBox                    =10141      # from enum ProcessTypeEnum
	prBlendSurface                =20178      # from enum ProcessTypeEnum
	prBodiesCircularPattern       =20166      # from enum ProcessTypeEnum
	prBodiesCurvePattern          =20167      # from enum ProcessTypeEnum
	prBodiesLinearPattern         =20165      # from enum ProcessTypeEnum
	prBodiesPointDrivenPattern    =20168      # from enum ProcessTypeEnum
	prBodiesTablePattern          =20169      # from enum ProcessTypeEnum
	prBodyReposition              =20173      # from enum ProcessTypeEnum
	prBossEvolution               =20009      # from enum ProcessTypeEnum
	prBossExtrusion               =20001      # from enum ProcessTypeEnum
	prBossLoft                    =20013      # from enum ProcessTypeEnum
	prBossRotated                 =20005      # from enum ProcessTypeEnum
	prBrace                       =10177      # from enum ProcessTypeEnum
	prBrandLeader                 =10072      # from enum ProcessTypeEnum
	prBrandLeader3D               =20110      # from enum ProcessTypeEnum
	prBreakCurve                  =10139      # from enum ProcessTypeEnum
	prBreakCurveNParts            =10140      # from enum ProcessTypeEnum
	prBrokenLine                  =10199      # from enum ProcessTypeEnum
	prBuildingCutLine             =10198      # from enum ProcessTypeEnum
	prBuildingCutLineMultiple     =10219      # from enum ProcessTypeEnum
	prCAggregateOper              =20100      # from enum ProcessTypeEnum
	prCAxis2Planes                =20044      # from enum ProcessTypeEnum
	prCAxis2Points                =20043      # from enum ProcessTypeEnum
	prCAxisConeface               =20045      # from enum ProcessTypeEnum
	prCAxisEdge                   =20046      # from enum ProcessTypeEnum
	prCAxisOperation              =20047      # from enum ProcessTypeEnum
	prCPlane3Points               =20035      # from enum ProcessTypeEnum
	prCPlaneAngle                 =20036      # from enum ProcessTypeEnum
	prCPlaneAtCurve               =20149      # from enum ProcessTypeEnum
	prCPlaneEdgePoint             =20037      # from enum ProcessTypeEnum
	prCPlaneLineToEdge            =20042      # from enum ProcessTypeEnum
	prCPlaneLineToFlat            =20101      # from enum ProcessTypeEnum
	prCPlaneMiddle                =20097      # from enum ProcessTypeEnum
	prCPlaneNormalToSurface       =20040      # from enum ProcessTypeEnum
	prCPlaneOffset                =20034      # from enum ProcessTypeEnum
	prCPlaneParallel              =20038      # from enum ProcessTypeEnum
	prCPlanePerpendicular         =20039      # from enum ProcessTypeEnum
	prCPlaneTangentAtPoint        =20148      # from enum ProcessTypeEnum
	prCPlaneTangentToSurface      =20041      # from enum ProcessTypeEnum
	prCPointConjunctive           =20099      # from enum ProcessTypeEnum
	prCPointControl               =20098      # from enum ProcessTypeEnum
	prCentreMarker                =10085      # from enum ProcessTypeEnum
	prChainAngleDim               =10063      # from enum ProcessTypeEnum
	prChainLineDim                =10057      # from enum ProcessTypeEnum
	prChamfer                     =10103      # from enum ProcessTypeEnum
	prChamfer3D                   =20017      # from enum ProcessTypeEnum
	prChamferPolyContour          =10104      # from enum ProcessTypeEnum
	prChangeLeader                =10075      # from enum ProcessTypeEnum
	prChoiceBodyUnit              =20120      # from enum ProcessTypeEnum
	prChoiceOperationResult       =20119      # from enum ProcessTypeEnum
	prChooseCircularPattern       =20156      # from enum ProcessTypeEnum
	prChooseCurvePattern          =20157      # from enum ProcessTypeEnum
	prChooseLinearPattern         =20155      # from enum ProcessTypeEnum
	prChooseMirrorPattern         =20160      # from enum ProcessTypeEnum
	prChoosePointDrivenPattern    =20158      # from enum ProcessTypeEnum
	prChooseTablePattern          =20159      # from enum ProcessTypeEnum
	prCircle                      =10024      # from enum ProcessTypeEnum
	prCircle2Points               =10030      # from enum ProcessTypeEnum
	prCircle3Points               =10025      # from enum ProcessTypeEnum
	prCircleArc                   =10031      # from enum ProcessTypeEnum
	prCircleAxis                  =10188      # from enum ProcessTypeEnum
	prCircleCentreOnEl            =10026      # from enum ProcessTypeEnum
	prCircleTangent               =10027      # from enum ProcessTypeEnum
	prCircleTangent2              =10028      # from enum ProcessTypeEnum
	prCircleTangent3              =10029      # from enum ProcessTypeEnum
	prCircularCentres             =10220      # from enum ProcessTypeEnum
	prCircularCopy                =20021      # from enum ProcessTypeEnum
	prCircularPartArray           =20027      # from enum ProcessTypeEnum
	prColouring                   =10196      # from enum ProcessTypeEnum
	prCommonBaseAngleDim          =10062      # from enum ProcessTypeEnum
	prCommonBaseLineDim           =10056      # from enum ProcessTypeEnum
	prCommonLineAngleDim          =10064      # from enum ProcessTypeEnum
	prCommonLineLineDim           =10058      # from enum ProcessTypeEnum
	prConicCurve                  =10215      # from enum ProcessTypeEnum
	prConicCurve4Or5Point         =10216      # from enum ProcessTypeEnum
	prConicSectionSurface         =20229      # from enum ProcessTypeEnum
	prConicSpiral                 =20051      # from enum ProcessTypeEnum
	prConnectCurve                =20124      # from enum ProcessTypeEnum
	prContinuityCheck             =20220      # from enum ProcessTypeEnum
	prContour                     =10102      # from enum ProcessTypeEnum
	prContour3D                   =20170      # from enum ProcessTypeEnum
	prContourArc                  =10036      # from enum ProcessTypeEnum
	prContourBezier               =10046      # from enum ProcessTypeEnum
	prContourConArc               =10037      # from enum ProcessTypeEnum
	prContourLineSeg              =10011      # from enum ProcessTypeEnum
	prContourNurbs                =10049      # from enum ProcessTypeEnum
	prContourParallelLineSeg      =10012      # from enum ProcessTypeEnum
	prContourPerpendLineSeg       =10013      # from enum ProcessTypeEnum
	prContourTanLineSegByOutsidePnt=10014      # from enum ProcessTypeEnum
	prConvertToNurbs              =10142      # from enum ProcessTypeEnum
	prConvertToNurbsSurface3D     =20133      # from enum ProcessTypeEnum
	prCopyBilletPart              =20068      # from enum ProcessTypeEnum
	prCreateArbitrarySheetView    =10095      # from enum ProcessTypeEnum
	prCreateArrowSheetView        =10097      # from enum ProcessTypeEnum
	prCreateAttachedLeaders       =10201      # from enum ProcessTypeEnum
	prCreateBrokenSheetView       =10101      # from enum ProcessTypeEnum
	prCreateLocalSectionSheetView =10100      # from enum ProcessTypeEnum
	prCreateLocalSheetView        =10099      # from enum ProcessTypeEnum
	prCreateProjectionSheetView   =10096      # from enum ProcessTypeEnum
	prCreateRemoteSheetView       =10098      # from enum ProcessTypeEnum
	prCreateReport                =10200      # from enum ProcessTypeEnum
	prCreateSectionSheetView      =10094      # from enum ProcessTypeEnum
	prCreateSheetView             =10091      # from enum ProcessTypeEnum
	prCreateSketch                =20116      # from enum ProcessTypeEnum
	prCreateSpecificationFromAssembly=20183      # from enum ProcessTypeEnum
	prCreateSpecificationObjects  =20181      # from enum ProcessTypeEnum
	prCreateStandartSheetView     =10093      # from enum ProcessTypeEnum
	prCurvatureGraph              =20219      # from enum ProcessTypeEnum
	prCurveByLaw                  =20172      # from enum ProcessTypeEnum
	prCurveCopy                   =20022      # from enum ProcessTypeEnum
	prCurveOper2Projection        =20171      # from enum ProcessTypeEnum
	prCurveOperationCrossing      =20131      # from enum ProcessTypeEnum
	prCurvePartArray              =20028      # from enum ProcessTypeEnum
	prCutAngleDimension           =10065      # from enum ProcessTypeEnum
	prCutByPlane                  =20018      # from enum ProcessTypeEnum
	prCutBySketch                 =20019      # from enum ProcessTypeEnum
	prCutEvolution                =20010      # from enum ProcessTypeEnum
	prCutExtrusion                =20002      # from enum ProcessTypeEnum
	prCutLine                     =10081      # from enum ProcessTypeEnum
	prCutLineDimension            =10060      # from enum ProcessTypeEnum
	prCutLineMultiple             =10218      # from enum ProcessTypeEnum
	prCutLoft                     =20014      # from enum ProcessTypeEnum
	prCutObjectPart               =10135      # from enum ProcessTypeEnum
	prCutObjectPartBy2Points      =10136      # from enum ProcessTypeEnum
	prCutRotated                  =20006      # from enum ProcessTypeEnum
	prCutUnitMarking              =10194      # from enum ProcessTypeEnum
	prCylindricSpiral             =20050      # from enum ProcessTypeEnum
	prDeleteHistory               =10210      # from enum ProcessTypeEnum
	prDeleteSpecificationObjects  =20182      # from enum ProcessTypeEnum
	prDerivativePartArray         =20025      # from enum ProcessTypeEnum
	prDiametralDimension          =10068      # from enum ProcessTypeEnum
	prDirectAxis                  =10186      # from enum ProcessTypeEnum
	prEditCopy                    =57634      # from enum ProcessTypeEnum
	prEditCut                     =57635      # from enum ProcessTypeEnum
	prEditPaste                   =57637      # from enum ProcessTypeEnum
	prEditProperties              =10202      # from enum ProcessTypeEnum
	prEditScetch                  =20054      # from enum ProcessTypeEnum
	prEditSelectedObject          =35736      # from enum ProcessTypeEnum
	prEditSketch                  =20054      # from enum ProcessTypeEnum
	prEllipse                     =10038      # from enum ProcessTypeEnum
	prEllipseCentre3Points        =10041      # from enum ProcessTypeEnum
	prEllipseGabCentrePoint       =10044      # from enum ProcessTypeEnum
	prEllipseGabDiagonal          =10039      # from enum ProcessTypeEnum
	prEllipseParallel3Points      =10042      # from enum ProcessTypeEnum
	prEllipseParallelCentre2Points=10043      # from enum ProcessTypeEnum
	prEllipseTangent2             =10040      # from enum ProcessTypeEnum
	prEmbodiment                  =20180      # from enum ProcessTypeEnum
	prEmbodimentsReport           =10213      # from enum ProcessTypeEnum
	prEquidToObj                  =10053      # from enum ProcessTypeEnum
	prEquidistant3D               =20118      # from enum ProcessTypeEnum
	prEvolutionSurface            =20011      # from enum ProcessTypeEnum
	prExcludeLayer                =10170      # from enum ProcessTypeEnum
	prExcludeObject               =10169      # from enum ProcessTypeEnum
	prExcludeOutSideRect          =10173      # from enum ProcessTypeEnum
	prExcludeSheetView            =10171      # from enum ProcessTypeEnum
	prExcludeWithCutPolyline      =10175      # from enum ProcessTypeEnum
	prExcludeWithCutRect          =10174      # from enum ProcessTypeEnum
	prExcludeWithRect             =10172      # from enum ProcessTypeEnum
	prExtensionSurface            =20147      # from enum ProcessTypeEnum
	prExtrusionSurface            =20003      # from enum ProcessTypeEnum
	prFillet                      =10105      # from enum ProcessTypeEnum
	prFillet3D                    =20016      # from enum ProcessTypeEnum
	prFilletCurve                 =20126      # from enum ProcessTypeEnum
	prFilletPolyContour           =10106      # from enum ProcessTypeEnum
	prFormTolerance               =10087      # from enum ProcessTypeEnum
	prFullFillet                  =20217      # from enum ProcessTypeEnum
	prHatch                       =10076      # from enum ProcessTypeEnum
	prHole                        =20032      # from enum ProcessTypeEnum
	prHoleConic                   =20200      # from enum ProcessTypeEnum
	prHoleCounterbore             =20197      # from enum ProcessTypeEnum
	prHoleCounterdrill            =20199      # from enum ProcessTypeEnum
	prHoleCountersinking          =20198      # from enum ProcessTypeEnum
	prHoleSimple                  =20196      # from enum ProcessTypeEnum
	prHorizontalLine              =10017      # from enum ProcessTypeEnum
	prImportedSurface             =20052      # from enum ProcessTypeEnum
	prInPlacePartEdit             =20056      # from enum ProcessTypeEnum
	prIncline                     =20029      # from enum ProcessTypeEnum
	prInsertFragment              =10090      # from enum ProcessTypeEnum
	prInsertOLEObject             =10092      # from enum ProcessTypeEnum
	prInsertRaster                =10088      # from enum ProcessTypeEnum
	prInsertScetch                =20053      # from enum ProcessTypeEnum
	prInsertSketch                =20053      # from enum ProcessTypeEnum
	prIntersectPoint              =10002      # from enum ProcessTypeEnum
	prIsoparamCurve               =20174      # from enum ProcessTypeEnum
	prIsoparamCurveArr            =20175      # from enum ProcessTypeEnum
	prJustify                     =10137      # from enum ProcessTypeEnum
	prKnotNumber                  =10192      # from enum ProcessTypeEnum
	prLeader                      =10071      # from enum ProcessTypeEnum
	prLeader3D                    =20114      # from enum ProcessTypeEnum
	prLine                        =10015      # from enum ProcessTypeEnum
	prLineDimension               =10055      # from enum ProcessTypeEnum
	prLineDimention3D             =20106      # from enum ProcessTypeEnum
	prLineDimention3DPlane        =20105      # from enum ProcessTypeEnum
	prLineSeg                     =10005      # from enum ProcessTypeEnum
	prLineSegment3D               =20179      # from enum ProcessTypeEnum
	prLinearCentres               =10221      # from enum ProcessTypeEnum
	prLocalCoordinateSystem       =20104      # from enum ProcessTypeEnum
	prLoftSurface                 =20015      # from enum ProcessTypeEnum
	prMakeFaceMover               =20226      # from enum ProcessTypeEnum
	prMakeFaceRemover             =20096      # from enum ProcessTypeEnum
	prMakeMacro                   =10089      # from enum ProcessTypeEnum
	prMakeMoldCavity              =20069      # from enum ProcessTypeEnum
	prMakeSplitLine               =20076      # from enum ProcessTypeEnum
	prMakeUnionComps              =20070      # from enum ProcessTypeEnum
	prMarkLeader                  =10073      # from enum ProcessTypeEnum
	prMarkOnLDRPosNum             =10190      # from enum ProcessTypeEnum
	prMarkOnLeader                =10217      # from enum ProcessTypeEnum
	prMarkWoLDRPosNum             =10191      # from enum ProcessTypeEnum
	prMarkerLeader3D              =20111      # from enum ProcessTypeEnum
	prMateCamGear                 =20192      # from enum ProcessTypeEnum
	prMateCoincident              =20060      # from enum ProcessTypeEnum
	prMateConcentric              =20061      # from enum ProcessTypeEnum
	prMateDependent               =20191      # from enum ProcessTypeEnum
	prMateOnAngle                 =20065      # from enum ProcessTypeEnum
	prMateOnDistance              =20064      # from enum ProcessTypeEnum
	prMateParallel                =20062      # from enum ProcessTypeEnum
	prMatePerpendicular           =20063      # from enum ProcessTypeEnum
	prMateRotation                =20193      # from enum ProcessTypeEnum
	prMateRotationTransfer        =20194      # from enum ProcessTypeEnum
	prMateSymmetry                =20190      # from enum ProcessTypeEnum
	prMateTangent                 =20066      # from enum ProcessTypeEnum
	prMeasureAngle2Lines          =10115      # from enum ProcessTypeEnum
	prMeasureAngle3Points         =10116      # from enum ProcessTypeEnum
	prMeasureArea                 =10118      # from enum ProcessTypeEnum
	prMeasureArea3D               =20079      # from enum ProcessTypeEnum
	prMeasureDistance2Curves      =10114      # from enum ProcessTypeEnum
	prMeasureDistance2Points      =10111      # from enum ProcessTypeEnum
	prMeasureDistance2PointsByCurve=10112      # from enum ProcessTypeEnum
	prMeasureDistance3D           =20077      # from enum ProcessTypeEnum
	prMeasureDistancePointObject  =10113      # from enum ProcessTypeEnum
	prMeasureInformation          =20117      # from enum ProcessTypeEnum
	prMeasureInterferenceVolumes  =20081      # from enum ProcessTypeEnum
	prMeasureMix3D                =20080      # from enum ProcessTypeEnum
	prMeasurePerimeter3D          =20078      # from enum ProcessTypeEnum
	prMeasurePointProperties      =10110      # from enum ProcessTypeEnum
	prMeshCopy                    =20020      # from enum ProcessTypeEnum
	prMeshPartArray               =20026      # from enum ProcessTypeEnum
	prMirrorAllCopy               =20024      # from enum ProcessTypeEnum
	prMirrorCopy                  =20023      # from enum ProcessTypeEnum
	prMix                         =10119      # from enum ProcessTypeEnum
	prMix3DExtrision              =10121      # from enum ProcessTypeEnum
	prMix3DExtrusion              =10121      # from enum ProcessTypeEnum
	prMix3DRevolution             =10120      # from enum ProcessTypeEnum
	prMoveDeformation             =10132      # from enum ProcessTypeEnum
	prMovePart                    =20072      # from enum ProcessTypeEnum
	prMoveSpecRough               =10209      # from enum ProcessTypeEnum
	prMoveView                    =32418      # from enum ProcessTypeEnum
	prMultiLine                   =10197      # from enum ProcessTypeEnum
	prMultiTextLeader             =10195      # from enum ProcessTypeEnum
	prNurbs                       =10048      # from enum ProcessTypeEnum
	prNurbs3DByObjects            =20130      # from enum ProcessTypeEnum
	prNurbsSurface3DByCurves      =20135      # from enum ProcessTypeEnum
	prNurbsSurface3DByPoints      =20134      # from enum ProcessTypeEnum
	prObjectMultiply              =10127      # from enum ProcessTypeEnum
	prObjectMultiplyByCircle      =10129      # from enum ProcessTypeEnum
	prObjectMultiplyByCurve       =10128      # from enum ProcessTypeEnum
	prObjectMultiplyByMesh        =10131      # from enum ProcessTypeEnum
	prObjectMultiplyByRing        =10130      # from enum ProcessTypeEnum
	prObjectRotate                =10124      # from enum ProcessTypeEnum
	prObjectScale                 =10125      # from enum ProcessTypeEnum
	prObjectShift                 =10122      # from enum ProcessTypeEnum
	prObjectShiftAngleLen         =10123      # from enum ProcessTypeEnum
	prObjectSymmetry              =10126      # from enum ProcessTypeEnum
	prOffsetSurface               =20139      # from enum ProcessTypeEnum
	prOrdinateDimension           =10070      # from enum ProcessTypeEnum
	prOrientationScetch           =20055      # from enum ProcessTypeEnum
	prOutPlacePartEdit            =20057      # from enum ProcessTypeEnum
	prOutlineCurve                =20152      # from enum ProcessTypeEnum
	prPanoramaView                =32419      # from enum ProcessTypeEnum
	prParallelLine                =10019      # from enum ProcessTypeEnum
	prParallelLineSeg             =10006      # from enum ProcessTypeEnum
	prParametricBisector          =10203      # from enum ProcessTypeEnum
	prParametricChangeDimension   =10158      # from enum ProcessTypeEnum
	prParametricColinear          =10152      # from enum ProcessTypeEnum
	prParametricDeleteAllConstraints=10161      # from enum ProcessTypeEnum
	prParametricDeleteObjConstraints=10160      # from enum ProcessTypeEnum
	prParametricEqualLength       =10156      # from enum ProcessTypeEnum
	prParametricEqualRadiuses     =10155      # from enum ProcessTypeEnum
	prParametricFixDimension      =10157      # from enum ProcessTypeEnum
	prParametricFixPoint          =10154      # from enum ProcessTypeEnum
	prParametricFixedAngle        =10205      # from enum ProcessTypeEnum
	prParametricFixedLenght       =10204      # from enum ProcessTypeEnum
	prParametricHorizontal        =10143      # from enum ProcessTypeEnum
	prParametricMergePoints       =10147      # from enum ProcessTypeEnum
	prParametricNormal            =10151      # from enum ProcessTypeEnum
	prParametricParallel          =10150      # from enum ProcessTypeEnum
	prParametricPointOnCurve      =10148      # from enum ProcessTypeEnum
	prParametricPointOnCurveMiddle=10206      # from enum ProcessTypeEnum
	prParametricPointSymmetry     =10149      # from enum ProcessTypeEnum
	prParametricSelected          =10159      # from enum ProcessTypeEnum
	prParametricTangent           =10153      # from enum ProcessTypeEnum
	prParametricVertical          =10144      # from enum ProcessTypeEnum
	prParametricXAlign            =10145      # from enum ProcessTypeEnum
	prParametricYAlign            =10146      # from enum ProcessTypeEnum
	prPartVariables               =20067      # from enum ProcessTypeEnum
	prPartsPointDrivenPattern     =20154      # from enum ProcessTypeEnum
	prPartsTablePattern           =20163      # from enum ProcessTypeEnum
	prPatchSurface                =20094      # from enum ProcessTypeEnum
	prPerimeter                   =10117      # from enum ProcessTypeEnum
	prPerpendLine                 =10018      # from enum ProcessTypeEnum
	prPerpendLineSeg              =10007      # from enum ProcessTypeEnum
	prPoint                       =10000      # from enum ProcessTypeEnum
	prPoint3D                     =20103      # from enum ProcessTypeEnum
	prPoint3DCenter               =20206      # from enum ProcessTypeEnum
	prPoint3DCoord                =20201      # from enum ProcessTypeEnum
	prPoint3DCurve                =20204      # from enum ProcessTypeEnum
	prPoint3DCylindrCoord         =20208      # from enum ProcessTypeEnum
	prPoint3DDisplace             =20202      # from enum ProcessTypeEnum
	prPoint3DIntersect            =20203      # from enum ProcessTypeEnum
	prPoint3DProjection           =20207      # from enum ProcessTypeEnum
	prPoint3DSphericCoord         =20209      # from enum ProcessTypeEnum
	prPoint3DSurface              =20205      # from enum ProcessTypeEnum
	prPointAlong                  =10001      # from enum ProcessTypeEnum
	prPointDrivenPattern          =20129      # from enum ProcessTypeEnum
	prPointOnDistance             =10004      # from enum ProcessTypeEnum
	prPolygon                     =10052      # from enum ProcessTypeEnum
	prPolyline                    =10047      # from enum ProcessTypeEnum
	prPolyline3D                  =20048      # from enum ProcessTypeEnum
	prPositionLeader              =10074      # from enum ProcessTypeEnum
	prPositionLeader3D            =20112      # from enum ProcessTypeEnum
	prProjectionObject            =10107      # from enum ProcessTypeEnum
	prRadialDimension             =10066      # from enum ProcessTypeEnum
	prRadialDimensionWithBreak    =10067      # from enum ProcessTypeEnum
	prRectangle                   =10050      # from enum ProcessTypeEnum
	prRectangleCentrePoint        =10051      # from enum ProcessTypeEnum
	prRedo                        =10212      # from enum ProcessTypeEnum
	prRemoteElement               =10083      # from enum ProcessTypeEnum
	prRemoveChamfer               =10138      # from enum ProcessTypeEnum
	prRepositionPart              =20186      # from enum ProcessTypeEnum
	prRestoredSurface             =20218      # from enum ProcessTypeEnum
	prRib                         =20031      # from enum ProcessTypeEnum
	prRotateDeformation           =10133      # from enum ProcessTypeEnum
	prRotatePartAxis              =20074      # from enum ProcessTypeEnum
	prRotatePartPoint             =20075      # from enum ProcessTypeEnum
	prRotatePartWC                =20073      # from enum ProcessTypeEnum
	prRotateView                  =32420      # from enum ProcessTypeEnum
	prRotatedSurface              =20007      # from enum ProcessTypeEnum
	prRough                       =10079      # from enum ProcessTypeEnum
	prRough3D                     =20108      # from enum ProcessTypeEnum
	prRuledSurface                =20146      # from enum ProcessTypeEnum
	prSaveBody                    =20115      # from enum ProcessTypeEnum
	prSaveBodyAs                  =20177      # from enum ProcessTypeEnum
	prScaleDeformation            =10134      # from enum ProcessTypeEnum
	prScalingOperation            =20128      # from enum ProcessTypeEnum
	prSectionAnalysis             =20221      # from enum ProcessTypeEnum
	prSelectCurrentCS             =20121      # from enum ProcessTypeEnum
	prSelectLayer                 =10163      # from enum ProcessTypeEnum
	prSelectObject                =10162      # from enum ProcessTypeEnum
	prSelectOutSideRect           =10166      # from enum ProcessTypeEnum
	prSelectSheetView             =10164      # from enum ProcessTypeEnum
	prSelectWithCutPolyline       =10168      # from enum ProcessTypeEnum
	prSelectWithCutRect           =10167      # from enum ProcessTypeEnum
	prSelectWithRect              =10165      # from enum ProcessTypeEnum
	prSewSurface                  =20095      # from enum ProcessTypeEnum
	prShMtBend                    =20083      # from enum ProcessTypeEnum
	prShMtBendBended              =20092      # from enum ProcessTypeEnum
	prShMtBendHook                =20086      # from enum ProcessTypeEnum
	prShMtBendLine                =20085      # from enum ProcessTypeEnum
	prShMtBendObject              =20210      # from enum ProcessTypeEnum
	prShMtBendParamUnfold         =20093      # from enum ProcessTypeEnum
	prShMtBendStraighten          =20091      # from enum ProcessTypeEnum
	prShMtClocingPressForming     =20211      # from enum ProcessTypeEnum
	prShMtClosedCorner            =20090      # from enum ProcessTypeEnum
	prShMtCombinedBend            =20084      # from enum ProcessTypeEnum
	prShMtCut                     =20088      # from enum ProcessTypeEnum
	prShMtHole                    =20087      # from enum ProcessTypeEnum
	prShMtJalousie                =20214      # from enum ProcessTypeEnum
	prShMtOpeningPressForming     =20212      # from enum ProcessTypeEnum
	prShMtRib                     =20215      # from enum ProcessTypeEnum
	prShMtShoulder                =20213      # from enum ProcessTypeEnum
	prSheetMetalConvertFromBody   =20228      # from enum ProcessTypeEnum
	prSheetMetalFlanging          =20225      # from enum ProcessTypeEnum
	prSheetMetalPunch             =20224      # from enum ProcessTypeEnum
	prShell                       =20030      # from enum ProcessTypeEnum
	prShmtLinearRuledOperation    =20185      # from enum ProcessTypeEnum
	prShmtRuledOperation          =20122      # from enum ProcessTypeEnum
	prSketchArcDimension3D        =20223      # from enum ProcessTypeEnum
	prSmartAxedLineSegment        =10109      # from enum ProcessTypeEnum
	prSmartDimension              =10108      # from enum ProcessTypeEnum
	prSmartLine                   =10176      # from enum ProcessTypeEnum
	prSpecRough                   =10208      # from enum ProcessTypeEnum
	prSpecRough3D                 =20184      # from enum ProcessTypeEnum
	prSpline3D                    =20049      # from enum ProcessTypeEnum
	prSplineOnSurface             =20153      # from enum ProcessTypeEnum
	prSplitSolid                  =20227      # from enum ProcessTypeEnum
	prSurfaceToBody               =20144      # from enum ProcessTypeEnum
	prSwithOwnCS                  =20127      # from enum ProcessTypeEnum
	prTable                       =10078      # from enum ProcessTypeEnum
	prTablePattern                =20161      # from enum ProcessTypeEnum
	prTanLineByOutsidePnt         =10022      # from enum ProcessTypeEnum
	prTanLineByPntOn              =10021      # from enum ProcessTypeEnum
	prTanLineSegByOutsidePnt      =10008      # from enum ProcessTypeEnum
	prTanLineSegByPntOn           =10009      # from enum ProcessTypeEnum
	prTangent2Line                =10020      # from enum ProcessTypeEnum
	prTangent2LineSeg             =10010      # from enum ProcessTypeEnum
	prTechnicalDemand             =10207      # from enum ProcessTypeEnum
	prTechnicalDemand3D           =20195      # from enum ProcessTypeEnum
	prTechnicalDemandPlacement    =10185      # from enum ProcessTypeEnum
	prText                        =10077      # from enum ProcessTypeEnum
	prThread                      =20033      # from enum ProcessTypeEnum
	prTolerance3D                 =20109      # from enum ProcessTypeEnum
	prTrimCurve                   =20125      # from enum ProcessTypeEnum
	prTrimmedSurface              =20143      # from enum ProcessTypeEnum
	prUndo                        =10211      # from enum ProcessTypeEnum
	prUnitMarking                 =10193      # from enum ProcessTypeEnum
	prUnknown                     =0          # from enum ProcessTypeEnum
	prVerticalLine                =10016      # from enum ProcessTypeEnum
	prViewPointer                 =10082      # from enum ProcessTypeEnum
	prWaveLine                    =10189      # from enum ProcessTypeEnum
	prZoomWindow                  =32411      # from enum ProcessTypeEnum
	ksNameAlwaysVisible           =0          # from enum PropertyControlNameVisibility
	ksNameHorizontalVisible       =1          # from enum PropertyControlNameVisibility
	ksNameNoVisible               =3          # from enum PropertyControlNameVisibility
	ksNameVerticalVisible         =2          # from enum PropertyControlNameVisibility
	pmAlignBottom                 =2          # from enum PropertyManagerLayout
	pmAlignLeft                   =4          # from enum PropertyManagerLayout
	pmAlignLeftInGroup            =6          # from enum PropertyManagerLayout
	pmAlignRight                  =3          # from enum PropertyManagerLayout
	pmAlignRightInGroup           =5          # from enum PropertyManagerLayout
	pmAlignTop                    =1          # from enum PropertyManagerLayout
	pmFloating                    =0          # from enum PropertyManagerLayout
	ksSeparatorBMPLeftName        =3          # from enum SeparatorTypeEnum
	ksSeparatorBMPRightName       =4          # from enum SeparatorTypeEnum
	ksSeparatorDownName           =0          # from enum SeparatorTypeEnum
	ksSeparatorUpName             =1          # from enum SeparatorTypeEnum
	ksSeparatorWithoutLine        =2          # from enum SeparatorTypeEnum
	ksBitmap                      =1          # from enum SlideTypeEnum
	ksGroup                       =2          # from enum SlideTypeEnum
	ksKompasDocument              =3          # from enum SlideTypeEnum
	ksKompasText                  =4          # from enum SlideTypeEnum
	ksSlide                       =-1         # from enum SlideTypeEnum
	pbAutoCreate                  =3          # from enum SpecPropertyButtonEnum
	pbCopyProps                   =9          # from enum SpecPropertyButtonEnum
	pbEnter                       =1          # from enum SpecPropertyButtonEnum
	pbEsc                         =2          # from enum SpecPropertyButtonEnum
	pbHelp                        =8          # from enum SpecPropertyButtonEnum
	pbNewSearch                   =5          # from enum SpecPropertyButtonEnum
	pbNextObj                     =7          # from enum SpecPropertyButtonEnum
	pbPrevObj                     =6          # from enum SpecPropertyButtonEnum
	pbSaveState                   =4          # from enum SpecPropertyButtonEnum
	pnEmpty                       =1          # from enum SpecPropertyToolBarEnum
	pnEnterEscCreateHelp          =4          # from enum SpecPropertyToolBarEnum
	pnEnterEscCreateSaveHelp      =5          # from enum SpecPropertyToolBarEnum
	pnEnterEscCreateSaveSearchHelp=6          # from enum SpecPropertyToolBarEnum
	pnEnterEscCreateSearchHelp    =10         # from enum SpecPropertyToolBarEnum
	pnEnterEscHelp                =3          # from enum SpecPropertyToolBarEnum
	pnEnterEscSaveSearchHelp      =11         # from enum SpecPropertyToolBarEnum
	pnEnterEscSaveSearchPrevNextHelp=7          # from enum SpecPropertyToolBarEnum
	pnEnterEscSearchHelp          =8          # from enum SpecPropertyToolBarEnum
	pnEnterEscSearchPrevNextHelp  =13         # from enum SpecPropertyToolBarEnum
	pnEscHelp                     =2          # from enum SpecPropertyToolBarEnum
	pnEscSaveSearchHelp           =9          # from enum SpecPropertyToolBarEnum
	pnEscSaveStateHelp            =12         # from enum SpecPropertyToolBarEnum
	pnUnknown                     =0          # from enum SpecPropertyToolBarEnum
	ko_ABreakDimParam             =51         # from enum StructType2DEnum
	ko_ADimParam                  =50         # from enum StructType2DEnum
	ko_ADimSource                 =49         # from enum StructType2DEnum
	ko_ArcByAngleParam            =12         # from enum StructType2DEnum
	ko_ArcByPointParam            =13         # from enum StructType2DEnum
	ko_AssociationViewParam       =122        # from enum StructType2DEnum
	ko_Attribute                  =38         # from enum StructType2DEnum
	ko_AttributeType              =37         # from enum StructType2DEnum
	ko_AxisLineParam              =123        # from enum StructType2DEnum
	ko_BaseParam                  =64         # from enum StructType2DEnum
	ko_BezierParam                =19         # from enum StructType2DEnum
	ko_BezierPointParam           =17         # from enum StructType2DEnum
	ko_BrandLeaderParam           =62         # from enum StructType2DEnum
	ko_BreakDimDrawing            =47         # from enum StructType2DEnum
	ko_CON                        =41         # from enum StructType2DEnum
	ko_CentreParam                =93         # from enum StructType2DEnum
	ko_ChangeLeaderParam          =128        # from enum StructType2DEnum
	ko_Char255                    =111        # from enum StructType2DEnum
	ko_CircleParam                =20         # from enum StructType2DEnum
	ko_ColumnInfoParam            =36         # from enum StructType2DEnum
	ko_ConicArcParam              =75         # from enum StructType2DEnum
	ko_ConstraintParam            =89         # from enum StructType2DEnum
	ko_ContourParam               =109        # from enum StructType2DEnum
	ko_CopyObjectParam            =126        # from enum StructType2DEnum
	ko_CornerParam                =90         # from enum StructType2DEnum
	ko_CurvePattern               =69         # from enum StructType2DEnum
	ko_CurvePatternEx             =71         # from enum StructType2DEnum
	ko_CurvePicture               =70         # from enum StructType2DEnum
	ko_CurveStyleParam            =72         # from enum StructType2DEnum
	ko_CutLineParam               =65         # from enum StructType2DEnum
	ko_DimDrawing                 =44         # from enum StructType2DEnum
	ko_DimText                    =42         # from enum StructType2DEnum
	ko_DimensionOptions           =80         # from enum StructType2DEnum
	ko_DimensionPartsParam        =73         # from enum StructType2DEnum
	ko_DocAttachSpcParam          =94         # from enum StructType2DEnum
	ko_DocumentParam              =35         # from enum StructType2DEnum
	ko_DoubleValue                =110        # from enum StructType2DEnum
	ko_EllipsArcParam             =23         # from enum StructType2DEnum
	ko_EllipsArcParam1            =24         # from enum StructType2DEnum
	ko_EllipseParam               =22         # from enum StructType2DEnum
	ko_EquidParam                 =25         # from enum StructType2DEnum
	ko_HatchLineParam             =113        # from enum StructType2DEnum
	ko_HatchParam                 =26         # from enum StructType2DEnum
	ko_HatchStyleParam            =114        # from enum StructType2DEnum
	ko_InertiaParam               =83         # from enum StructType2DEnum
	ko_InsertFragmentParam        =88         # from enum StructType2DEnum
	ko_InsertFragmentParamEx      =119        # from enum StructType2DEnum
	ko_LBreakDimParam             =48         # from enum StructType2DEnum
	ko_LBreakDimSource            =46         # from enum StructType2DEnum
	ko_LDimParam                  =45         # from enum StructType2DEnum
	ko_LDimSource                 =43         # from enum StructType2DEnum
	ko_LayerParam                 =9          # from enum StructType2DEnum
	ko_LeaderParam                =60         # from enum StructType2DEnum
	ko_LibStyle                   =77         # from enum StructType2DEnum
	ko_LibraryAttrTypeParam       =39         # from enum StructType2DEnum
	ko_LibraryStyleParam          =82         # from enum StructType2DEnum
	ko_LineParam                  =21         # from enum StructType2DEnum
	ko_LineSegParam               =11         # from enum StructType2DEnum
	ko_LtVariant                  =108        # from enum StructType2DEnum
	ko_MarkerLeaderParam          =63         # from enum StructType2DEnum
	ko_MassInertiaParam           =84         # from enum StructType2DEnum
	ko_MathPointParam             =14         # from enum StructType2DEnum
	ko_NumberTypeAttrParam        =98         # from enum StructType2DEnum
	ko_NurbsParam                 =87         # from enum StructType2DEnum
	ko_NurbsPointParam            =18         # from enum StructType2DEnum
	ko_OrdinatedDimParam          =117        # from enum StructType2DEnum
	ko_OrdinatedDrawingParam      =116        # from enum StructType2DEnum
	ko_OrdinatedSourceParam       =115        # from enum StructType2DEnum
	ko_OverlapObjectOptions       =127        # from enum StructType2DEnum
	ko_ParagraphParam             =27         # from enum StructType2DEnum
	ko_ParametrisationParam       =9000       # from enum StructType2DEnum
	ko_Phantom                    =6          # from enum StructType2DEnum
	ko_PlacementParam             =7          # from enum StructType2DEnum
	ko_PointParam                 =16         # from enum StructType2DEnum
	ko_PolylineParam              =76         # from enum StructType2DEnum
	ko_PosLeaderParam             =61         # from enum StructType2DEnum
	ko_QualityContensParam        =107        # from enum StructType2DEnum
	ko_QualityItemParam           =106        # from enum StructType2DEnum
	ko_RBreakDimParam             =56         # from enum StructType2DEnum
	ko_RBreakDrawing              =55         # from enum StructType2DEnum
	ko_RDimDrawing                =53         # from enum StructType2DEnum
	ko_RDimParam                  =54         # from enum StructType2DEnum
	ko_RDimSource                 =52         # from enum StructType2DEnum
	ko_RasterParam                =96         # from enum StructType2DEnum
	ko_RecordTypeAttrParam        =97         # from enum StructType2DEnum
	ko_RectParam                  =15         # from enum StructType2DEnum
	ko_RectangleParam             =91         # from enum StructType2DEnum
	ko_RegularPolygonParam        =92         # from enum StructType2DEnum
	ko_RemoteElementParam         =125        # from enum StructType2DEnum
	ko_RequestInfo                =10         # from enum StructType2DEnum
	ko_RoughPar                   =57         # from enum StructType2DEnum
	ko_RoughParam                 =59         # from enum StructType2DEnum
	ko_SheetOptions               =118        # from enum StructType2DEnum
	ko_SheetPar                   =34         # from enum StructType2DEnum
	ko_SheetSize                  =33         # from enum StructType2DEnum
	ko_ShelfPar                   =58         # from enum StructType2DEnum
	ko_SnapOptions                =86         # from enum StructType2DEnum
	ko_SpcColumnParam             =81         # from enum StructType2DEnum
	ko_SpcDescrParam              =105        # from enum StructType2DEnum
	ko_SpcObjParam                =95         # from enum StructType2DEnum
	ko_SpcStyleColumnParam        =99         # from enum StructType2DEnum
	ko_SpcStyleParam              =104        # from enum StructType2DEnum
	ko_SpcStyleSectionParam       =100        # from enum StructType2DEnum
	ko_SpcSubSectionParam         =101        # from enum StructType2DEnum
	ko_SpcTuningSectionParam      =102        # from enum StructType2DEnum
	ko_SpcTuningStyleParam        =103        # from enum StructType2DEnum
	ko_SpecRoughParam             =79         # from enum StructType2DEnum
	ko_StandartSheet              =32         # from enum StructType2DEnum
	ko_TAN                        =40         # from enum StructType2DEnum
	ko_TechnicalDemandParam       =78         # from enum StructType2DEnum
	ko_TextDocumentParam          =124        # from enum StructType2DEnum
	ko_TextItemFont               =30         # from enum StructType2DEnum
	ko_TextItemParam              =31         # from enum StructType2DEnum
	ko_TextLineParam              =29         # from enum StructType2DEnum
	ko_TextParam                  =28         # from enum StructType2DEnum
	ko_TextStyleParam             =74         # from enum StructType2DEnum
	ko_ToleranceBranch            =67         # from enum StructType2DEnum
	ko_ToleranceParam             =68         # from enum StructType2DEnum
	ko_TreeNodeParam              =120        # from enum StructType2DEnum
	ko_Type1                      =1          # from enum StructType2DEnum
	ko_Type2                      =2          # from enum StructType2DEnum
	ko_Type3                      =3          # from enum StructType2DEnum
	ko_Type5                      =4          # from enum StructType2DEnum
	ko_Type6                      =5          # from enum StructType2DEnum
	ko_UserParam                  =112        # from enum StructType2DEnum
	ko_VariableParam              =85         # from enum StructType2DEnum
	ko_ViewColorParam             =121        # from enum StructType2DEnum
	ko_ViewParam                  =8          # from enum StructType2DEnum
	ko_ViewPointerParam           =66         # from enum StructType2DEnum
	ksZoomAll                     =2          # from enum ZoomTypeEnum
	ksZoomNext                    =0          # from enum ZoomTypeEnum
	ksZoomPrevious                =1          # from enum ZoomTypeEnum
	ksAPI3DCom                    =3          # from enum ksAPITypeEnum
	ksAPI5Auto                    =1          # from enum ksAPITypeEnum
	ksAPI7Dual                    =2          # from enum ksAPITypeEnum
	ksAPIUndef                    =0          # from enum ksAPITypeEnum
	ksAccuracy0                   =0          # from enum ksAccuracyEnum
	ksAccuracy1                   =1          # from enum ksAccuracyEnum
	ksAccuracy2                   =2          # from enum ksAccuracyEnum
	ksAccuracy3                   =3          # from enum ksAccuracyEnum
	ksAccuracy4                   =4          # from enum ksAccuracyEnum
	ksAccuracy5                   =5          # from enum ksAccuracyEnum
	ksAccuracy6                   =6          # from enum ksAccuracyEnum
	ksAccuracy7                   =7          # from enum ksAccuracyEnum
	ksAccuracy8                   =8          # from enum ksAccuracyEnum
	ksAccuracy9                   =9          # from enum ksAccuracyEnum
	ksAccuracyDefault             =-1         # from enum ksAccuracyEnum
	ksAlignAllWidth               =3          # from enum ksAlignEnum
	ksAlignCenter                 =1          # from enum ksAlignEnum
	ksAlignDecimal                =3          # from enum ksAlignEnum
	ksAlignDefault                =-1         # from enum ksAlignEnum
	ksAlignLeft                   =0          # from enum ksAlignEnum
	ksAlignRight                  =2          # from enum ksAlignEnum
	ksATArbitrary                 =0          # from enum ksAlignmentTypeEnum
	ksATHorizontal                =1          # from enum ksAlignmentTypeEnum
	ksATVertical                  =2          # from enum ksAlignmentTypeEnum
	ksAlCentre                    =1          # from enum ksAllocationEnum
	ksAlLeft                      =0          # from enum ksAllocationEnum
	ksAlRight                     =2          # from enum ksAllocationEnum
	ksADMaxAngle                  =1          # from enum ksAngleDimTypeEnum
	ksADMinAngle                  =0          # from enum ksAngleDimTypeEnum
	ksADMoreAngle                 =2          # from enum ksAngleDimTypeEnum
	ksAngle0                      =0          # from enum ksAngleEnum
	ksAngle180                    =2          # from enum ksAngleEnum
	ksAngle270                    =3          # from enum ksAngleEnum
	ksAngle90                     =1          # from enum ksAngleEnum
	ksAsteriskPoint               =7          # from enum ksAnnotationSymbolEnum
	ksCirclePoint                 =6          # from enum ksAnnotationSymbolEnum
	ksDotPoint                    =1          # from enum ksAnnotationSymbolEnum
	ksPlusPoint                   =2          # from enum ksAnnotationSymbolEnum
	ksPlusPointTwo                =9          # from enum ksAnnotationSymbolEnum
	ksSquarePoint                 =4          # from enum ksAnnotationSymbolEnum
	ksStrikeSquarePoint           =8          # from enum ksAnnotationSymbolEnum
	ksTrianglePoint               =5          # from enum ksAnnotationSymbolEnum
	ksUnknownSymbol               =0          # from enum ksAnnotationSymbolEnum
	ksXPoint                      =3          # from enum ksAnnotationSymbolEnum
	ksASArrowInside               =101        # from enum ksAnnotativeTerminatorSignEnum
	ksASArrowOrdinate             =107        # from enum ksAnnotativeTerminatorSignEnum
	ksASArrowOutside              =102        # from enum ksAnnotativeTerminatorSignEnum
	ksASBaseTriangle              =118        # from enum ksAnnotativeTerminatorSignEnum
	ksASBigArrowInside            =106        # from enum ksAnnotativeTerminatorSignEnum
	ksASCentreMarker              =110        # from enum ksAnnotativeTerminatorSignEnum
	ksASClosedArrowInside         =119        # from enum ksAnnotativeTerminatorSignEnum
	ksASClosedArrowOutside        =120        # from enum ksAnnotativeTerminatorSignEnum
	ksASCornerCrampSign           =115        # from enum ksAnnotativeTerminatorSignEnum
	ksASCrampSign                 =114        # from enum ksAnnotativeTerminatorSignEnum
	ksASDot                       =125        # from enum ksAnnotativeTerminatorSignEnum
	ksASDownHalfArrow             =105        # from enum ksAnnotativeTerminatorSignEnum
	ksASGlueSign                  =111        # from enum ksAnnotativeTerminatorSignEnum
	ksASLeftNotch                 =128        # from enum ksAnnotativeTerminatorSignEnum
	ksASMontageJointSign          =116        # from enum ksAnnotativeTerminatorSignEnum
	ksASNotch                     =117        # from enum ksAnnotativeTerminatorSignEnum
	ksASNotchTail                 =103        # from enum ksAnnotativeTerminatorSignEnum
	ksASOpenArrowInside           =121        # from enum ksAnnotativeTerminatorSignEnum
	ksASOpenArrowOutside          =122        # from enum ksAnnotativeTerminatorSignEnum
	ksASPoint                     =127        # from enum ksAnnotativeTerminatorSignEnum
	ksASRightAngleInside          =123        # from enum ksAnnotativeTerminatorSignEnum
	ksASRightAngleOutside         =124        # from enum ksAnnotativeTerminatorSignEnum
	ksASSewingSign                =113        # from enum ksAnnotativeTerminatorSignEnum
	ksASSmallDot                  =126        # from enum ksAnnotativeTerminatorSignEnum
	ksASSolderingSign             =112        # from enum ksAnnotativeTerminatorSignEnum
	ksASTriangle                  =108        # from enum ksAnnotativeTerminatorSignEnum
	ksASUnknown                   =0          # from enum ksAnnotativeTerminatorSignEnum
	ksASUpHalfArrow               =104        # from enum ksAnnotativeTerminatorSignEnum
	ksAScircleRad2                =109        # from enum ksAnnotativeTerminatorSignEnum
	ksArrow                       =2          # from enum ksArrowEnum
	ksClosedArrow                 =8          # from enum ksArrowEnum
	ksDot                         =10         # from enum ksArrowEnum
	ksDownHalfArrow               =4          # from enum ksArrowEnum
	ksLeaderArrow                 =2          # from enum ksArrowEnum
	ksLeaderPoint                 =1          # from enum ksArrowEnum
	ksLeaderWithoutArrow          =0          # from enum ksArrowEnum
	ksLeftNotch                   =6          # from enum ksArrowEnum
	ksNotch                       =5          # from enum ksArrowEnum
	ksOpenArrow                   =9          # from enum ksArrowEnum
	ksPoint                       =1          # from enum ksArrowEnum
	ksRightAngle                  =7          # from enum ksArrowEnum
	ksSmallDot                    =11         # from enum ksArrowEnum
	ksTriangle60                  =12         # from enum ksArrowEnum
	ksTriangle90                  =13         # from enum ksArrowEnum
	ksUpHalfArrow                 =3          # from enum ksArrowEnum
	ksWithoutArrow                =0          # from enum ksArrowEnum
	ksATDouble                    =1          # from enum ksAttributeTypeEnum
	ksATFixedTable                =2          # from enum ksAttributeTypeEnum
	ksATString                    =0          # from enum ksAttributeTypeEnum
	ksATUnknown                   =-1         # from enum ksAttributeTypeEnum
	ksATVariableTable             =3          # from enum ksAttributeTypeEnum
	ksBVNone                      =0          # from enum ksBisectorVariant
	ksBVNormalDiff                =2          # from enum ksBisectorVariant
	ksBVNormalSum                 =1          # from enum ksBisectorVariant
	ksBmp1616                     =0          # from enum ksBmpSizeEnum
	ksBmp2424                     =1          # from enum ksBmpSizeEnum
	ksBmp3232                     =2          # from enum ksBmpSizeEnum
	ksBmp4848                     =3          # from enum ksBmpSizeEnum
	ksBooleanUnknown              =0          # from enum ksBooleanType
	ksDifference                  =2          # from enum ksBooleanType
	ksIntersect                   =1          # from enum ksBooleanType
	ksUnion                       =3          # from enum ksBooleanType
	ksBLBreak                     =2          # from enum ksBreakLineTypeEnum
	ksBLNotImage                  =0          # from enum ksBreakLineTypeEnum
	ksBLStraight                  =1          # from enum ksBreakLineTypeEnum
	ksBLVawe                      =3          # from enum ksBreakLineTypeEnum
	ksCBAllBorders                =7          # from enum ksCellBoundariesEnum
	ksCBBottomBorder              =3          # from enum ksCellBoundariesEnum
	ksCBExternalBorders           =6          # from enum ksCellBoundariesEnum
	ksCBHorisontMidleBorder       =4          # from enum ksCellBoundariesEnum
	ksCBInternalBorders           =8          # from enum ksCellBoundariesEnum
	ksCBLeftBorder                =0          # from enum ksCellBoundariesEnum
	ksCBNoBorders                 =9          # from enum ksCellBoundariesEnum
	ksCBRightBorder               =1          # from enum ksCellBoundariesEnum
	ksCBTopBorder                 =2          # from enum ksCellBoundariesEnum
	ksCBVerticalMidleBorder       =5          # from enum ksCellBoundariesEnum
	ksCMOneAxis                   =1          # from enum ksCentreMarkerEnum
	ksCMPlusPoint                 =0          # from enum ksCentreMarkerEnum
	ksCMTwoAxis                   =2          # from enum ksCentreMarkerEnum
	ksCMUnknown                   =-1         # from enum ksCentreMarkerEnum
	ksCLSBracketCircle            =3          # from enum ksChangeLeaderSignEnum
	ksCLSBracketCorner            =4          # from enum ksChangeLeaderSignEnum
	ksCLSBracketSquare            =2          # from enum ksChangeLeaderSignEnum
	ksCLSCircle                   =1          # from enum ksChangeLeaderSignEnum
	ksCLSSquare                   =0          # from enum ksChangeLeaderSignEnum
	ksCheckBoxDefault             =0          # from enum ksCheckBoxVisualStyleEnum
	ksCheckBoxSwitcher            =1          # from enum ksCheckBoxVisualStyleEnum
	ksCsrCurrent                  =0          # from enum ksCheckSumVersionEnum
	ksCsrKompas10SP2              =-1         # from enum ksCheckSumVersionEnum
	ksCsrKompas11                 =-5         # from enum ksCheckSumVersionEnum
	ksCsrKompas11SP1              =-6         # from enum ksCheckSumVersionEnum
	ksCsrKompas12                 =-10        # from enum ksCheckSumVersionEnum
	ksCsrKompas12SP1              =-11        # from enum ksCheckSumVersionEnum
	ksCsrKompas13                 =-15        # from enum ksCheckSumVersionEnum
	ksCsrKompas13SP1              =-16        # from enum ksCheckSumVersionEnum
	ksCsrKompas13SP2              =-17        # from enum ksCheckSumVersionEnum
	ksCsrKompas14                 =-20        # from enum ksCheckSumVersionEnum
	ksCsrKompas14SP1              =-21        # from enum ksCheckSumVersionEnum
	ksCsrKompas14SP2              =-22        # from enum ksCheckSumVersionEnum
	ksCsrKompas15                 =-25        # from enum ksCheckSumVersionEnum
	ksCsrKompas15Sp1              =-26        # from enum ksCheckSumVersionEnum
	ksCsrKompas15Sp2              =-27        # from enum ksCheckSumVersionEnum
	ksCsrKompas16                 =-30        # from enum ksCheckSumVersionEnum
	ksCsrKompas16Sp1              =-31        # from enum ksCheckSumVersionEnum
	ksCsrKompas17                 =-35        # from enum ksCheckSumVersionEnum
	ksCsrKompas17Sp1              =-36        # from enum ksCheckSumVersionEnum
	ksCsrKompas18                 =-37        # from enum ksCheckSumVersionEnum
	ksChMAllColors                =-1         # from enum ksChooseManagerTypeEnum
	ksChMLevel1Color1             =1          # from enum ksChooseManagerTypeEnum
	ksChMLevel1Color2             =2          # from enum ksChooseManagerTypeEnum
	ksChMLevel1ColorBase          =0          # from enum ksChooseManagerTypeEnum
	ksChMLevel2Color1             =101        # from enum ksChooseManagerTypeEnum
	ksChMLevel2Color2             =102        # from enum ksChooseManagerTypeEnum
	ksChMLevel2ColorBase          =100        # from enum ksChooseManagerTypeEnum
	ksChMUnknown                  =-2         # from enum ksChooseManagerTypeEnum
	ksColouringAngle              =2          # from enum ksColouringTypeEnum
	ksColouringCircle             =4          # from enum ksColouringTypeEnum
	ksColouringCone               =3          # from enum ksColouringTypeEnum
	ksColouringCylinder           =6          # from enum ksColouringTypeEnum
	ksColouringLinear             =1          # from enum ksColouringTypeEnum
	ksColouringSolid              =0          # from enum ksColouringTypeEnum
	ksColouringSquare             =5          # from enum ksColouringTypeEnum
	ksCCBeginPoint                =0          # from enum ksConicCurvePontIndexEnum
	ksCCEndPoint                  =1          # from enum ksConicCurvePontIndexEnum
	ksCCIntersectPoint            =2          # from enum ksConicCurvePontIndexEnum
	ksCCPointOnCurve              =3          # from enum ksConicCurvePontIndexEnum
	ksCAssociation                =12         # from enum ksConstraintTypeEnum
	ksCBisector                   =21         # from enum ksConstraintTypeEnum
	ksCCollinear                  =17         # from enum ksConstraintTypeEnum
	ksCConcentricity              =22         # from enum ksConstraintTypeEnum
	ksCDimWithVariable            =13         # from enum ksConstraintTypeEnum
	ksCEqualLength                =7          # from enum ksConstraintTypeEnum
	ksCEqualRadius                =8          # from enum ksConstraintTypeEnum
	ksCFixedAngle                 =18         # from enum ksConstraintTypeEnum
	ksCFixedDim                   =14         # from enum ksConstraintTypeEnum
	ksCFixedLenght                =19         # from enum ksConstraintTypeEnum
	ksCFixedPoint                 =1          # from enum ksConstraintTypeEnum
	ksCHAlignPoints               =9          # from enum ksConstraintTypeEnum
	ksCHorizontal                 =3          # from enum ksConstraintTypeEnum
	ksCMergePoints                =11         # from enum ksConstraintTypeEnum
	ksCParallel                   =5          # from enum ksConstraintTypeEnum
	ksCPerpendicular              =6          # from enum ksConstraintTypeEnum
	ksCPointOnCurve               =2          # from enum ksConstraintTypeEnum
	ksCPointOnCurveMiddle         =20         # from enum ksConstraintTypeEnum
	ksCSymmetryTwoPoints          =16         # from enum ksConstraintTypeEnum
	ksCTangentTwoCurves           =15         # from enum ksConstraintTypeEnum
	ksCUnknown                    =0          # from enum ksConstraintTypeEnum
	ksCVAlignPoints               =10         # from enum ksConstraintTypeEnum
	ksCVertical                   =4          # from enum ksConstraintTypeEnum
	ksCDButtonUpdate              =4          # from enum ksContentDialogNotifyEnum
	ksCDCreateContentCallback     =1          # from enum ksContentDialogNotifyEnum
	ksCDDestroyContent            =2          # from enum ksContentDialogNotifyEnum
	ksCDExecuteCommand            =3          # from enum ksContentDialogNotifyEnum
	ksUFormCRectangle             =2          # from enum ksContourFormEnum
	ksUFormCircle                 =0          # from enum ksContourFormEnum
	ksUFormCirle                  =0          # from enum ksContourFormEnum
	ksUFormRectangle              =1          # from enum ksContourFormEnum
	ksCSArc                       =3          # from enum ksContourSegmentEnum
	ksCSBezier                    =8          # from enum ksContourSegmentEnum
	ksCSCircle                    =2          # from enum ksContourSegmentEnum
	ksCSEllipse                   =32         # from enum ksContourSegmentEnum
	ksCSEllipseArc                =34         # from enum ksContourSegmentEnum
	ksCSLineSeg                   =1          # from enum ksContourSegmentEnum
	ksCSNurbs                     =33         # from enum ksContourSegmentEnum
	ksCSUnknown                   =-1         # from enum ksContourSegmentEnum
	ksCTChamfer                   =1          # from enum ksCornerTypeEnum
	ksCTFillet                    =2          # from enum ksCornerTypeEnum
	ksCTNoProcess                 =0          # from enum ksCornerTypeEnum
	ksCPTBasicLine                =1          # from enum ksCurvePenTypeEnum
	ksCPTHeavyLine                =3          # from enum ksCurvePenTypeEnum
	ksCPTIndependent              =0          # from enum ksCurvePenTypeEnum
	ksCPTThinLine                 =2          # from enum ksCurvePenTypeEnum
	ksCSAxial                     =3          # from enum ksCurveStyleEnum
	ksCSBrokenLine                =5          # from enum ksCurveStyleEnum
	ksCSConstruction              =6          # from enum ksCurveStyleEnum
	ksCSDash2Dots                 =8          # from enum ksCurveStyleEnum
	ksCSDashed                    =4          # from enum ksCurveStyleEnum
	ksCSDashedNormal              =9          # from enum ksCurveStyleEnum
	ksCSHidden                    =-1         # from enum ksCurveStyleEnum
	ksCSISO02Dashed               =12         # from enum ksCurveStyleEnum
	ksCSISO03DashedLSpace         =13         # from enum ksCurveStyleEnum
	ksCSISO04DashDotLDash         =14         # from enum ksCurveStyleEnum
	ksCSISO05DashDotLDash2Dots    =15         # from enum ksCurveStyleEnum
	ksCSISO06DashDotLDash3Dots    =16         # from enum ksCurveStyleEnum
	ksCSISO07Dotted               =17         # from enum ksCurveStyleEnum
	ksCSISO08DashDotLShDashes     =18         # from enum ksCurveStyleEnum
	ksCSISO09DashDot1L2ShDashes   =19         # from enum ksCurveStyleEnum
	ksCSISO10DashDot              =20         # from enum ksCurveStyleEnum
	ksCSISO11DashDot2Dashes       =21         # from enum ksCurveStyleEnum
	ksCSISO12DashDot2Dots         =22         # from enum ksCurveStyleEnum
	ksCSISO13DashDot3Dots         =23         # from enum ksCurveStyleEnum
	ksCSISO14DashDot2Dashes2Dots  =24         # from enum ksCurveStyleEnum
	ksCSISO15DashDot2Dashes3Dots  =25         # from enum ksCurveStyleEnum
	ksCSNormal                    =1          # from enum ksCurveStyleEnum
	ksCSNormalDashDot             =10         # from enum ksCurveStyleEnum
	ksCSThick                     =7          # from enum ksCurveStyleEnum
	ksCSThin                      =2          # from enum ksCurveStyleEnum
	ksCSThinForHatch              =11         # from enum ksCurveStyleEnum
	ksCSUnvisible                 =0          # from enum ksCurveStyleEnum
	ksCSTBrokenLine               =1          # from enum ksCurveStyleTypeEnum
	ksCSTSoldLine                 =0          # from enum ksCurveStyleTypeEnum
	ksDimTextFormatGDD            =1          # from enum ksDimTextFormatEnum
	ksDimTextFormatGMS            =0          # from enum ksDimTextFormatEnum
	ksDimArrowAuto                =2          # from enum ksDimensionArrowPosEnum
	ksDimArrowInside              =0          # from enum ksDimensionArrowPosEnum
	ksDimArrowOutside             =1          # from enum ksDimensionArrowPosEnum
	ksDimBaseCenter               =0          # from enum ksDimensionBaseEnum
	ksDimBaseP1                   =1          # from enum ksDimensionBaseEnum
	ksDimBaseP2                   =2          # from enum ksDimensionBaseEnum
	ksDimCommonBase               =3          # from enum ksDimensionBaseEnum
	ksDimFirstCommonBase          =4          # from enum ksDimensionBaseEnum
	ksDimDeviation                =0          # from enum ksDimensionDeviationEnum
	ksDimLimits                   =1          # from enum ksDimensionDeviationEnum
	ksDimLineLimits               =2          # from enum ksDimensionDeviationEnum
	ksDimACentre                  =2          # from enum ksDimensionTextAlignEnum
	ksDimACentreLowFont           =0          # from enum ksDimensionTextAlignEnum
	ksDimALowerBoundary           =3          # from enum ksDimensionTextAlignEnum
	ksDimAUpperBoundary           =1          # from enum ksDimensionTextAlignEnum
	ksDimBrackets                 =1          # from enum ksDimensionTextBracketsEnum
	ksDimBracketsOff              =0          # from enum ksDimensionTextBracketsEnum
	ksDimSquareBrackets           =2          # from enum ksDimensionTextBracketsEnum
	ksDimTextHorizontalInCut      =2          # from enum ksDimensionTextPosEnum
	ksDimTextParallelInCut        =1          # from enum ksDimensionTextPosEnum
	ksDimTextParallelOnLine       =0          # from enum ksDimensionTextPosEnum
	ksDTPOnShelf                  =2          # from enum ksDimensionTextTypeEnum
	ksDimTAuto                    =0          # from enum ksDimensionTextTypeEnum
	ksDimTManual                  =1          # from enum ksDimensionTextTypeEnum
	d2BeginChoiceMaterial         =3          # from enum ksDocument2DNotifyEnum
	d2BeginChoiceProperty         =7          # from enum ksDocument2DNotifyEnum
	d2BeginInsertFragment         =5          # from enum ksDocument2DNotifyEnum
	d2BeginRebuild                =1          # from enum ksDocument2DNotifyEnum
	d2ChoiceMaterial              =4          # from enum ksDocument2DNotifyEnum
	d2ChoiceProperty              =8          # from enum ksDocument2DNotifyEnum
	d2LocalFragmentEdit           =6          # from enum ksDocument2DNotifyEnum
	d2Rebuild                     =2          # from enum ksDocument2DNotifyEnum
	d3BedinLoadCombinationChange  =16         # from enum ksDocument3DNotifyEnum
	d3BeginChoiceMarking          =5          # from enum ksDocument3DNotifyEnum
	d3BeginChoiceMaterial         =3          # from enum ksDocument3DNotifyEnum
	d3BeginChoiceProperty         =12         # from enum ksDocument3DNotifyEnum
	d3BeginCreatePartFromFile     =8          # from enum ksDocument3DNotifyEnum
	d3BeginRebuild                =1          # from enum ksDocument3DNotifyEnum
	d3BeginRollbackFeatures       =14         # from enum ksDocument3DNotifyEnum
	d3BeginSetPartFromFile        =7          # from enum ksDocument3DNotifyEnum
	d3ChangeCurrentEmbodiment     =11         # from enum ksDocument3DNotifyEnum
	d3ChoiceMarking               =6          # from enum ksDocument3DNotifyEnum
	d3ChoiceMaterial              =4          # from enum ksDocument3DNotifyEnum
	d3ChoiceProperty              =13         # from enum ksDocument3DNotifyEnum
	d3CreateEmbodiment            =9          # from enum ksDocument3DNotifyEnum
	d3DeleteEmbodiment            =10         # from enum ksDocument3DNotifyEnum
	d3LoadCombinationChange       =17         # from enum ksDocument3DNotifyEnum
	d3Rebuild                     =2          # from enum ksDocument3DNotifyEnum
	d3RollbackFeatures            =15         # from enum ksDocument3DNotifyEnum
	kdActiveDocument              =5          # from enum ksDocumentFileNotifyEnum
	kdAutoSaveDocument            =14         # from enum ksDocumentFileNotifyEnum
	kdBeginAutoSaveDocument       =13         # from enum ksDocumentFileNotifyEnum
	kdBeginCloseDocument          =1          # from enum ksDocumentFileNotifyEnum
	kdBeginProcess                =11         # from enum ksDocumentFileNotifyEnum
	kdBeginSaveAsDocument         =7          # from enum ksDocumentFileNotifyEnum
	kdBeginSaveDocument           =3          # from enum ksDocumentFileNotifyEnum
	kdCloseDocument               =2          # from enum ksDocumentFileNotifyEnum
	kdDeactiveDocument            =6          # from enum ksDocumentFileNotifyEnum
	kdDocumentFrameOpen           =8          # from enum ksDocumentFileNotifyEnum
	kdEndProcess                  =12         # from enum ksDocumentFileNotifyEnum
	kdProcessActivate             =9          # from enum ksDocumentFileNotifyEnum
	kdProcessDeactivate           =10         # from enum ksDocumentFileNotifyEnum
	kdSaveDocument                =4          # from enum ksDocumentFileNotifyEnum
	ksFormatA0                    =0          # from enum ksDocumentFormatEnum
	ksFormatA1                    =1          # from enum ksDocumentFormatEnum
	ksFormatA2                    =2          # from enum ksDocumentFormatEnum
	ksFormatA3                    =3          # from enum ksDocumentFormatEnum
	ksFormatA4                    =4          # from enum ksDocumentFormatEnum
	ksFormatA5                    =5          # from enum ksDocumentFormatEnum
	ksFormatUser                  =6          # from enum ksDocumentFormatEnum
	frActivate                    =9          # from enum ksDocumentFrameNotifyEnum
	frAddGabarit                  =8          # from enum ksDocumentFrameNotifyEnum
	frBeginPaint                  =1          # from enum ksDocumentFrameNotifyEnum
	frBeginPaintGL                =6          # from enum ksDocumentFrameNotifyEnum
	frBeginPaintTmpObjects        =14         # from enum ksDocumentFrameNotifyEnum
	frCloseFrame                  =11         # from enum ksDocumentFrameNotifyEnum
	frClosePaint                  =2          # from enum ksDocumentFrameNotifyEnum
	frClosePaintGL                =7          # from enum ksDocumentFrameNotifyEnum
	frClosePaintTmpObjects        =15         # from enum ksDocumentFrameNotifyEnum
	frDeactivate                  =10         # from enum ksDocumentFrameNotifyEnum
	frMouseDblClick               =5          # from enum ksDocumentFrameNotifyEnum
	frMouseDown                   =3          # from enum ksDocumentFrameNotifyEnum
	frMouseMove                   =12         # from enum ksDocumentFrameNotifyEnum
	frMouseUp                     =4          # from enum ksDocumentFrameNotifyEnum
	frShowOcxTree                 =13         # from enum ksDocumentFrameNotifyEnum
	ksInsertionAssembly           =5          # from enum ksDocumentsLibraryInsertionTypeEnum
	ksInsertionFragment           =2          # from enum ksDocumentsLibraryInsertionTypeEnum
	ksInsertionPart               =4          # from enum ksDocumentsLibraryInsertionTypeEnum
	ksInsertionRaster             =20         # from enum ksDocumentsLibraryInsertionTypeEnum
	ksInsertionTable              =21         # from enum ksDocumentsLibraryInsertionTypeEnum
	ksInsertionTextual            =6          # from enum ksDocumentsLibraryInsertionTypeEnum
	ksInsertionTxtFile            =22         # from enum ksDocumentsLibraryInsertionTypeEnum
	ksInsertionUnknown            =0          # from enum ksDocumentsLibraryInsertionTypeEnum
	ksDrawInScreenPlane           =1          # from enum ksDrawInScreenPlaneEnum
	ksDrawNone                    =0          # from enum ksDrawInScreenPlaneEnum
	ksDrawProjectFromScreen       =3          # from enum ksDrawInScreenPlaneEnum
	ksDrawProjectToScreen         =2          # from enum ksDrawInScreenPlaneEnum
	ksAllParam                    =-1         # from enum ksDrawingObjectParamTypeEnum
	ksSheetAllParam               =-2         # from enum ksDrawingObjectParamTypeEnum
	ksViewAllParam                =-7         # from enum ksDrawingObjectParamTypeEnum
	ksListItemDelete              =2          # from enum ksEditListCommandEnum
	ksListItemEdit                =5          # from enum ksEditListCommandEnum
	ksListItemMoveDown            =4          # from enum ksEditListCommandEnum
	ksListItemMoveUp              =3          # from enum ksEditListCommandEnum
	ksListItemNew                 =1          # from enum ksEditListCommandEnum
	ksCheckList                   =1          # from enum ksEditListTypeEnum
	ksEditList                    =0          # from enum ksEditListTypeEnum
	ksRadioList                   =2          # from enum ksEditListTypeEnum
	ksEnterApplyIcon              =3          # from enum ksEnterButtonIconTypeEnum
	ksEnterCheckIcon              =0          # from enum ksEnterButtonIconTypeEnum
	ksEnterFloppyIcon             =1          # from enum ksEnterButtonIconTypeEnum
	ksEnterNewInputIcon           =2          # from enum ksEnterButtonIconTypeEnum
	ksETBoth                      =2          # from enum ksEquidistantTypeEnum
	ksETLeft                      =0          # from enum ksEquidistantTypeEnum
	ksETRight                     =1          # from enum ksEquidistantTypeEnum
	ksETUnknown                   =-1         # from enum ksEquidistantTypeEnum
	ksEFExternalBilletPart        =28         # from enum ksExternalFilesTypesEnum
	ksEFTAssRprtTable             =25         # from enum ksExternalFilesTypesEnum
	ksEFTAssemblyFile             =16         # from enum ksExternalFilesTypesEnum
	ksEFTAttributeTypesLibrary    =4          # from enum ksExternalFilesTypesEnum
	ksEFTCopyExternalGeometry     =27         # from enum ksExternalFilesTypesEnum
	ksEFTCurveStyleLibrary        =1          # from enum ksExternalFilesTypesEnum
	ksEFTDataFile                 =23         # from enum ksExternalFilesTypesEnum
	ksEFTDocConnectedToSpcObj     =13         # from enum ksExternalFilesTypesEnum
	ksEFTDocConnectedToSpcObjInOtherDocs=15         # from enum ksExternalFilesTypesEnum
	ksEFTDocumentFile             =0          # from enum ksExternalFilesTypesEnum
	ksEFTDraftFile                =21         # from enum ksExternalFilesTypesEnum
	ksEFTEexternalHyperText       =26         # from enum ksExternalFilesTypesEnum
	ksEFTExternalLayoutGeometry   =29         # from enum ksExternalFilesTypesEnum
	ksEFTExternalRefContextFile   =32         # from enum ksExternalFilesTypesEnum
	ksEFTFragmentFile             =6          # from enum ksExternalFilesTypesEnum
	ksEFTFragmentsLibrary         =7          # from enum ksExternalFilesTypesEnum
	ksEFTHatchStyleLibrary        =3          # from enum ksExternalFilesTypesEnum
	ksEFTHyperLink                =22         # from enum ksExternalFilesTypesEnum
	ksEFTIngotsLibrary            =10         # from enum ksExternalFilesTypesEnum
	ksEFTLayoutsLibrary           =5          # from enum ksExternalFilesTypesEnum
	ksEFTMetaDataSource           =30         # from enum ksExternalFilesTypesEnum
	ksEFTModelsLibrary            =17         # from enum ksExternalFilesTypesEnum
	ksEFTPartFile                 =11         # from enum ksExternalFilesTypesEnum
	ksEFTRasterFile               =12         # from enum ksExternalFilesTypesEnum
	ksEFTReadingRegimFile         =24         # from enum ksExternalFilesTypesEnum
	ksEFTServiceFile              =20         # from enum ksExternalFilesTypesEnum
	ksEFTSheetConnectedToSpc      =8          # from enum ksExternalFilesTypesEnum
	ksEFTSourceFileForVariable    =19         # from enum ksExternalFilesTypesEnum
	ksEFTSpcConnectedToSheet      =14         # from enum ksExternalFilesTypesEnum
	ksEFTSystemFile               =9          # from enum ksExternalFilesTypesEnum
	ksEFTTemporaryFile            =18         # from enum ksExternalFilesTypesEnum
	ksEFTTextStyleLibrary         =2          # from enum ksExternalFilesTypesEnum
	ksEFTUnknown                  =-1         # from enum ksExternalFilesTypesEnum
	ksFOPFilterObject3D           =1          # from enum ksFindObject3DParametersNotifyEnum
	ksFOPFilterObject             =1          # from enum ksFindObjectParametersNotifyEnum
	ksFindAll                     =0          # from enum ksFindObjectsTypeEnum
	ksFindAnyCurve                =1          # from enum ksFindObjectsTypeEnum
	ksFindCircleAnalog            =4          # from enum ksFindObjectsTypeEnum
	ksFindEllipseAnalog           =13         # from enum ksFindObjectsTypeEnum
	ksFindHatchBoundary           =15         # from enum ksFindObjectsTypeEnum
	ksFindObjByType               =-1         # from enum ksFindObjectsTypeEnum
	ksFindtTimmedCurve            =8          # from enum ksFindObjectsTypeEnum
	ksGTEnum                      =4          # from enum ksGroupeTypeEnum
	ksGTMatch                     =1          # from enum ksGroupeTypeEnum
	ksGTNone                      =0          # from enum ksGroupeTypeEnum
	ksGTRange                     =3          # from enum ksGroupeTypeEnum
	ksGTSum                       =2          # from enum ksGroupeTypeEnum
	ksHatchArtificialStone        =10         # from enum ksHatchStyleEnum
	ksHatchCeramics               =4          # from enum ksHatchStyleEnum
	ksHatchConcrete               =5          # from enum ksHatchStyleEnum
	ksHatchGlass                  =6          # from enum ksHatchStyleEnum
	ksHatchLiquid                 =7          # from enum ksHatchStyleEnum
	ksHatchLongitudalTimber       =13         # from enum ksHatchStyleEnum
	ksHatchMetal                  =0          # from enum ksHatchStyleEnum
	ksHatchNaturalStone           =3          # from enum ksHatchStyleEnum
	ksHatchNaturallyGround        =8          # from enum ksHatchStyleEnum
	ksHatchNonMetal               =1          # from enum ksHatchStyleEnum
	ksHatchReinforcedConcrete     =11         # from enum ksHatchStyleEnum
	ksHatchSand                   =14         # from enum ksHatchStyleEnum
	ksHatchSpreadGround           =9          # from enum ksHatchStyleEnum
	ksHatchTenseReinforcedConcrete=12         # from enum ksHatchStyleEnum
	ksHatchTimber                 =2          # from enum ksHatchStyleEnum
	ksHDFrontView                 =0          # from enum ksHeightDimTypeEnum
	ksHDTopView                   =1          # from enum ksHeightDimTypeEnum
	ksHDTopViewLeader             =2          # from enum ksHeightDimTypeEnum
	ksHideMessageNo               =2          # from enum ksHideMessageEnum
	ksHideMessageYes              =1          # from enum ksHideMessageEnum
	ksShowMessage                 =0          # from enum ksHideMessageEnum
	ksHLFile                      =1          # from enum ksHyperLinkTypeEnum
	ksHLMail                      =3          # from enum ksHyperLinkTypeEnum
	ksHLObject                    =2          # from enum ksHyperLinkTypeEnum
	ksHLUnknown                   =0          # from enum ksHyperLinkTypeEnum
	ksHTObjectNumberingGroup      =5          # from enum ksHypertextTypeEnum
	ksHTObjectProperty            =128        # from enum ksHypertextTypeEnum
	ksHTObjectSheet               =-2         # from enum ksHypertextTypeEnum
	ksHTObjectText                =0          # from enum ksHypertextTypeEnum
	ksHTObjectText1               =1          # from enum ksHypertextTypeEnum
	ksHTObjectText2               =2          # from enum ksHypertextTypeEnum
	ksHTObjectText3               =3          # from enum ksHypertextTypeEnum
	ksHTObjectText4               =4          # from enum ksHypertextTypeEnum
	ksHTObjectZone                =-1         # from enum ksHypertextTypeEnum
	ksHTPositionNumber            =16         # from enum ksHypertextTypeEnum
	ksHTSpecificationObjectCount  =130        # from enum ksHypertextTypeEnum
	ksHTSpecificationObjectMarking=128        # from enum ksHypertextTypeEnum
	ksHTSpecificationObjectName   =129        # from enum ksHypertextTypeEnum
	ksHTVariableComment           =3          # from enum ksHypertextTypeEnum
	ksHTVariableExpression        =2          # from enum ksHypertextTypeEnum
	ksHTVariableName              =1          # from enum ksHypertextTypeEnum
	ksHTVariableValue             =0          # from enum ksHypertextTypeEnum
	ksHTViewBaseObjectSheet       =-4         # from enum ksHypertextTypeEnum
	ksHTViewBaseObjectZone        =-3         # from enum ksHypertextTypeEnum
	ksHTViewName                  =6          # from enum ksHypertextTypeEnum
	ksHTViewScale                 =1          # from enum ksHypertextTypeEnum
	ksHTViewTitleSheet            =-2         # from enum ksHypertextTypeEnum
	ksHTViewTitleZone             =-1         # from enum ksHypertextTypeEnum
	ksHTViewTurn                  =4          # from enum ksHypertextTypeEnum
	ksHTViewTurnAngle             =5          # from enum ksHypertextTypeEnum
	ksHTViewUnfold                =3          # from enum ksHypertextTypeEnum
	ksTBodyFragment               =0          # from enum ksInsertionTypeEnum
	ksTBodyView                   =4          # from enum ksInsertionTypeEnum
	ksTLocalFragment              =3          # from enum ksInsertionTypeEnum
	ksTReferenceFragment          =1          # from enum ksInsertionTypeEnum
	ksTReferenceView              =5          # from enum ksInsertionTypeEnum
	ksTUnknown                    =-1         # from enum ksInsertionTypeEnum
	ksConverterToC3D              =7          # from enum ksKOMPASConverterEnum
	ksConverterToIGES             =4          # from enum ksKOMPASConverterEnum
	ksConverterToRaster           =0          # from enum ksKOMPASConverterEnum
	ksConverterToSAT              =1          # from enum ksKOMPASConverterEnum
	ksConverterToSTEP             =3          # from enum ksKOMPASConverterEnum
	ksConverterToSTEP_AP203       =203        # from enum ksKOMPASConverterEnum
	ksConverterToSTEP_AP214       =214        # from enum ksKOMPASConverterEnum
	ksConverterToSTEP_AP242       =242        # from enum ksKOMPASConverterEnum
	ksConverterToSTL              =6          # from enum ksKOMPASConverterEnum
	ksConverterToVRML             =5          # from enum ksKOMPASConverterEnum
	ksConverterToXT               =2          # from enum ksKOMPASConverterEnum
	ksCM3DArrayDestroy            =40615      # from enum ksKompasCommandEnum
	ksCM3DAssemblyDestroy         =40746      # from enum ksKompasCommandEnum
	ksCM3DSavePartAs              =40744      # from enum ksKompasCommandEnum
	ksCM3DUnitParts               =40745      # from enum ksKompasCommandEnum
	ksCMAbout                     =57664      # from enum ksKompasCommandEnum
	ksCMAddEditChangeListObject   =35761      # from enum ksKompasCommandEnum
	ksCMAddEditSpcObject          =35760      # from enum ksKompasCommandEnum
	ksCMAddPage                   =35766      # from enum ksKompasCommandEnum
	ksCMAddSpcDelegate            =36095      # from enum ksKompasCommandEnum
	ksCMAdditionNumberberManager  =40711      # from enum ksKompasCommandEnum
	ksCMAutoCreateSpcObj          =36097      # from enum ksKompasCommandEnum
	ksCMBuildTreeView             =37003      # from enum ksKompasCommandEnum
	ksCMCansel                    =33701      # from enum ksKompasCommandEnum
	ksCMChangeBilletPart          =40622      # from enum ksKompasCommandEnum
	ksCMChangeSelObjLayer         =35731      # from enum ksKompasCommandEnum
	ksCMChangeSelObjStyles        =35730      # from enum ksKompasCommandEnum
	ksCMCloseAll                  =33008      # from enum ksKompasCommandEnum
	ksCMCloseSpcSlave             =32408      # from enum ksKompasCommandEnum
	ksCMCloseTechnicalDemand      =32407      # from enum ksKompasCommandEnum
	ksCMContextHelp               =57669      # from enum ksKompasCommandEnum
	ksCMCpcShowExcludedObjects    =33911      # from enum ksKompasCommandEnum
	ksCMCreateLocalFragment       =35706      # from enum ksKompasCommandEnum
	ksCMCreateObject              =33700      # from enum ksKompasCommandEnum
	ksCMCreateSheetFromModel      =40373      # from enum ksKompasCommandEnum
	ksCMCreateSheetFromObject     =40723      # from enum ksKompasCommandEnum
	ksCMDelAuxCurves              =35739      # from enum ksKompasCommandEnum
	ksCMDelAuxCurvesInCurentView  =35740      # from enum ksKompasCommandEnum
	ksCMDelSpecRough              =35743      # from enum ksKompasCommandEnum
	ksCMDelStamp                  =35741      # from enum ksKompasCommandEnum
	ksCMDelTechnicalDemand        =35742      # from enum ksKompasCommandEnum
	ksCMDeleteRollbackObjects     =40375      # from enum ksKompasCommandEnum
	ksCMDestroyMacro              =35728      # from enum ksKompasCommandEnum
	ksCMDiscreteModeOnOff         =35747      # from enum ksKompasCommandEnum
	ksCMDocumentSetup             =32410      # from enum ksKompasCommandEnum
	ksCMEditBilletPart            =40621      # from enum ksKompasCommandEnum
	ksCMEditClear                 =57632      # from enum ksKompasCommandEnum
	ksCMEditClearAll              =57633      # from enum ksKompasCommandEnum
	ksCMEditCopy                  =57634      # from enum ksKompasCommandEnum
	ksCMEditCut                   =57635      # from enum ksKompasCommandEnum
	ksCMEditFind                  =57636      # from enum ksKompasCommandEnum
	ksCMEditFragment              =35705      # from enum ksKompasCommandEnum
	ksCMEditFragmentSource        =35707      # from enum ksKompasCommandEnum
	ksCMEditObject                =35736      # from enum ksKompasCommandEnum
	ksCMEditPaste                 =57637      # from enum ksKompasCommandEnum
	ksCMEditRedo                  =57644      # from enum ksKompasCommandEnum
	ksCMEditRepeat                =57640      # from enum ksKompasCommandEnum
	ksCMEditReplace               =57641      # from enum ksKompasCommandEnum
	ksCMEditSelectAll             =57642      # from enum ksKompasCommandEnum
	ksCMEditSpcObject             =36077      # from enum ksKompasCommandEnum
	ksCMEditSpcObjectForGeom      =36086      # from enum ksKompasCommandEnum
	ksCMEditUndo                  =57643      # from enum ksKompasCommandEnum
	ksCMEmbodimentManager         =40710      # from enum ksKompasCommandEnum
	ksCMEscape                    =33211      # from enum ksKompasCommandEnum
	ksCMFastLines                 =41891      # from enum ksKompasCommandEnum
	ksCMFileClose                 =57602      # from enum ksKompasCommandEnum
	ksCMFileNew                   =57600      # from enum ksKompasCommandEnum
	ksCMFileOpen                  =57601      # from enum ksKompasCommandEnum
	ksCMFilePrint                 =57607      # from enum ksKompasCommandEnum
	ksCMFilePrintPreview          =57609      # from enum ksKompasCommandEnum
	ksCMFilePrintSetup            =57606      # from enum ksKompasCommandEnum
	ksCMFileSave                  =57603      # from enum ksKompasCommandEnum
	ksCMFileSaveAs                =57604      # from enum ksKompasCommandEnum
	ksCMFileSendMail              =57612      # from enum ksKompasCommandEnum
	ksCMFragmentManager           =35704      # from enum ksKompasCommandEnum
	ksCMFullPageHeight            =33800      # from enum ksKompasCommandEnum
	ksCMFullPageWidth             =33801      # from enum ksKompasCommandEnum
	ksCMGoto00                    =36028      # from enum ksKompasCommandEnum
	ksCMGridOnOf                  =35746      # from enum ksKompasCommandEnum
	ksCMGridSetup                 =36090      # from enum ksKompasCommandEnum
	ksCMHelp                      =57670      # from enum ksKompasCommandEnum
	ksCMHelpFinder                =57667      # from enum ksKompasCommandEnum
	ksCMHelpIndex                 =57666      # from enum ksKompasCommandEnum
	ksCMHiddenRemovedMode         =41883      # from enum ksKompasCommandEnum
	ksCMHiddenThinMode            =41884      # from enum ksKompasCommandEnum
	ksCMHideAllObjects            =40368      # from enum ksKompasCommandEnum
	ksCMHideCAxies                =40362      # from enum ksKompasCommandEnum
	ksCMHideCPlaces               =40360      # from enum ksKompasCommandEnum
	ksCMHideCPlanes               =40361      # from enum ksKompasCommandEnum
	ksCMHideCurves                =40366      # from enum ksKompasCommandEnum
	ksCMHideDesignations          =40370      # from enum ksKompasCommandEnum
	ksCMHideDimensions            =40369      # from enum ksKompasCommandEnum
	ksCMHideInCompAllObjects      =40736      # from enum ksKompasCommandEnum
	ksCMHideInCompCAxies          =40730      # from enum ksKompasCommandEnum
	ksCMHideInCompCPlaces         =40728      # from enum ksKompasCommandEnum
	ksCMHideInCompCPlanes         =40729      # from enum ksKompasCommandEnum
	ksCMHideInCompCurves          =40734      # from enum ksKompasCommandEnum
	ksCMHideInCompDesignations    =40738      # from enum ksKompasCommandEnum
	ksCMHideInCompDimensions      =40737      # from enum ksKompasCommandEnum
	ksCMHideInCompPoints          =40735      # from enum ksKompasCommandEnum
	ksCMHideInCompSketches        =40731      # from enum ksKompasCommandEnum
	ksCMHideInCompSurfaces        =40732      # from enum ksKompasCommandEnum
	ksCMHideInCompThreads         =40733      # from enum ksKompasCommandEnum
	ksCMHidePoints                =40367      # from enum ksKompasCommandEnum
	ksCMHideSketches              =40363      # from enum ksKompasCommandEnum
	ksCMHideSurfaces              =40364      # from enum ksKompasCommandEnum
	ksCMHideThreads               =40365      # from enum ksKompasCommandEnum
	ksCMLODOn                     =40610      # from enum ksKompasCommandEnum
	ksCMLayoutManager             =35765      # from enum ksKompasCommandEnum
	ksCMLibraryBarVisible         =36104      # from enum ksKompasCommandEnum
	ksCMMakeMacro                 =35727      # from enum ksKompasCommandEnum
	ksCMMoveDocumentEX            =32522      # from enum ksKompasCommandEnum
	ksCMMoveDocumentFirst         =32523      # from enum ksKompasCommandEnum
	ksCMMoveDocumentLast          =32524      # from enum ksKompasCommandEnum
	ksCMMoveDocumentNext          =32526      # from enum ksKompasCommandEnum
	ksCMMoveDocumentPrev          =32525      # from enum ksKompasCommandEnum
	ksCMMoveView                  =32418      # from enum ksKompasCommandEnum
	ksCMObjStreamline             =35738      # from enum ksKompasCommandEnum
	ksCMOrthoModeOnOff            =35750      # from enum ksKompasCommandEnum
	ksCMPanoramaView              =32419      # from enum ksKompasCommandEnum
	ksCMParameters                =37608      # from enum ksKompasCommandEnum
	ksCMPerspective               =41886      # from enum ksKompasCommandEnum
	ksCMProcessBarVisible         =46541      # from enum ksKompasCommandEnum
	ksCMPropertyEditor            =45171      # from enum ksKompasCommandEnum
	ksCMRebuildSheet              =35751      # from enum ksKompasCommandEnum
	ksCMRefresh                   =32417      # from enum ksKompasCommandEnum
	ksCMRegulateLeaderLineX       =36075      # from enum ksKompasCommandEnum
	ksCMRegulateLeaderLineY       =36076      # from enum ksKompasCommandEnum
	ksCMRepeatFind                =33207      # from enum ksKompasCommandEnum
	ksCMRetryCommand              =32534      # from enum ksKompasCommandEnum
	ksCMRotate90CC                =41890      # from enum ksKompasCommandEnum
	ksCMRotate90CCW               =41889      # from enum ksKompasCommandEnum
	ksCMRotateCC                  =41888      # from enum ksKompasCommandEnum
	ksCMRotateCCW                 =41887      # from enum ksKompasCommandEnum
	ksCMRotateView                =32420      # from enum ksKompasCommandEnum
	ksCMSaveAll                   =32404      # from enum ksKompasCommandEnum
	ksCMSaveTechnicalDemand       =32405      # from enum ksKompasCommandEnum
	ksCMSaveTechnicalDemandToTxt  =32406      # from enum ksKompasCommandEnum
	ksCMScaleView                 =32414      # from enum ksKompasCommandEnum
	ksCMSelectByAttr              =35717      # from enum ksKompasCommandEnum
	ksCMSelectByCurveStyle        =35718      # from enum ksKompasCommandEnum
	ksCMSelectByType              =35713      # from enum ksKompasCommandEnum
	ksCMSelectGroup               =35711      # from enum ksKompasCommandEnum
	ksCMSelectLayer               =35712      # from enum ksKompasCommandEnum
	ksCMSelectPrevList            =35719      # from enum ksKompasCommandEnum
	ksCMSelectView                =35716      # from enum ksKompasCommandEnum
	ksCMSelectedCompanentInstanceProperties=40464      # from enum ksKompasCommandEnum
	ksCMSelectedCompanentProperties=40463      # from enum ksKompasCommandEnum
	ksCMSelectedObjectOwnerProperties=40462      # from enum ksKompasCommandEnum
	ksCMSelectedObjectProperties  =40461      # from enum ksKompasCommandEnum
	ksCMSetAttributeTypes         =32421      # from enum ksKompasCommandEnum
	ksCMSetCurveStyles            =32422      # from enum ksKompasCommandEnum
	ksCMSetGraphicShape           =32426      # from enum ksKompasCommandEnum
	ksCMSetHatchStyles            =32427      # from enum ksKompasCommandEnum
	ksCMSetProperties             =32541      # from enum ksKompasCommandEnum
	ksCMSetReportStyles           =32542      # from enum ksKompasCommandEnum
	ksCMSetSpcStyles              =32448      # from enum ksKompasCommandEnum
	ksCMSetStampStyles            =32424      # from enum ksKompasCommandEnum
	ksCMSetTextShape              =32425      # from enum ksKompasCommandEnum
	ksCMSetTextStyles             =32423      # from enum ksKompasCommandEnum
	ksCMShadedMode                =41885      # from enum ksKompasCommandEnum
	ksCMShadedWireframeMode       =41893      # from enum ksKompasCommandEnum
	ksCMSheetSpc                  =35764      # from enum ksKompasCommandEnum
	ksCMSheetViewParams           =35752      # from enum ksKompasCommandEnum
	ksCMSheetViewStates           =35744      # from enum ksKompasCommandEnum
	ksCMSlaveChangeList           =35756      # from enum ksKompasCommandEnum
	ksCMSlaveSpc                  =35755      # from enum ksKompasCommandEnum
	ksCMSlaveSpcDelegate          =36094      # from enum ksKompasCommandEnum
	ksCMSnapSetup                 =35749      # from enum ksKompasCommandEnum
	ksCMSnapSuspend               =35748      # from enum ksKompasCommandEnum
	ksCMSpcCopyObject             =33902      # from enum ksKompasCommandEnum
	ksCMSpcInsertIspoln           =33906      # from enum ksKompasCommandEnum
	ksCMSpcInsertLine             =33898      # from enum ksKompasCommandEnum
	ksCMSpcMakePosition           =33891      # from enum ksKompasCommandEnum
	ksCMSpcObjectDelete           =33892      # from enum ksKompasCommandEnum
	ksCMSpcObjectEdit             =33905      # from enum ksKompasCommandEnum
	ksCMSpcObjectInsert           =33893      # from enum ksKompasCommandEnum
	ksCMSpcObjectMoveDovn         =33904      # from enum ksKompasCommandEnum
	ksCMSpcObjectMoveUp           =33903      # from enum ksKompasCommandEnum
	ksCMSpcObjectsSort            =33796      # from enum ksKompasCommandEnum
	ksCMSpcOpenGeometryDocs       =33907      # from enum ksKompasCommandEnum
	ksCMSpcRebuild                =33797      # from enum ksKompasCommandEnum
	ksCMSpcShowAll                =33900      # from enum ksKompasCommandEnum
	ksCMSpcSinhronize             =35763      # from enum ksKompasCommandEnum
	ksCMSpcSynchronize            =33896      # from enum ksKompasCommandEnum
	ksCMSpcTuningSetup            =33901      # from enum ksKompasCommandEnum
	ksCMSpecRough                 =35754      # from enum ksKompasCommandEnum
	ksCMStop                      =33206      # from enum ksKompasCommandEnum
	ksCMStoreGroup                =35715      # from enum ksKompasCommandEnum
	ksCMSummaryInfo               =32440      # from enum ksKompasCommandEnum
	ksCMTechnicalDemand           =35753      # from enum ksKompasCommandEnum
	ksCMToggleCursor              =36029      # from enum ksKompasCommandEnum
	ksCMToggleToObjLayer          =35737      # from enum ksKompasCommandEnum
	ksCMTreeStructure             =41904      # from enum ksKompasCommandEnum
	ksCMTutor2D                   =32540      # from enum ksKompasCommandEnum
	ksCMTutor3D                   =32535      # from enum ksKompasCommandEnum
	ksCMUnSelectByAttr            =35724      # from enum ksKompasCommandEnum
	ksCMUnSelectByCurveStyle      =35725      # from enum ksKompasCommandEnum
	ksCMUnSelectByType            =35722      # from enum ksKompasCommandEnum
	ksCMUnSelectLayer             =35721      # from enum ksKompasCommandEnum
	ksCMUnSelectPrevList          =35726      # from enum ksKompasCommandEnum
	ksCMUnSelectSroup             =35720      # from enum ksKompasCommandEnum
	ksCMUnSelectView              =35723      # from enum ksKompasCommandEnum
	ksCMViewFeatureInTree         =40524      # from enum ksKompasCommandEnum
	ksCMViewFullScreen            =32403      # from enum ksKompasCommandEnum
	ksCMViewLayerStates           =35745      # from enum ksKompasCommandEnum
	ksCMViewObjAttr               =35729      # from enum ksKompasCommandEnum
	ksCMViewVariables             =32498      # from enum ksKompasCommandEnum
	ksCMWindowNew                 =57648      # from enum ksKompasCommandEnum
	ksCMWireframeMode             =41882      # from enum ksKompasCommandEnum
	ksCMZoom1                     =32545      # from enum ksKompasCommandEnum
	ksCMZoomEntireDocument        =32415      # from enum ksKompasCommandEnum
	ksCMZoomIn                    =32412      # from enum ksKompasCommandEnum
	ksCMZoomOut                   =32413      # from enum ksKompasCommandEnum
	ksCMZoomRedo                  =38531      # from enum ksKompasCommandEnum
	ksCMZoomSelected              =32416      # from enum ksKompasCommandEnum
	ksCMZoomSketch                =40872      # from enum ksKompasCommandEnum
	ksCMZoomUndo                  =38530      # from enum ksKompasCommandEnum
	ksCMZoomWindow                =32411      # from enum ksKompasCommandEnum
	ksCMaximizeWorkArea           =37079      # from enum ksKompasCommandEnum
	ksClearAttachedLeaders        =37186      # from enum ksKompasCommandEnum
	ksEditDocumentProperties      =37171      # from enum ksKompasCommandEnum
	ksEditInserionFragmentProperties=37172      # from enum ksKompasCommandEnum
	ksEditInserionViewProperties  =37173      # from enum ksKompasCommandEnum
	ksEditMacroObjectProperties   =37174      # from enum ksKompasCommandEnum
	ksPrintSpecialExecute         =37289      # from enum ksKompasCommandEnum
	ksSheetViewParams             =37005      # from enum ksKompasCommandEnum
	ksViewShowBreakups            =39344      # from enum ksKompasCommandEnum
	ksKompasExport                =101        # from enum ksKompasModuleEnum
	ksKompasModule2D              =1          # from enum ksKompasModuleEnum
	ksKompasModule3D              =2          # from enum ksKompasModuleEnum
	ksKompasPrint                 =100        # from enum ksKompasModuleEnum
	koApplicatinDestroy           =5          # from enum ksKompasObjectNotifyEnum
	koBeginChoiceMaterial         =13         # from enum ksKompasObjectNotifyEnum
	koBeginCloseAllDocument       =8          # from enum ksKompasObjectNotifyEnum
	koBeginConvertToSavePrevious  =16         # from enum ksKompasObjectNotifyEnum
	koBeginCreate                 =6          # from enum ksKompasObjectNotifyEnum
	koBeginOpenDocument           =2          # from enum ksKompasObjectNotifyEnum
	koBeginOpenFile               =7          # from enum ksKompasObjectNotifyEnum
	koBeginRequestFiles           =12         # from enum ksKompasObjectNotifyEnum
	koChangeActiveDocument        =4          # from enum ksKompasObjectNotifyEnum
	koChangeTheme                 =18         # from enum ksKompasObjectNotifyEnum
	koChoiceMaterial              =14         # from enum ksKompasObjectNotifyEnum
	koCreateDocument              =1          # from enum ksKompasObjectNotifyEnum
	koEndConvertToSavePrevious    =17         # from enum ksKompasObjectNotifyEnum
	koIsNeedConvertToSavePrevious =15         # from enum ksKompasObjectNotifyEnum
	koKeyDown                     =9          # from enum ksKompasObjectNotifyEnum
	koKeyPress                    =11         # from enum ksKompasObjectNotifyEnum
	koKeyUp                       =10         # from enum ksKompasObjectNotifyEnum
	koOpenDocument                =3          # from enum ksKompasObjectNotifyEnum
	ksKompasConsumer              =4096       # from enum ksKompasVariantEnum
	ksKompasGraphic               =256        # from enum ksKompasVariantEnum
	ksKompasHome                  =1          # from enum ksKompasVariantEnum
	ksKompasInvisible             =512        # from enum ksKompasVariantEnum
	ksKompasLatin                 =1024       # from enum ksKompasVariantEnum
	ksKompasPro                   =0          # from enum ksKompasVariantEnum
	ksKompasSpds                  =4          # from enum ksKompasVariantEnum
	ksKompasStudy                 =8192       # from enum ksKompasVariantEnum
	ksKompasViewer                =2          # from enum ksKompasVariantEnum
	ksLayoutAdd                   =1          # from enum ksLayoutSheetsNotifyEnum
	ksLayoutDelete                =2          # from enum ksLayoutSheetsNotifyEnum
	ksLayoutUpdate                =3          # from enum ksLayoutSheetsNotifyEnum
	ksLCrampSign                  =4          # from enum ksLeaderSignEnum
	ksLGlueSign                   =1          # from enum ksLeaderSignEnum
	ksLMontageJointSign           =6          # from enum ksLeaderSignEnum
	ksLSewingSign                 =3          # from enum ksLeaderSignEnum
	ksLSignNone                   =0          # from enum ksLeaderSignEnum
	ksLSolderingSign              =2          # from enum ksLeaderSignEnum
	ksLcornerCrampSign            =5          # from enum ksLeaderSignEnum
	ksLUCentimetres               =1          # from enum ksLengthUnitEnum
	ksLUDecimetres                =2          # from enum ksLengthUnitEnum
	ksLUKilometres                =4          # from enum ksLengthUnitEnum
	ksLUMetres                    =3          # from enum ksLengthUnitEnum
	ksLUMillimetres               =0          # from enum ksLengthUnitEnum
	ksLUnDM                       =2          # from enum ksLengthUnitsEnum
	ksLUnDocument                 =4          # from enum ksLengthUnitsEnum
	ksLUnM                        =3          # from enum ksLengthUnitsEnum
	ksLUnMM                       =1          # from enum ksLengthUnitsEnum
	ksLUnSM                       =0          # from enum ksLengthUnitsEnum
	ksLMAddInsert                 =11         # from enum ksLibraryManagerNotifyEnum
	ksLMAddLibraryDescription     =9          # from enum ksLibraryManagerNotifyEnum
	ksLMAttach                    =2          # from enum ksLibraryManagerNotifyEnum
	ksLMBeginAttach               =1          # from enum ksLibraryManagerNotifyEnum
	ksLMBeginDetach               =3          # from enum ksLibraryManagerNotifyEnum
	ksLMBeginExecute              =5          # from enum ksLibraryManagerNotifyEnum
	ksLMBeginInsertDocument       =15         # from enum ksLibraryManagerNotifyEnum
	ksLMDeleteInsert              =12         # from enum ksLibraryManagerNotifyEnum
	ksLMDeleteLibraryDescription  =10         # from enum ksLibraryManagerNotifyEnum
	ksLMDetach                    =4          # from enum ksLibraryManagerNotifyEnum
	ksLMEditInsert                =13         # from enum ksLibraryManagerNotifyEnum
	ksLMEndExecute                =6          # from enum ksLibraryManagerNotifyEnum
	ksLMSystemControlStart        =8          # from enum ksLibraryManagerNotifyEnum
	ksLMSystemControlStop         =7          # from enum ksLibraryManagerNotifyEnum
	ksLMTryExecute                =14         # from enum ksLibraryManagerNotifyEnum
	ksLibraryStyleBar             =4          # from enum ksLibraryStyleEnum
	ksLibraryStyleDialog          =2          # from enum ksLibraryStyleEnum
	ksLibraryStyleInvisible       =5          # from enum ksLibraryStyleEnum
	ksLibraryStyleMenu            =1          # from enum ksLibraryStyleEnum
	ksLibraryStyleUnknown         =0          # from enum ksLibraryStyleEnum
	ksLibraryStyleWindow          =3          # from enum ksLibraryStyleEnum
	ksLibraryDocuments            =4          # from enum ksLibraryTypeEnum
	ksLibraryFragment             =2          # from enum ksLibraryTypeEnum
	ksLibraryModel                =3          # from enum ksLibraryTypeEnum
	ksLibraryProcedure            =1          # from enum ksLibraryTypeEnum
	ksLibraryUnknown              =0          # from enum ksLibraryTypeEnum
	ksLinDHorizontal              =1          # from enum ksLineDimensionOrientationEnum
	ksLinDParallel                =0          # from enum ksLineDimensionOrientationEnum
	ksLinDVertical                =2          # from enum ksLineDimensionOrientationEnum
	ksMFormChamferedRectangle     =9          # from enum ksMarkInsideFormEnum
	ksMFormCircle                 =1          # from enum ksMarkInsideFormEnum
	ksMFormCircleWidthVerticalDelimer=10         # from enum ksMarkInsideFormEnum
	ksMFormCirle                  =1          # from enum ksMarkInsideFormEnum
	ksMFormDoubleCircle           =11         # from enum ksMarkInsideFormEnum
	ksMFormEmpty                  =0          # from enum ksMarkInsideFormEnum
	ksMFormHexagon                =6          # from enum ksMarkInsideFormEnum
	ksMFormRectangle              =2          # from enum ksMarkInsideFormEnum
	ksMFormRhomb1                 =4          # from enum ksMarkInsideFormEnum
	ksMFormRhomb2                 =5          # from enum ksMarkInsideFormEnum
	ksMFormSquare                 =3          # from enum ksMarkInsideFormEnum
	ksMFormTriangle1              =7          # from enum ksMarkInsideFormEnum
	ksMFormTriangle2              =8          # from enum ksMarkInsideFormEnum
	ksMarkCircle                  =0          # from enum ksMarkNodeEnum
	ksMarkRefCircle               =1          # from enum ksMarkNodeEnum
	ksMarkText                    =2          # from enum ksMarkNodeEnum
	ksMTextAboveLine              =0          # from enum ksMarkOnLinePosTypeEnum
	ksMTextOnLine                 =1          # from enum ksMarkOnLinePosTypeEnum
	ksMTextUnderLine              =2          # from enum ksMarkOnLinePosTypeEnum
	ksCalculateParam              =0          # from enum ksMassSettingModeEnum
	ksManualMass                  =1          # from enum ksMassSettingModeEnum
	ksMUnDocument                 =4          # from enum ksMassUnitsEnum
	ksMUnGR                       =0          # from enum ksMassUnitsEnum
	ksMUnKG                       =1          # from enum ksMassUnitsEnum
	ksMPNewPartDocumentSettings   =1          # from enum ksMaterialPropertyTypeEnum
	ksMEndArc                     =2          # from enum ksMlEndLimiterEnum
	ksMEndLine                    =1          # from enum ksMlEndLimiterEnum
	ksMEndPolyline                =3          # from enum ksMlEndLimiterEnum
	ksMEndUnknown                 =0          # from enum ksMlEndLimiterEnum
	ksMVeAngle                    =2          # from enum ksMlVertexLimiterEnum
	ksMVeArc                      =1          # from enum ksMlVertexLimiterEnum
	ksMVeTangent                  =3          # from enum ksMlVertexLimiterEnum
	ksMVeUnknown                  =0          # from enum ksMlVertexLimiterEnum
	ksMTrEquaFillet               =2          # from enum ksMlVertexTrackingEnum
	ksMTrFillet                   =1          # from enum ksMlVertexTrackingEnum
	ksMTrShear                    =0          # from enum ksMlVertexTrackingEnum
	ksMPLDisabledAntialiasing     =0          # from enum ksModelPerformanceLevelEnum
	ksMPLHightAntialiasing        =3          # from enum ksModelPerformanceLevelEnum
	ksMPLLowAntialiasing          =1          # from enum ksModelPerformanceLevelEnum
	ksMPLNormalAntialiasing       =2          # from enum ksModelPerformanceLevelEnum
	ksModelRenderAuto             =0          # from enum ksModelRenderTypeEnum
	ksModelRenderLow              =3          # from enum ksModelRenderTypeEnum
	ksModelRenderMedium           =2          # from enum ksModelRenderTypeEnum
	ksModelRenderNone             =-1         # from enum ksModelRenderTypeEnum
	ksModelRenderPerfected        =1          # from enum ksModelRenderTypeEnum
	ksModelTransparencyMesh       =0          # from enum ksModelTransparencyTypeEnum
	ksModelTransparencyRealistic  =1          # from enum ksModelTransparencyTypeEnum
	ksNewPartDocumentSettings     =1          # from enum ksNewDocumentSettingsTypeEnum
	ntContentDialogNotify         =20         # from enum ksNotifyType
	ntDocument2DNotify            =11         # from enum ksNotifyType
	ntDocument3DNotify            =9          # from enum ksNotifyType
	ntDocumentFileNotify          =2          # from enum ksNotifyType
	ntDocumentFrameNotify         =14         # from enum ksNotifyType
	ntFindObject3DParametersNotify=24         # from enum ksNotifyType
	ntFindObjectParametersNotify  =21         # from enum ksNotifyType
	ntKompasObjectNotify          =1          # from enum ksNotifyType
	ntLayoutSheetsNotify          =17         # from enum ksNotifyType
	ntLibraryManagerNotify        =16         # from enum ksNotifyType
	ntObject2DNotify              =4          # from enum ksNotifyType
	ntObject3DNotify              =10         # from enum ksNotifyType
	ntPLMObjectNotify             =23         # from enum ksNotifyType
	ntProcess2DNotify             =18         # from enum ksNotifyType
	ntProcess3DManipulatorsNotify =22         # from enum ksNotifyType
	ntProcess3DNotify             =19         # from enum ksNotifyType
	ntPropertyManagerNotify       =12         # from enum ksNotifyType
	ntPropertyUserControlNotifyEnum=13         # from enum ksNotifyType
	ntSelectionMngNotify          =5          # from enum ksNotifyType
	ntSpcDocumentNotify           =7          # from enum ksNotifyType
	ntSpcObjectNotify             =6          # from enum ksNotifyType
	ntSpecificationNotify         =8          # from enum ksNotifyType
	ntStampNotify                 =3          # from enum ksNotifyType
	ntViewsAndLayersManagerNotify =15         # from enum ksNotifyType
	ksNTArabicNumerals            =0          # from enum ksNumberingTypeEnum
	ksNTLowerRegEnglish           =3          # from enum ksNumberingTypeEnum
	ksNTLowerRegRussian           =5          # from enum ksNumberingTypeEnum
	ksNTRomanNumerals             =1          # from enum ksNumberingTypeEnum
	ksNTUpperRegEnglish           =2          # from enum ksNumberingTypeEnum
	ksNTUpperRegRussian           =4          # from enum ksNumberingTypeEnum
	ksNumericGroupNumbers         =0          # from enum ksNumericGroupTypeEnum
	ksNumericGroupSymbols         =1          # from enum ksNumericGroupTypeEnum
	ksNBPAproximationStepByCurvature=0          # from enum ksNurbsByPointsAproximationTypeEnum
	ksNBPAproximationStepByDeviation=1          # from enum ksNurbsByPointsAproximationTypeEnum
	ksNByPBCentripetal            =3          # from enum ksNurbsByPointsBuildingTypeEnum
	ksNByPBChordLength            =2          # from enum ksNurbsByPointsBuildingTypeEnum
	ksNByPBLinear                 =1          # from enum ksNurbsByPointsBuildingTypeEnum
	ksNByPBTUndefined             =0          # from enum ksNurbsByPointsBuildingTypeEnum
	ksNByPBPCNone                 =0          # from enum ksNurbsByPointsPointConstraintsEnum
	ksNByPBPCNormal               =3          # from enum ksNurbsByPointsPointConstraintsEnum
	ksNByPBPCSmoothG2             =2          # from enum ksNurbsByPointsPointConstraintsEnum
	ksNByPBPCTangent              =1          # from enum ksNurbsByPointsPointConstraintsEnum
	koBeginCopy                   =12         # from enum ksObject2DNotifyEnum
	koBeginDelete                 =2          # from enum ksObject2DNotifyEnum
	koBeginDestroyObject          =20         # from enum ksObject2DNotifyEnum
	koBeginMove                   =4          # from enum ksObject2DNotifyEnum
	koBeginProcess                =16         # from enum ksObject2DNotifyEnum
	koBeginPropertyChanged        =22         # from enum ksObject2DNotifyEnum
	koBeginRotate                 =6          # from enum ksObject2DNotifyEnum
	koBeginScale                  =8          # from enum ksObject2DNotifyEnum
	koBeginSymmetry               =14         # from enum ksObject2DNotifyEnum
	koBeginTransform              =10         # from enum ksObject2DNotifyEnum
	koChangeActive                =1          # from enum ksObject2DNotifyEnum
	koCopy                        =13         # from enum ksObject2DNotifyEnum
	koCreateObject                =18         # from enum ksObject2DNotifyEnum
	koDelete                      =3          # from enum ksObject2DNotifyEnum
	koDestroyObject               =21         # from enum ksObject2DNotifyEnum
	koEndProcess                  =17         # from enum ksObject2DNotifyEnum
	koMove                        =5          # from enum ksObject2DNotifyEnum
	koPropertyChanged             =23         # from enum ksObject2DNotifyEnum
	koRotate                      =7          # from enum ksObject2DNotifyEnum
	koScale                       =9          # from enum ksObject2DNotifyEnum
	koSymmetry                    =15         # from enum ksObject2DNotifyEnum
	koTransform                   =11         # from enum ksObject2DNotifyEnum
	koUpdateObject                =19         # from enum ksObject2DNotifyEnum
	o3BeginDelete                 =1          # from enum ksObject3DNotifyEnum
	o3BeginLoadStateChange        =13         # from enum ksObject3DNotifyEnum
	o3BeginPlacementChanged       =7          # from enum ksObject3DNotifyEnum
	o3BeginProcess                =9          # from enum ksObject3DNotifyEnum
	o3BeginPropertyChanged        =5          # from enum ksObject3DNotifyEnum
	o3CreateObject                =11         # from enum ksObject3DNotifyEnum
	o3Delete                      =2          # from enum ksObject3DNotifyEnum
	o3EndProcess                  =10         # from enum ksObject3DNotifyEnum
	o3Excluded                    =3          # from enum ksObject3DNotifyEnum
	o3Hidden                      =4          # from enum ksObject3DNotifyEnum
	o3LoadStateChange             =14         # from enum ksObject3DNotifyEnum
	o3PlacementChanged            =8          # from enum ksObject3DNotifyEnum
	o3PropertyChanged             =6          # from enum ksObject3DNotifyEnum
	o3UpdateObject                =12         # from enum ksObject3DNotifyEnum
	ksOPControlColor              =6          # from enum ksObjectPropertyControlTypeEnum
	ksOPControlEdit               =31         # from enum ksObjectPropertyControlTypeEnum
	ksOPControlEditDouble         =7          # from enum ksObjectPropertyControlTypeEnum
	ksOPControlEditInt            =10         # from enum ksObjectPropertyControlTypeEnum
	ksOPControlExternalEdit       =34         # from enum ksObjectPropertyControlTypeEnum
	ksOPControlExternalMultyText  =45         # from enum ksObjectPropertyControlTypeEnum
	ksOPControlExternalStringEdit =35         # from enum ksObjectPropertyControlTypeEnum
	ksOPControlExternalText       =44         # from enum ksObjectPropertyControlTypeEnum
	ksOPControlFontImageList      =38         # from enum ksObjectPropertyControlTypeEnum
	ksOPControlGroup              =0          # from enum ksObjectPropertyControlTypeEnum
	ksOPControlHatchStyle         =5          # from enum ksObjectPropertyControlTypeEnum
	ksOPControlLineStyle          =4          # from enum ksObjectPropertyControlTypeEnum
	ksOPControlListBmp            =16         # from enum ksObjectPropertyControlTypeEnum
	ksOPControlListCheck          =15         # from enum ksObjectPropertyControlTypeEnum
	ksOPControlListDouble         =11         # from enum ksObjectPropertyControlTypeEnum
	ksOPControlListInt            =14         # from enum ksObjectPropertyControlTypeEnum
	ksOPControlListString         =17         # from enum ksObjectPropertyControlTypeEnum
	ksOPControlPointCoord         =1          # from enum ksObjectPropertyControlTypeEnum
	ksOPControlPointStyle         =2          # from enum ksObjectPropertyControlTypeEnum
	ksOPControlSimpleText         =19         # from enum ksObjectPropertyControlTypeEnum
	ksOPControlText               =25         # from enum ksObjectPropertyControlTypeEnum
	ksOPControlUserLineStyle      =47         # from enum ksObjectPropertyControlTypeEnum
	ksPJ_OCBlack                  =0          # from enum ksOutputColorTypeEnum
	ksPJ_OCByLayer                =2          # from enum ksOutputColorTypeEnum
	ksPJ_OCByObject               =3          # from enum ksOutputColorTypeEnum
	ksPJ_OCByView                 =1          # from enum ksOutputColorTypeEnum
	ksPLMChangeUndefined          =0          # from enum ksPLMChangesEnum
	ksPLMChangesNotCommited       =2          # from enum ksPLMChangesEnum
	ksPLMConflict                 =4          # from enum ksPLMChangesEnum
	ksPLMNoChanges                =1          # from enum ksPLMChangesEnum
	ksPLMUpdateNeeded             =3          # from enum ksPLMChangesEnum
	ksPLMChangeChanged            =1002       # from enum ksPLMObjectNotifyEnum
	ksPLMStatusChanged            =1001       # from enum ksPLMObjectNotifyEnum
	ksPLMStateAvailable           =2          # from enum ksPLMStatusEnum
	ksPLMStateBlocked             =4          # from enum ksPLMStatusEnum
	ksPLMStateError               =5          # from enum ksPLMStatusEnum
	ksPLMStateInProgress          =3          # from enum ksPLMStatusEnum
	ksPLMStateNotRegistered       =1          # from enum ksPLMStatusEnum
	ksPLMStateUndefined           =0          # from enum ksPLMStatusEnum
	ksRPLayout1                   =1          # from enum ksPageLayoutTypeEnum
	ksRPLayoutDefault             =0          # from enum ksPageLayoutTypeEnum
	ksAngleLineSegPhantom         =4          # from enum ksPhantomTypeEnum
	ksCirclePhantom               =7          # from enum ksPhantomTypeEnum
	ksHalfRectanglePhantom        =5          # from enum ksPhantomTypeEnum
	ksLineSegPhantom              =2          # from enum ksPhantomTypeEnum
	ksMoveGroupPhantom            =1          # from enum ksPhantomTypeEnum
	ksRectanglePhantom            =3          # from enum ksPhantomTypeEnum
	ksUnknownPhantom              =0          # from enum ksPhantomTypeEnum
	ksUserPhantom                 =6          # from enum ksPhantomTypeEnum
	ksLPInside                    =3          # from enum ksPointLocationTypeEnum
	ksPLOnCurve                   =2          # from enum ksPointLocationTypeEnum
	ksPLOutside                   =1          # from enum ksPointLocationTypeEnum
	ksPLUndefined                 =0          # from enum ksPointLocationTypeEnum
	ksPLCircle                    =2          # from enum ksPositionLederFormEnum
	ksPLCircleWithSeparator       =4          # from enum ksPositionLederFormEnum
	ksPLHexagon                   =3          # from enum ksPositionLederFormEnum
	ksPLOpenText                  =1          # from enum ksPositionLederFormEnum
	ksPLSingleText                =0          # from enum ksPositionLederFormEnum
	ksPTPrintPreviewPrinter       =0          # from enum ksPrinterTypeEnum
	ksPTSpecialPrinter            =1          # from enum ksPrinterTypeEnum
	ksProcess2DAbortProcess       =9          # from enum ksProcess2DNotifyEnum
	ksProcess2DActivate           =5          # from enum ksProcess2DNotifyEnum
	ksProcess2DDeactivate         =6          # from enum ksProcess2DNotifyEnum
	ksProcess2DEndProcess         =7          # from enum ksProcess2DNotifyEnum
	ksProcess2DExecuteCommand     =2          # from enum ksProcess2DNotifyEnum
	ksProcess2DMouseEnterLeaveParam=8          # from enum ksProcess2DNotifyEnum
	ksProcess2DPlacementChanged   =1          # from enum ksProcess2DNotifyEnum
	ksProcess2DRun                =3          # from enum ksProcess2DNotifyEnum
	ksProcess2DStop               =4          # from enum ksProcess2DNotifyEnum
	ksProcess2DCursor             =1          # from enum ksProcess2DTypeEnum
	ksProcess2DPlacement          =2          # from enum ksProcess2DTypeEnum
	ksBeginDragManipulator        =4          # from enum ksProcess3DManipulatorsNotifyEnum
	ksChangeManipulatorValue      =8          # from enum ksProcess3DManipulatorsNotifyEnum
	ksClickManipulatorPrimitive   =3          # from enum ksProcess3DManipulatorsNotifyEnum
	ksCreateManipulatorEdit       =6          # from enum ksProcess3DManipulatorsNotifyEnum
	ksDestroyManipulatorEdit      =7          # from enum ksProcess3DManipulatorsNotifyEnum
	ksEndDragManipulator          =5          # from enum ksProcess3DManipulatorsNotifyEnum
	ksMoveManipulator             =2          # from enum ksProcess3DManipulatorsNotifyEnum
	ksRotateManipulator           =1          # from enum ksProcess3DManipulatorsNotifyEnum
	ksProcess3DAbortProcess       =11         # from enum ksProcess3DNotifyEnum
	ksProcess3DActivate           =5          # from enum ksProcess3DNotifyEnum
	ksProcess3DCreateTakeObject   =8          # from enum ksProcess3DNotifyEnum
	ksProcess3DDeactivate         =6          # from enum ksProcess3DNotifyEnum
	ksProcess3DEndProcess         =9          # from enum ksProcess3DNotifyEnum
	ksProcess3DExecuteCommand     =2          # from enum ksProcess3DNotifyEnum
	ksProcess3DFilterObjects      =7          # from enum ksProcess3DNotifyEnum
	ksProcess3DPlacementChanged   =1          # from enum ksProcess3DNotifyEnum
	ksProcess3DProcessingGroupObjects=10         # from enum ksProcess3DNotifyEnum
	ksProcess3DRun                =3          # from enum ksProcess3DNotifyEnum
	ksProcess3DStop               =4          # from enum ksProcess3DNotifyEnum
	ksProcess3DPlacementAndEntity =1          # from enum ksProcess3DTypeEnum
	ksProcess3DSelectEntity       =2          # from enum ksProcess3DTypeEnum
	ksProcessContextIconMenu      =-4         # from enum ksProcessContextMenuType
	ksProcessContextMenuHide      =-2         # from enum ksProcessContextMenuType
	ksProcessContextPanel         =-3         # from enum ksProcessContextMenuType
	ksProcessDefaultContextMenu   =0          # from enum ksProcessContextMenuType
	ksPOTAllObjects               =-1         # from enum ksProductObjectTypeEnum
	ksPOTBodyObject               =8          # from enum ksProductObjectTypeEnum
	ksPOTDocumentObject           =1          # from enum ksProductObjectTypeEnum
	ksPOTEmbodimentsObject        =2          # from enum ksProductObjectTypeEnum
	ksPOTInformObject             =32         # from enum ksProductObjectTypeEnum
	ksPOTPartObject               =4          # from enum ksProductObjectTypeEnum
	ksPOTProductObject            =16         # from enum ksProductObjectTypeEnum
	ksPOTSurfaceObject            =64         # from enum ksProductObjectTypeEnum
	prButtonClick                 =1          # from enum ksPropertyManagerNotifyEnum
	prButtonUpdate                =4          # from enum ksPropertyManagerNotifyEnum
	prChangeActiveTab             =10         # from enum ksPropertyManagerNotifyEnum
	prChangeControlValue          =2          # from enum ksPropertyManagerNotifyEnum
	prChangeTabExpanded           =18         # from enum ksPropertyManagerNotifyEnum
	prCheckItem                   =9          # from enum ksPropertyManagerNotifyEnum
	prCommandHelp                 =7          # from enum ksPropertyManagerNotifyEnum
	prControlCommand              =3          # from enum ksPropertyManagerNotifyEnum
	prEditFocus                   =11         # from enum ksPropertyManagerNotifyEnum
	prEndEditItem                 =17         # from enum ksPropertyManagerNotifyEnum
	prFillContextIconMenu         =16         # from enum ksPropertyManagerNotifyEnum
	prFillContextPanel            =15         # from enum ksPropertyManagerNotifyEnum
	prGetContextMenuType          =14         # from enum ksPropertyManagerNotifyEnum
	prItemDblClick                =19         # from enum ksPropertyManagerNotifyEnum
	prLayoutChanged               =13         # from enum ksPropertyManagerNotifyEnum
	prProcessActivate             =5          # from enum ksPropertyManagerNotifyEnum
	prProcessDeactivate           =6          # from enum ksPropertyManagerNotifyEnum
	prSelectItem                  =8          # from enum ksPropertyManagerNotifyEnum
	prUserMenuCommand             =12         # from enum ksPropertyManagerNotifyEnum
	ksPropertyDataTypeBoolean     =4          # from enum ksPropertyTypeEnum
	ksPropertyDataTypeColorRGB    =5          # from enum ksPropertyTypeEnum
	ksPropertyDataTypeDouble      =2          # from enum ksPropertyTypeEnum
	ksPropertyDataTypeGroup       =7          # from enum ksPropertyTypeEnum
	ksPropertyDataTypeHatchStyle  =6          # from enum ksPropertyTypeEnum
	ksPropertyDataTypeLong        =1          # from enum ksPropertyTypeEnum
	ksPropertyDataTypeString      =3          # from enum ksPropertyTypeEnum
	ksPropertyDataTypeUnknown     =0          # from enum ksPropertyTypeEnum
	puCreateOCX                   =1          # from enum ksPropertyUserControlNotifyEnum
	puDestroyOCX                  =2          # from enum ksPropertyUserControlNotifyEnum
	ksProtectDemo                 =1          # from enum ksProtectProductStatusEnum
	ksProtectDisabled             =2          # from enum ksProtectProductStatusEnum
	ksProtectExpired              =3          # from enum ksProtectProductStatusEnum
	ksProtectFailed               =5          # from enum ksProtectProductStatusEnum
	ksProtectNormal               =4          # from enum ksProtectProductStatusEnum
	ksProtectUnknown              =0          # from enum ksProtectProductStatusEnum
	ksRAlreadyOpen                =3          # from enum ksRecoverErrorEnum
	ksRNoError                    =0          # from enum ksRecoverErrorEnum
	ksRNoOpen                     =2          # from enum ksRecoverErrorEnum
	ksRProtected                  =4          # from enum ksRecoverErrorEnum
	ksRecover                     =1          # from enum ksRecoverErrorEnum
	ksRedrawAnimation             =1          # from enum ksRedrawDocumentModeEnum
	ksRedrawDimensions            =4          # from enum ksRedrawDocumentModeEnum
	ksRedrawFull                  =0          # from enum ksRedrawDocumentModeEnum
	ksRedrawHighlightObjects      =6          # from enum ksRedrawDocumentModeEnum
	ksRedrawOperationPhantom      =3          # from enum ksRedrawDocumentModeEnum
	ksRedrawPhantomObjects        =5          # from enum ksRedrawDocumentModeEnum
	ksRedrawSelection             =2          # from enum ksRedrawDocumentModeEnum
	ksRedrawWidgets               =7          # from enum ksRedrawDocumentModeEnum
	ksRTCutFrame                  =3          # from enum ksRegionTypeEnum
	ksRTInside                    =1          # from enum ksRegionTypeEnum
	ksRTOutside                   =2          # from enum ksRegionTypeEnum
	ksPtDown                      =4          # from enum ksRelativeProjectionTypeEnum
	ksPtFront                     =1          # from enum ksRelativeProjectionTypeEnum
	ksPtIsoXYZ                    =7          # from enum ksRelativeProjectionTypeEnum
	ksPtLeft                      =5          # from enum ksRelativeProjectionTypeEnum
	ksPtNone                      =-1         # from enum ksRelativeProjectionTypeEnum
	ksPtRear                      =2          # from enum ksRelativeProjectionTypeEnum
	ksPtRight                     =6          # from enum ksRelativeProjectionTypeEnum
	ksPtUp                        =3          # from enum ksRelativeProjectionTypeEnum
	ksRBAllObjects                =0          # from enum ksReportBuildingTypeEnum
	ksRBChoiceToLevel             =3          # from enum ksReportBuildingTypeEnum
	ksRBChooseObjects             =1          # from enum ksReportBuildingTypeEnum
	ksRBCurrentView               =2          # from enum ksReportBuildingTypeEnum
	ksFilterConditionContain      =6          # from enum ksReportFiltersTypeEnum
	ksFilterConditionEqual        =1          # from enum ksReportFiltersTypeEnum
	ksFilterConditionEqualOrLarger=5          # from enum ksReportFiltersTypeEnum
	ksFilterConditionEqualOrSmaller=4          # from enum ksReportFiltersTypeEnum
	ksFilterConditionLarger       =3          # from enum ksReportFiltersTypeEnum
	ksFilterConditionNotContain   =7          # from enum ksReportFiltersTypeEnum
	ksFilterConditionSmaller      =2          # from enum ksReportFiltersTypeEnum
	ksFilterConditionUnknown      =0          # from enum ksReportFiltersTypeEnum
	ksRSIDefault                  =0          # from enum ksReportStyleInitEnum
	ksRTAdditionNumbersReport     =3          # from enum ksReportTypeEnum
	ksRTEmbodimentsReport         =1          # from enum ksReportTypeEnum
	ksRTPatternWithVariablesTableReport=2          # from enum ksReportTypeEnum
	ksRTPropertiesReport          =0          # from enum ksReportTypeEnum
	koRFAddAssembly               =6          # from enum ksRequestFilesTypeEnum
	koRFAddDetail                 =5          # from enum ksRequestFilesTypeEnum
	koRFAddLayoutGeometry         =14         # from enum ksRequestFilesTypeEnum
	koRFAddLocalDetail            =13         # from enum ksRequestFilesTypeEnum
	koRFAddPartFromFile           =7          # from enum ksRequestFilesTypeEnum
	koRFChangeAssemblyFile        =9          # from enum ksRequestFilesTypeEnum
	koRFChangeBilletPartFile      =10         # from enum ksRequestFilesTypeEnum
	koRFChangeDetailFile          =8          # from enum ksRequestFilesTypeEnum
	koRFCopyBilletPart            =3          # from enum ksRequestFilesTypeEnum
	koRFSavePartAs                =4          # from enum ksRequestFilesTypeEnum
	koRFSelectCopyGeometryFile    =16         # from enum ksRequestFilesTypeEnum
	koRFSelectDummyFile           =15         # from enum ksRequestFilesTypeEnum
	koRFSelectModelForAssociationView=17         # from enum ksRequestFilesTypeEnum
	koRFSelectModelForStandartAssociationView=18         # from enum ksRequestFilesTypeEnum
	koRFSpcAssemblyAddDocument    =12         # from enum ksRequestFilesTypeEnum
	koRFSpcObjAddDocument         =11         # from enum ksRequestFilesTypeEnum
	koRFUnitParts                 =2          # from enum ksRequestFilesTypeEnum
	ksRFSaveBody                  =1          # from enum ksRequestFilesTypeEnum
	ksRFUnknown                   =0          # from enum ksRequestFilesTypeEnum
	ksDeleteMaterial              =1          # from enum ksRoughSignEnum
	ksNoProcessingType            =0          # from enum ksRoughSignEnum
	ksWithoutDeleteMaterial       =2          # from enum ksRoughSignEnum
	ksRNTMultiLevel               =2          # from enum ksRowsNumberingTypeEnum
	ksRNTNone                     =0          # from enum ksRowsNumberingTypeEnum
	ksRNTSimple                   =1          # from enum ksRowsNumberingTypeEnum
	ksSDV_Current                 =0          # from enum ksSaveDocumentVersionEnum
	ksSDV_Kompas_10_0             =9          # from enum ksSaveDocumentVersionEnum
	ksSDV_Kompas_11_0             =10         # from enum ksSaveDocumentVersionEnum
	ksSDV_Kompas_12_0             =11         # from enum ksSaveDocumentVersionEnum
	ksSDV_Kompas_13_0             =12         # from enum ksSaveDocumentVersionEnum
	ksSDV_Kompas_14_0             =13         # from enum ksSaveDocumentVersionEnum
	ksSDV_Kompas_14_Sp1           =14         # from enum ksSaveDocumentVersionEnum
	ksSDV_Kompas_14_Sp2           =15         # from enum ksSaveDocumentVersionEnum
	ksSDV_Kompas_15_0             =16         # from enum ksSaveDocumentVersionEnum
	ksSDV_Kompas_15_Sp1           =17         # from enum ksSaveDocumentVersionEnum
	ksSDV_Kompas_15_Sp2           =18         # from enum ksSaveDocumentVersionEnum
	ksSDV_Kompas_16               =19         # from enum ksSaveDocumentVersionEnum
	ksSDV_Kompas_16_Sp1           =20         # from enum ksSaveDocumentVersionEnum
	ksSDV_Kompas_17               =21         # from enum ksSaveDocumentVersionEnum
	ksSDV_Kompas_17_Sp1           =22         # from enum ksSaveDocumentVersionEnum
	ksSDV_Kompas_18               =23         # from enum ksSaveDocumentVersionEnum
	ksSDV_Kompas_18_Sp1           =24         # from enum ksSaveDocumentVersionEnum
	ksSDV_Kompas_19               =25         # from enum ksSaveDocumentVersionEnum
	ksSDV_Kompas_20               =26         # from enum ksSaveDocumentVersionEnum
	ksSDV_Kompas_5_11_R03         =1          # from enum ksSaveDocumentVersionEnum
	ksSDV_Kompas_6_0              =2          # from enum ksSaveDocumentVersionEnum
	ksSDV_Kompas_6_Plus           =3          # from enum ksSaveDocumentVersionEnum
	ksSDV_Kompas_7_0              =4          # from enum ksSaveDocumentVersionEnum
	ksSDV_Kompas_7_Plus           =5          # from enum ksSaveDocumentVersionEnum
	ksSDV_Kompas_8_0              =6          # from enum ksSaveDocumentVersionEnum
	ksSDV_Kompas_8_Plus           =7          # from enum ksSaveDocumentVersionEnum
	ksSDV_Kompas_9_0              =8          # from enum ksSaveDocumentVersionEnum
	ksSDV_Prev                    =-1         # from enum ksSaveDocumentVersionEnum
	ksmSelect                     =1          # from enum ksSelectionMngNotifyEnum
	ksmUnselect                   =2          # from enum ksSelectionMngNotifyEnum
	ksmUnselectAll                =3          # from enum ksSelectionMngNotifyEnum
	ksAxisUnknown                 =-1         # from enum ksSemiAxisTypeEnum
	ksAxisXMinus                  =1          # from enum ksSemiAxisTypeEnum
	ksAxisXPlus                   =0          # from enum ksSemiAxisTypeEnum
	ksAxisYMinus                  =3          # from enum ksSemiAxisTypeEnum
	ksAxisYPlus                   =2          # from enum ksSemiAxisTypeEnum
	ksDocumentSheet               =0          # from enum ksSheetTypeEnum
	ksFrontAdditionalSheet        =1          # from enum ksSheetTypeEnum
	ksLastAdditionalSheet         =2          # from enum ksSheetTypeEnum
	ksAllSheets                   =0          # from enum ksSheetsRangeEnum
	ksEvenSheets                  =2          # from enum ksSheetsRangeEnum
	ksUnevenSheets                =1          # from enum ksSheetsRangeEnum
	ksLSDown                      =3          # from enum ksShelfDirectionEnum
	ksLSLeft                      =-1         # from enum ksShelfDirectionEnum
	ksLSNone                      =0          # from enum ksShelfDirectionEnum
	ksLSRight                     =1          # from enum ksShelfDirectionEnum
	ksLSUp                        =2          # from enum ksShelfDirectionEnum
	ksTmpObjHide                  =0          # from enum ksShowHideTmpObjTypeEnum
	ksTmpObjShow                  =1          # from enum ksShowHideTmpObjTypeEnum
	ksTmpObjShowPhantom           =2          # from enum ksShowHideTmpObjTypeEnum
	ksSDSketchMode                =1000       # from enum ksSlaveDocumentTypeEnum
	ksSDSpecificationSlave        =1001       # from enum ksSlaveDocumentTypeEnum
	ksSTAngleSnap                 =7          # from enum ksSnapTypeEnum
	ksSTGrid                      =5          # from enum ksSnapTypeEnum
	ksSTIntersect                 =4          # from enum ksSnapTypeEnum
	ksSTNearestMiddle             =2          # from enum ksSnapTypeEnum
	ksSTNearestPoint              =1          # from enum ksSnapTypeEnum
	ksSTNormalToCurve             =9          # from enum ksSnapTypeEnum
	ksSTObjectCentre              =3          # from enum ksSnapTypeEnum
	ksSTPointOnCurve              =8          # from enum ksSnapTypeEnum
	ksSTTangentToCurve            =10         # from enum ksSnapTypeEnum
	ksSTUndefine                  =0          # from enum ksSnapTypeEnum
	ksSTUnknown                   =-1         # from enum ksSnapTypeEnum
	ksSTXYAlign                   =6          # from enum ksSnapTypeEnum
	ksSortTypeCompositeDown       =6          # from enum ksSortTypeEnum
	ksSortTypeCompositeUp         =1          # from enum ksSortTypeEnum
	ksSortTypeDocument            =4          # from enum ksSortTypeEnum
	ksSortTypeDown                =5          # from enum ksSortTypeEnum
	ksSortTypeNone                =0          # from enum ksSortTypeEnum
	ksSortTypeUp                  =3          # from enum ksSortTypeEnum
	sdDocumentAdd                 =2          # from enum ksSpcDocumentNotifyEnum
	sdDocumentBeginAdd            =1          # from enum ksSpcDocumentNotifyEnum
	sdDocumentBeginRemove         =3          # from enum ksSpcDocumentNotifyEnum
	sdDocumentRemove              =4          # from enum ksSpcDocumentNotifyEnum
	sdSpcStyleBeginChange         =5          # from enum ksSpcDocumentNotifyEnum
	sdSpcStyleChange              =6          # from enum ksSpcDocumentNotifyEnum
	soBeginCopy                   =15         # from enum ksSpcObjectNotifyEnum
	soBeginDelete                 =1          # from enum ksSpcObjectNotifyEnum
	soBeginGeomChange             =9          # from enum ksSpcObjectNotifyEnum
	soBeginProcess                =11         # from enum ksSpcObjectNotifyEnum
	soCellBeginEdit               =4          # from enum ksSpcObjectNotifyEnum
	soCellDblClick                =3          # from enum ksSpcObjectNotifyEnum
	soChangeCurrent               =5          # from enum ksSpcObjectNotifyEnum
	soCopy                        =16         # from enum ksSpcObjectNotifyEnum
	soCreateObject                =13         # from enum ksSpcObjectNotifyEnum
	soDelete                      =2          # from enum ksSpcObjectNotifyEnum
	soDocumentAdd                 =7          # from enum ksSpcObjectNotifyEnum
	soDocumentBeginAdd            =6          # from enum ksSpcObjectNotifyEnum
	soDocumentRemove              =8          # from enum ksSpcObjectNotifyEnum
	soEndProcess                  =12         # from enum ksSpcObjectNotifyEnum
	soGeomChange                  =10         # from enum ksSpcObjectNotifyEnum
	soUpdateObject                =14         # from enum ksSpcObjectNotifyEnum
	ksSpcUsedInAllDescriptions    =0          # from enum ksSpcUsedTypeEnum
	ksSpcUsedInCurrentDescription =1          # from enum ksSpcUsedTypeEnum
	ksSColumnCode                 =11         # from enum ksSpecificationColumnTypeEnum
	ksSColumnCodeOKP              =16         # from enum ksSpecificationColumnTypeEnum
	ksSColumnCount                =6          # from enum ksSpecificationColumnTypeEnum
	ksSColumnDocumentCode         =15         # from enum ksSpecificationColumnTypeEnum
	ksSColumnDocumentName         =14         # from enum ksSpecificationColumnTypeEnum
	ksSColumnDocumentNumber       =13         # from enum ksSpecificationColumnTypeEnum
	ksSColumnFactory              =12         # from enum ksSpecificationColumnTypeEnum
	ksSColumnFormat               =1          # from enum ksSpecificationColumnTypeEnum
	ksSColumnMark                 =4          # from enum ksSpecificationColumnTypeEnum
	ksSColumnMass                 =8          # from enum ksSpecificationColumnTypeEnum
	ksSColumnMaterial             =9          # from enum ksSpecificationColumnTypeEnum
	ksSColumnName                 =5          # from enum ksSpecificationColumnTypeEnum
	ksSColumnNote                 =7          # from enum ksSpecificationColumnTypeEnum
	ksSColumnPosition             =3          # from enum ksSpecificationColumnTypeEnum
	ksSColumnUnknown              =0          # from enum ksSpecificationColumnTypeEnum
	ksSColumnUser                 =10         # from enum ksSpecificationColumnTypeEnum
	ksSColumnZone                 =2          # from enum ksSpecificationColumnTypeEnum
	ksLinkNone                    =0          # from enum ksSpecificationLinkTypeEnum
	ksLinkOnlyObjects             =1          # from enum ksSpecificationLinkTypeEnum
	ksLinkWithPositionCalculate   =2          # from enum ksSpecificationLinkTypeEnum
	ssBeginCalcPositions          =10         # from enum ksSpecificationNotifyEnum
	ssBeginCreateObject           =12         # from enum ksSpecificationNotifyEnum
	ssCalcPositions               =11         # from enum ksSpecificationNotifyEnum
	ssChangeCurrentSpcDescription =3          # from enum ksSpecificationNotifyEnum
	ssSpcDescriptionAdd           =4          # from enum ksSpecificationNotifyEnum
	ssSpcDescriptionBeginEdit     =6          # from enum ksSpecificationNotifyEnum
	ssSpcDescriptionEdit          =7          # from enum ksSpecificationNotifyEnum
	ssSpcDescriptionRemove        =5          # from enum ksSpecificationNotifyEnum
	ssSynchronization             =9          # from enum ksSpecificationNotifyEnum
	ssSynchronizationBegin        =8          # from enum ksSpecificationNotifyEnum
	ssTuningSpcStyleBeginChange   =1          # from enum ksSpecificationNotifyEnum
	ssTuningSpcStyleChange        =2          # from enum ksSpecificationNotifyEnum
	ksObjectStateEdit             =2          # from enum ksSpecificationObjectStateEnum
	ksObjectStateFromInsert       =1          # from enum ksSpecificationObjectStateEnum
	ksObjectStateIndependent      =0          # from enum ksSpecificationObjectStateEnum
	ksObjectStateUserSetNotEdit   =3          # from enum ksSpecificationObjectStateEnum
	ksSpecificationBaseObject     =1          # from enum ksSpecificationObjectTypeEnum
	ksSpecificationBlock          =4          # from enum ksSpecificationObjectTypeEnum
	ksSpecificationComment        =2          # from enum ksSpecificationObjectTypeEnum
	ksSpecificationEmptyString    =6          # from enum ksSpecificationObjectTypeEnum
	ksSpecificationReserveString  =5          # from enum ksSpecificationObjectTypeEnum
	ksSpecificationSectionName    =3          # from enum ksSpecificationObjectTypeEnum
	ksSpecificationUnknownObject  =0          # from enum ksSpecificationObjectTypeEnum
	ksSpcStyleDistinguish         =1          # from enum ksSpecificationStyleDifferenceTypeEnum
	ksSpcStyleEqual               =0          # from enum ksSpecificationStyleDifferenceTypeEnum
	ksSpcStyleNotFound            =-1         # from enum ksSpecificationStyleDifferenceTypeEnum
	ksSpecificationSimple         =0          # from enum ksSpecificationVariantEnum
	ksSpecificationVariantA       =1          # from enum ksSpecificationVariantEnum
	ksSpecificationVariantB       =2          # from enum ksSpecificationVariantEnum
	ksSpecificationVariantG       =4          # from enum ksSpecificationVariantEnum
	ksSpecificationVariantV       =3          # from enum ksSpecificationVariantEnum
	ksStApprovedBy                =115        # from enum ksStampEnum
	ksStApprovedDate              =135        # from enum ksStampEnum
	ksStAuthor                    =110        # from enum ksStampEnum
	ksStCheckedBy                 =111        # from enum ksStampEnum
	ksStCheckedDate               =131        # from enum ksStampEnum
	ksStCompany                   =9          # from enum ksStampEnum
	ksStDescription               =2          # from enum ksStampEnum
	ksStDesigner                  =113        # from enum ksStampEnum
	ksStDocumentCode              =52         # from enum ksStampEnum
	ksStDocumentLetter1           =40         # from enum ksStampEnum
	ksStDocumentLetter2           =41         # from enum ksStampEnum
	ksStDocumentLetter3           =42         # from enum ksStampEnum
	ksStDocumentName              =51         # from enum ksStampEnum
	ksStEndDesignDate             =130        # from enum ksStampEnum
	ksStExecutionDate             =133        # from enum ksStampEnum
	ksStFullFileName              =43         # from enum ksStampEnum
	ksStMarkingLine               =45         # from enum ksStampEnum
	ksStMass                      =5          # from enum ksStampEnum
	ksStMaterial                  =3          # from enum ksStampEnum
	ksStMfgApprovedBy             =112        # from enum ksStampEnum
	ksStMfgApprovedDate           =132        # from enum ksStampEnum
	ksStNumberOfSheets            =8          # from enum ksStampEnum
	ksStOKPCode                   =53         # from enum ksStampEnum
	ksStPartNumber                =1          # from enum ksStampEnum
	ksStRateOfInspection          =114        # from enum ksStampEnum
	ksStRateOfInspectionDate      =134        # from enum ksStampEnum
	ksStScale                     =6          # from enum ksStampEnum
	ksStSheetNumber               =7          # from enum ksStampEnum
	ksStShortFileName             =44         # from enum ksStampEnum
	ksStTypeOfWork                =10         # from enum ksStampEnum
	kdBeginEditStamp              =1          # from enum ksStampNotifyEnum
	kdEndEditStamp                =2          # from enum ksStampNotifyEnum
	kdStampBeginClearCells        =5          # from enum ksStampNotifyEnum
	kdStampCellBeginEdit          =4          # from enum ksStampNotifyEnum
	kdStampCellDblClick           =3          # from enum ksStampNotifyEnum
	ksCurveStyleLibrary           =1          # from enum ksStylesLibraryTypeEnum
	ksGraphicLayoutStyleLibrary   =5          # from enum ksStylesLibraryTypeEnum
	ksHatchStyleLibrary           =2          # from enum ksStylesLibraryTypeEnum
	ksSpcLayoutStyleLibrary       =7          # from enum ksStylesLibraryTypeEnum
	ksStampStyleLibrary           =4          # from enum ksStylesLibraryTypeEnum
	ksTextLayoutStyleLibrary      =6          # from enum ksStylesLibraryTypeEnum
	ksTextStyleLibrary            =3          # from enum ksStylesLibraryTypeEnum
	ksSCAlreadyStarted            =-2         # from enum ksSystemControlStartEnum
	ksSCCloseApplication          =0          # from enum ksSystemControlStartEnum
	ksSCError                     =-4         # from enum ksSystemControlStartEnum
	ksSCStartedByAnotherLibrary   =-3         # from enum ksSystemControlStartEnum
	ksSCStopItself                =-1         # from enum ksSystemControlStartEnum
	ksSCStoppedByMenuCommand      =1          # from enum ksSystemControlStartEnum
	ksTPBottomCenter              =8          # from enum ksTablePointEnum
	ksTPCenter                    =9          # from enum ksTablePointEnum
	ksTPLeftBottom                =1          # from enum ksTablePointEnum
	ksTPLeftCenter                =2          # from enum ksTablePointEnum
	ksTPLeftUp                    =3          # from enum ksTablePointEnum
	ksTPRightBottom               =7          # from enum ksTablePointEnum
	ksTPRightCenter               =6          # from enum ksTablePointEnum
	ksTPRightUp                   =5          # from enum ksTablePointEnum
	ksTPUndefined                 =0          # from enum ksTablePointEnum
	ksTPUpCenter                  =4          # from enum ksTablePointEnum
	ksTTLFirstColumn              =1          # from enum ksTableTileLayoutEnum
	ksTTLFirstRow                 =0          # from enum ksTableTileLayoutEnum
	ksTTLNotCreate                =2          # from enum ksTableTileLayoutEnum
	ksTabulatorFillingBaseDash    =5          # from enum ksTabulatorFillingEnum
	ksTabulatorFillingBaseDot     =3          # from enum ksTabulatorFillingEnum
	ksTabulatorFillingBaseLine    =1          # from enum ksTabulatorFillingEnum
	ksTabulatorFillingCenterDash  =6          # from enum ksTabulatorFillingEnum
	ksTabulatorFillingCenterDot   =4          # from enum ksTabulatorFillingEnum
	ksTabulatorFillingCenterLine  =2          # from enum ksTabulatorFillingEnum
	ksTabulatorFillingNone        =0          # from enum ksTabulatorFillingEnum
	ksTABaseline                  =24         # from enum ksTextAlignEnum
	ksTABottom                    =8          # from enum ksTextAlignEnum
	ksTAHCenter                   =6          # from enum ksTextAlignEnum
	ksTALeft                      =0          # from enum ksTextAlignEnum
	ksTARight                     =2          # from enum ksTextAlignEnum
	ksTATop                       =0          # from enum ksTextAlignEnum
	ksTAVCenter                   =56         # from enum ksTextAlignEnum
	ksHFormatDivision             =2          # from enum ksTextHorizontalFormatEnum
	ksHFormatNot                  =0          # from enum ksTextHorizontalFormatEnum
	ksHFormatStrNarrowing         =1          # from enum ksTextHorizontalFormatEnum
	ksTItDenominator              =2          # from enum ksTextItemEnum
	ksTItDeviationEnd             =6          # from enum ksTextItemEnum
	ksTItFontSymbol               =23         # from enum ksTextItemEnum
	ksTItFontSymbolW              =8215       # from enum ksTextItemEnum
	ksTItFractionEnd              =3          # from enum ksTextItemEnum
	ksTItHyperText                =8192       # from enum ksTextItemEnum
	ksTItHyperTextEnd             =25         # from enum ksTextItemEnum
	ksTItLowerDeviation           =5          # from enum ksTextItemEnum
	ksTItNumerator                =1          # from enum ksTextItemEnum
	ksTItSBase                    =7          # from enum ksTextItemEnum
	ksTItSEnd                     =16         # from enum ksTextItemEnum
	ksTItSLowerIndex              =9          # from enum ksTextItemEnum
	ksTItSUpperIndex              =8          # from enum ksTextItemEnum
	ksTItSeparator                =24         # from enum ksTextItemEnum
	ksTItSpecialSymbol            =17         # from enum ksTextItemEnum
	ksTItSpecialSymbolDown        =20         # from enum ksTextItemEnum
	ksTItSpecialSymbolEnd         =18         # from enum ksTextItemEnum
	ksTItSpecialSymbolNext        =19         # from enum ksTextItemEnum
	ksTItSpecialSymbolRight       =21         # from enum ksTextItemEnum
	ksTItString                   =0          # from enum ksTextItemEnum
	ksTItTab                      =22         # from enum ksTextItemEnum
	ksTItUpperDeviation           =4          # from enum ksTextItemEnum
	ksTLError                     =0          # from enum ksTextLineType
	ksTLFragment                  =3          # from enum ksTextLineType
	ksTLRaster                    =4          # from enum ksTextLineType
	ksTLTable                     =5          # from enum ksTextLineType
	ksTLText                      =1          # from enum ksTextLineType
	ksTLVerticalText              =2          # from enum ksTextLineType
	ksTNumbDisableNumber          =3          # from enum ksTextNumberingEnum
	ksTNumbNewNumber              =2          # from enum ksTextNumberingEnum
	ksTNumbNoNumber               =0          # from enum ksTextNumberingEnum
	ksTNumbNumber                 =1          # from enum ksTextNumberingEnum
	ksTNumbUnknown                =-1         # from enum ksTextNumberingEnum
	ksTextBig                     =2          # from enum ksTextSizeEnum
	ksTextDefault                 =0          # from enum ksTextSizeEnum
	ksTextMiddle                  =2          # from enum ksTextSizeEnum
	ksTextNormal                  =1          # from enum ksTextSizeEnum
	ksTextSmall                   =3          # from enum ksTextSizeEnum
	ksTSAxisMark                  =19         # from enum ksTextStyleEnum
	ksTSBOMTableName              =23         # from enum ksTextStyleEnum
	ksTSBrace                     =15         # from enum ksTextStyleEnum
	ksTSBuildingCutLine           =24         # from enum ksTextStyleEnum
	ksTSDefault                   =0          # from enum ksTextStyleEnum
	ksTSDimensionText             =3          # from enum ksTextStyleEnum
	ksTSDirectionArrow            =12         # from enum ksTextStyleEnum
	ksTSDrawingAnnotation         =1          # from enum ksTextStyleEnum
	ksTSLeader1                   =5          # from enum ksTextStyleEnum
	ksTSLeader2                   =6          # from enum ksTextStyleEnum
	ksTSLeader3                   =7          # from enum ksTextStyleEnum
	ksTSMarkInsideForm            =22         # from enum ksTextStyleEnum
	ksTSMarkOnLeader              =20         # from enum ksTextStyleEnum
	ksTSMarkOnLine                =21         # from enum ksTextStyleEnum
	ksTSModificationSymbol        =14         # from enum ksTextStyleEnum
	ksTSMultiTextLeader           =17         # from enum ksTextStyleEnum
	ksTSRprtTableCell             =26         # from enum ksTextStyleEnum
	ksTSRprtTableHeader           =25         # from enum ksTextStyleEnum
	ksTSRprtTableName             =27         # from enum ksTextStyleEnum
	ksTSSectionLine               =11         # from enum ksTextStyleEnum
	ksTSShapeDeviations           =8          # from enum ksTextStyleEnum
	ksTSSpecifications            =2          # from enum ksTextStyleEnum
	ksTSSurfaceFinish             =4          # from enum ksTextStyleEnum
	ksTSTableCell                 =10         # from enum ksTextStyleEnum
	ksTSTableHeader               =9          # from enum ksTextStyleEnum
	ksTSTableName                 =28         # from enum ksTextStyleEnum
	ksTSTextMark                  =29         # from enum ksTextStyleEnum
	ksTSUnitMarking               =18         # from enum ksTextStyleEnum
	ksTSUnitNumber                =16         # from enum ksTextStyleEnum
	ksTSUnspecifiedSurfaceFinish  =13         # from enum ksTextStyleEnum
	ksThemeDark                   =2          # from enum ksThemeEnum
	ksThemeLight                  =0          # from enum ksThemeEnum
	ksTAArrow                     =1          # from enum ksToleranceArrowType
	ksTANone                      =0          # from enum ksToleranceArrowType
	ksTATriangle                  =2          # from enum ksToleranceArrowType
	ksTPSDiametr                  =2          # from enum ksTolerancePrefixSignEnum
	ksTPSNone                     =0          # from enum ksTolerancePrefixSignEnum
	ksTPSRadius                   =1          # from enum ksTolerancePrefixSignEnum
	ksTPSToleranseT               =3          # from enum ksTolerancePrefixSignEnum
	ksTPSToleranseT2              =4          # from enum ksTolerancePrefixSignEnum
	ksTSNone                      =0          # from enum ksToleranceSuffixSignEnum
	ksTSToleranseM                =1          # from enum ksToleranceSuffixSignEnum
	ksTSToleranseP                =3          # from enum ksToleranceSuffixSignEnum
	ksTSToleranseS                =2          # from enum ksToleranceSuffixSignEnum
	ksMultiTree                   =1          # from enum ksTreeTypeEnum
	ksOperTree                    =0          # from enum ksTreeTypeEnum
	ksTwinSwitcherPos1            =1          # from enum ksTwinSwitcherValueEnum
	ksTwinSwitcherPos2            =2          # from enum ksTwinSwitcherValueEnum
	tls_Carbon                    =14         # from enum ksTypeLookStyle
	tls_Office_2003               =2          # from enum ksTypeLookStyle
	tls_Office_2007               =5          # from enum ksTypeLookStyle
	tls_Office_2007_Aqua          =7          # from enum ksTypeLookStyle
	tls_Office_2007_LunaBlue      =5          # from enum ksTypeLookStyle
	tls_Office_2007_ObsidianBlack =6          # from enum ksTypeLookStyle
	tls_Office_2007_Silver        =8          # from enum ksTypeLookStyle
	tls_Office_2010_Blue          =11         # from enum ksTypeLookStyle
	tls_Office_2010_Dark          =12         # from enum ksTypeLookStyle
	tls_Office_2010_White         =13         # from enum ksTypeLookStyle
	tls_VisualStudio2005          =3          # from enum ksTypeLookStyle
	tls_VisualStudio2008          =9          # from enum ksTypeLookStyle
	tls_VisualStudio2010          =10         # from enum ksTypeLookStyle
	tls_VisualStudio_97           =0          # from enum ksTypeLookStyle
	tls_VisualStudio_NET          =1          # from enum ksTypeLookStyle
	tls_WindowsXP                 =4          # from enum ksTypeLookStyle
	ksVFBooleanPlusMinus          =3          # from enum ksValueFormatEnum
	ksVFBooleanValue              =1          # from enum ksValueFormatEnum
	ksVFBooleanYesNo              =2          # from enum ksValueFormatEnum
	ksVFFullMarking               =1          # from enum ksValueFormatEnum
	ksVFOnlyAdditionMarking       =2          # from enum ksValueFormatEnum
	ksVFVariableValue             =9          # from enum ksValueFormatEnum
	ksVFvvfFullValue              =15         # from enum ksValueFormatEnum
	ksVFvvfGridFullValue          =7          # from enum ksValueFormatEnum
	ksVFvvfToleranceDiv           =14         # from enum ksValueFormatEnum
	ksValueTypeFloat              =2          # from enum ksValueTypeEnum
	ksValueTypeInteger            =1          # from enum ksValueTypeEnum
	ksValueTypeRecord             =4          # from enum ksValueTypeEnum
	ksValueTypeString             =3          # from enum ksValueTypeEnum
	ksValueTypeUnknown            =0          # from enum ksValueTypeEnum
	ksVMAdditionalNumber          =4          # from enum ksVariantMarkingTypeEnum
	ksVMBaseMarking               =1          # from enum ksVariantMarkingTypeEnum
	ksVMCode                      =8          # from enum ksVariantMarkingTypeEnum
	ksVMEmbodimentNumber          =2          # from enum ksVariantMarkingTypeEnum
	ksVMFullMarking               =-1         # from enum ksVariantMarkingTypeEnum
	vmBeginEdit                   =1          # from enum ksViewsAndLayersManagerNotifyEnum
	vmEndEdit                     =2          # from enum ksViewsAndLayersManagerNotifyEnum

RecordMap = {
}

CLSIDToClassMap = {
}
CLSIDToPackageMap = {}
win32com.client.CLSIDToClass.RegisterCLSIDsFromDict( CLSIDToClassMap )
VTablesToPackageMap = {}
VTablesToClassMap = {
}


NamesToIIDMap = {
}

win32com.client.constants.__dicts__.append(constants.__dict__)

